within ;
package CO2GCHPModels_Master_Monjur
  connector FluidPort_a "Generic fluid connector at design inlet"
    extends Modelica.Fluid.Interfaces.FluidPort;
    annotation (defaultComponentName="port_a",
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics={Ellipse(
            extent={{-40,40},{40,-40}},
            lineColor={0,0,0},
            fillColor={0,127,255},
            fillPattern=FillPattern.Solid), Text(extent={{-150,110},{150,50}},
              textString="%name")}),
         Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}), graphics={
                             Ellipse(
            extent={{-80,80},{80,-80}},
            lineColor={23,162,255},
            lineThickness=0.5,
            fillColor={23,162,255},
            fillPattern=FillPattern.Solid)}));
  end FluidPort_a;

  connector LiquidPort "Liquid port"

    parameter TILMedia.LiquidTypes.BaseLiquid           liquidType;

    Modelica.SIunits.AbsolutePressure p "Pressure"
                                     annotation (
        unassignedMessage="A liquid pressure cannot be uniquely calculated.
The reason could be that
- a hydraulic capacitor object (TIL.LiquidComponents.HydraulicCapacitor) or
- a liquid boundary type \"p\" is missing, to define the pressure inside a liquid circuit, or
- a connector of a liquid component is not connected.");

    flow Modelica.SIunits.MassFlowRate m_flow "Mass flow rate"
                                                 annotation (
        unassignedMessage="A liquid mass flow rate cannot be uniquely calculated.
The reason could be that
- a hydraulic capacitor object (TIL.LiquidComponents.HydraulicCapacitor) or
- a liquid boundary type \"p\" is missing, to define the pressure inside a liquid circuit, or
- a connector of a liquid component is not connected.");

    stream Modelica.SIunits.SpecificEnthalpy h_outflow "Specific enthalpy";

    stream Modelica.SIunits.MassFraction xi_outflow[liquidType.nc - 1]
      "Independent mixture mass fractions m_i/m in the connection point";
  annotation (Icon(graphics={Ellipse(
            extent={{-80,80},{80,-80}},
            lineColor={0,170,238},
            lineThickness=0.5,
            fillColor={0,170,238},
            fillPattern=FillPattern.Solid)}),
                            Diagram(graphics={Ellipse(
            extent={{-40,40},{40,-40}},
            lineColor={0,170,238},
            fillColor={0,170,238},
            fillPattern=FillPattern.Solid), Text(
            extent={{-100,100},{100,60}},
            lineColor={0,170,238},
            fillColor={0,170,238},
            fillPattern=FillPattern.Solid,
            textString=
               "%name")}));

  end LiquidPort;

  model InterfaceMFtoTILLiquid
  /*********************** SIM ***********************************/

    replaceable package Medium =
        Modelica.Media.Interfaces.PartialMedium
      "Medium model within the source"
       annotation (choicesAllMatching=true);

    parameter TILMedia.LiquidTypes.BaseLiquid  liquidType = sim.liquidType1
      "Liquid type"
                 annotation (Dialog(tab="SIM",group="SIM"),choices(
      choice=sim.liquidType1 "Liquid 1 as defined in SIM",
      choice=sim.liquidType2 "Liquid 2 as defined in SIM",
      choice=sim.liquidType3 "Liquid 3 as defined in SIM"));

  protected
    outer TIL.SystemInformationManager sim "System information manager";
    Modelica.SIunits.Temperature T;
    TILMedia.Liquid_pT liquid_to_TIL(p = port_a.p, T = T,  xi = inStream(port_a.Xi_outflow),  liquidType = liquidType) annotation (Placement(transformation(extent={{-10,10},
              {10,30}})));
    TILMedia.Liquid_ph liquid_to_MF(p = port_a.p, h = inStream(liquidPort.h_outflow),  xi = inStream(liquidPort.xi_outflow), liquidType = liquidType) annotation (Placement(transformation(extent={{-10,-32},
              {10,-12}})));
    Medium.BaseProperties medium;//(p=port_a.p, Xi = inStream(gasPort.xi_outflow, T = 1);
  /******************** Connector *****************************/

  public
    CO2GCHPModels_Master_Monjur.FluidPort_a port_a(redeclare each package
        Medium = Medium)
      annotation (Placement(transformation(extent={{-49,-10},{-29,10}}),
          iconTransformation(extent={{-21,-11},{1,11}})));
    CO2GCHPModels_Master_Monjur.LiquidPort liquidPort(final liquidType=
          liquidType)
      annotation (Placement(transformation(extent={{30,-10},{50,10}}),
          iconTransformation(extent={{-1,-11},{21,11}})));

  equation
    port_a.m_flow + liquidPort.m_flow = 0;
    port_a.p = liquidPort.p;

    T = Medium.temperature(Medium.setState_phX(port_a.p, inStream(port_a.h_outflow), inStream(port_a.Xi_outflow)));
    medium.p = port_a.p;
    medium.T = liquid_to_MF.T;
    medium.Xi = liquid_to_MF.xi;

    liquidPort.h_outflow = liquid_to_TIL.h;
    port_a.h_outflow = medium.h;

    liquidPort.xi_outflow = inStream(port_a.Xi_outflow);
    port_a.Xi_outflow = inStream(liquidPort.xi_outflow);

   annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics), Icon(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
            Rectangle(
            extent={{-1,20},{1,-20}},
            pattern=LinePattern.None,
            lineColor={0,0,0},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid)}),
      uses(Modelica(version="3.2")),             Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
              {100,100}}), graphics), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics));
  end InterfaceMFtoTILLiquid;

  package Boreholes "Package with borehole heat exchangers"
    extends Modelica.Icons.VariantsPackage;
    model UTube "Single U-tube borehole heat exchanger"
      extends
        CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialTwoPortInterface(
          show_T=true);
      extends Buildings.Fluid.Interfaces.TwoPortFlowResistanceParameters(final
          computeFlowResistance=false, final linearizeFlowResistance=false);
      extends Buildings.Fluid.Interfaces.LumpedVolumeDeclarations;

      replaceable parameter Buildings.HeatTransfer.Data.Soil.Generic matSoi
        "Thermal properties of soil"
        annotation (choicesAllMatching=true, Dialog(group="Soil"),
        Placement(transformation(extent={{2,70},{22,90}})));
      replaceable parameter
        Buildings.HeatTransfer.Data.BoreholeFillings.Generic                     matFil
        "Thermal properties of the filling material"
        annotation (choicesAllMatching=true, Dialog(group="Borehole"),
        Placement(transformation(extent={{-42,70},{-22,90}})));

      parameter Modelica.SIunits.Radius rTub=0.02 "Radius of the tubes"
        annotation(Dialog(group="Tubes"));
      parameter Modelica.SIunits.ThermalConductivity kTub=0.5
        "Thermal conductivity of the tube" annotation (Dialog(group="Tubes"));
      parameter Modelica.SIunits.Length eTub=0.002 "Thickness of a tube"
        annotation (Dialog(group="Tubes"));

      parameter Modelica.SIunits.Height hBor "Total height of the borehole"
        annotation(Dialog(group="Borehole"));
      parameter Integer nVer=10
        "Number of segments used for discretization in the vertical direction"
          annotation(Dialog(group="Borehole"));
      parameter Modelica.SIunits.Radius rBor=0.1 "Radius of the borehole";

      parameter Modelica.SIunits.Radius rExt=3
        "Radius of the soil used for the external boundary condition"
        annotation (Dialog(group="Soil"));
      parameter Integer nHor(min=1) = 10
        "Number of state variables in each horizontal layer of the soil"
        annotation (Dialog(group="Soil"));

      parameter Modelica.SIunits.Temperature TExt0_start=283.15
        "Initial far field temperature"
        annotation (Dialog(tab="Initial temperature", group="Soil"));
      parameter Modelica.SIunits.Temperature TExt_start[nVer]={if z[i] >= z0 then
          TExt0_start + (z[i] - z0)*dT_dz else TExt0_start for i in 1:nVer}
        "Temperature of the undisturbed ground"
        annotation (Dialog(tab="Initial temperature", group="Soil"));

      parameter Modelica.SIunits.Temperature TFil0_start=TExt0_start
        "Initial temperature of the filling material for h = 0...z0"
        annotation (Dialog(tab="Initial temperature", group="Filling material"));
      parameter Modelica.SIunits.Temperature TFil_start[nVer]=TExt_start
        "Temperature of the undisturbed ground"
        annotation (Dialog(tab="Initial temperature", group="Filling material"));

      parameter Modelica.SIunits.Height z0=10
        "Depth below which the temperature gradient starts"
        annotation (Dialog(tab="Initial temperature", group="Temperature profile"));
      parameter Real dT_dz(unit="K/m") = 0.01
        "Vertical temperature gradient of the undisturbed soil for h below z0"
        annotation (Dialog(tab="Initial temperature", group="Temperature profile"));

      parameter Modelica.SIunits.Time samplePeriod
        "Sample period for the external boundary condition"
        annotation (Dialog(group="Soil"));
      parameter Modelica.SIunits.Length xC=0.05
        "Shank spacing, defined as the distance between the center of a pipe and the center of the borehole"
        annotation(Dialog(group="Borehole"));
      parameter Real B0=17.44 "Shape coefficient for grout resistance"
        annotation(Dialog(group="Borehole"));
      parameter Real B1=-0.605 "Shape coefficient for grout resistance"
        annotation(Dialog(group="Borehole"));
      CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.BoreholeSegment borHol[nVer](
        redeclare each final package Medium = Medium,
        each final matSoi=matSoi,
        each final matFil=matFil,
        each final hSeg=hBor/nVer,
        each final samplePeriod=samplePeriod,
        each final rTub=rTub,
        each final rBor=rBor,
        each final rExt=rExt,
        each final xC=xC,
        each final eTub=eTub,
        each final kTub=kTub,
        each final B0=B0,
        each final B1=B1,
        each final nSta=nHor,
        each final m_flow_nominal=m_flow_nominal,
        each final m_flow_small=m_flow_small,
        final dp_nominal={if i == 1 then dp_nominal else 0 for i in 1:nVer},
        TExt_start=TExt_start,
        TFil_start=TExt_start,
        each final homotopyInitialization=homotopyInitialization,
        each final show_T=show_T,
        each final computeFlowResistance=computeFlowResistance,
        each final from_dp=from_dp,
        each final linearizeFlowResistance=linearizeFlowResistance,
        each final deltaM=deltaM,
        each final energyDynamics=energyDynamics,
        each final massDynamics=massDynamics,
        each final p_start=p_start,
        each T_start=T_start,
        each X_start=X_start,
        each C_start=C_start,
        each C_nominal=C_nominal,
        each allowFlowReversal=allowFlowReversal)
        "Discretized borehole segments"
        annotation (Placement(transformation(extent={{-20,-10},{0,10}})));

      Modelica.SIunits.Temperature Tdown[nVer] "Medium temperature in pipe 1";
      Modelica.SIunits.Temperature Tup[nVer] "Medium temperature in pipe 2";
    protected
      parameter Modelica.SIunits.Height z[nVer]={hBor/nVer*(i - 0.5) for i in 1:
          nVer} "Distance from the surface to the considered segment";
    equation
      Tdown[:] = borHol[:].pipFil.vol1.heatPort.T;
      Tup[:] = borHol[:].pipFil.vol2.heatPort.T;
      connect(port_a, borHol[1].port_a1) annotation (Line(
          points={{-83,86},{-60,86},{-60,6},{-20,6}},
          color={0,127,255},
          smooth=Smooth.None));
      connect(port_b, borHol[1].port_b2) annotation (Line(
          points={{83,85},{20,85},{20,-40},{-40,-40},{-40,-6},{-20,-6}},
          color={0,127,255},
          smooth=Smooth.None));
      connect(borHol[nVer].port_b1, borHol[nVer].port_a2) annotation (Line(
          points={{5.55112e-16,6},{10,6},{10,-6},{5.55112e-16,-6}},
          color={0,127,255},
          smooth=Smooth.None));
      for i in 1:nVer - 1 loop
        connect(borHol[i].port_b1, borHol[i + 1].port_a1) annotation (Line(
            points={{5.55112e-16,6},{5.55112e-16,20},{-20,20},{-20,6}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(borHol[i].port_a2, borHol[i + 1].port_b2) annotation (Line(
            points={{5.55112e-16,-6},{5.55112e-16,-20},{-20,-20},{-20,-6}},
            color={0,127,255},
            smooth=Smooth.None));
      end for;
        annotation (
        defaultComponentName="borehole",
        Icon(coordinateSystem(
            preserveAspectRatio=false,
            extent={{-100,-100},{100,100}},
            grid={2,2},
            initialScale=0.5), graphics={    Bitmap(extent={{-158,100},{157,
                  -224}}, fileName=
                  "modelica://CO2GCHPModels_Master_Monjur/GroundHX.png")}),
        Diagram(coordinateSystem(
            preserveAspectRatio=false,
            extent={{-100,-100},{100,100}},
            grid={2,2},
            initialScale=0.5), graphics),
        Documentation(info="<html>
<p>
Model of a single U-tube borehole heat exchanger. 
The borehole heat exchanger is vertically discretized into <i>n<sub>seg</sub></i>
elements of height <i>h=h<sub>Bor</sub>&frasl;n<sub>seg</sub></i>.
Each segment contains a model for the heat transfer in the borehole, 
for heat transfer in the soil and for the far-field boundary condition.
</p>
<p>
The heat transfer in the borehole is computed using a convective heat transfer coefficient
that depends on the fluid velocity, a heat resistance between the two pipes, and
a heat resistance between the pipes and the circumference of the borehole.
The heat capacity of the fluid, and the heat capacity of the grout, is taken into account.
All thermal mass is assumed to be at the two bulk temperatures of the down-flowing 
and up-flowing fluid.
</p>
<p>
The heat transfer in the soil is computed using transient heat conduction in cylindrical
coordinates for the spatial domain <i>r<sub>bor</sub> &le; r &le; r<sub>ext</sub></i>. 
In the radial direction, the spatial domain is discretized into 
<i>n<sub>hor</sub></i> segments with uniform material properties.
Thermal properties can be specified separately for each horizontal layer.
The vertical heat flow is assumed to be zero, and there is assumed to be 
no ground water flow. 
</p>
<p>
The far-field temperature, i.e., the temperature at the radius 
<i>r<sub>ext</sub></i>, is computed using a power-series solution
to a line-source heat transfer problem. This temperature boundary condition
is updated every <i>t<sub>sample</sub></i> seconds.
</p>
<p>
The initial far-field temperature <i>T<sub>ext,start</sub></i>, which
is the temperature of the soil at a radius <i>r<sub>ext</sub></i>,
is computed 
as a function of the depth <i>z &gt; 0</i>. 
For a depth between <i>0 &le; z &le; z<sub>0</sub></i>, the temperature
is set to <i>T<sub>ext,0,start</sub></i>. 
The value of <i>z<sub>0</sub></i> is a parameter with a default of 10 meters.
However, there is large variability in the depth where the undisturbed soil temperature
starts.
For a depth of <i>z<sub>0</sub> &le; z &le; h<sub>bor</sub></i>,
the temperature is computed as
</p>
<p align=\"center\" style=\"font-style:italic;\">
  T<sup>i</sup><sub>ext,start</sub> = T<sub>ext,0,start</sub> + (z<sup>i</sup> - z<sub>0</sub>)  dT &frasl; dz
</p>
<p>
with <i>i &isin; {1, ..., n<sub>ver</sub>}</i>,
where the temperature gradient <i>dT &frasl; dz &ge; 0</i> is a parameter.
As with <i>z<sub>0</sub></i>, there is large variability in 
<i>dT &frasl; dz &ge; 0</i>. The default value is set to <i>1</i> Kelvin per 100 meters.
For the temperature of the grout, the same equations are applied, with
<i>T<sub>ext,0,start</sub></i> replaced with
<i>T<sub>fil,0,start</sub></i>, and 
<i>T<sup>i</sup><sub>ext,start</sub></i> replaced with
<i>T<sup>i</sup><sub>fil,start</sub></i>. 
The default setting uses the same temperature for the soil and the filling material.
</p>
<h4>Implementation</h4>
<p>
Each horizontal layer is modeled using an instance of
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.BoreholeSegment\">
Buildings.HeatExchangers.Fluid.Boreholes.BaseClasses.BoreholeSegment</a>.
This model is composed of the model
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.HexInternalElement\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.HexInternalElement</a> which computes
the heat transfer in the pipes and the borehole filling,
of the model
<a href=\"modelica://Buildings.HeatTransfer.Conduction.SingleLayerCylinder\">
Buildings.HeatTransfer.Conduction.SingleLayerCylinder</a> which computes
the heat transfer in the soil, and
of the model
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.TemperatureBoundaryCondition\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.TemperatureBoundaryCondition</a> which computes
the far-field temperature boundary condition.
</p>
</html>",     revisions="<html>
<ul>
<li>
October 8, 2013, by Michael Wetter:<br/>
Removed parameter <code>show_V_flow</code>.
</li>
<li>
September 27, 2013, by Michael Wetter:<br/>
Added missing <code>each</code> in propagation of material properties.
</li>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
    end UTube;

    package Examples "Example files for borehole heat exchanger"
    extends Modelica.Icons.ExamplesPackage;
      model UTube "Model that tests the borehole model"
        extends Modelica.Icons.Example;
       package Medium = Buildings.Media.ConstantPropertyLiquidWater;
        CO2GCHPModels_Master_Monjur.Boreholes.UTube borHol(
          redeclare each package Medium = Medium,
          hBor=150,
          dp_nominal=10000,
          dT_dz=0.0015,
          samplePeriod=604800,
          m_flow_nominal=0.3,
          redeclare each parameter
            Buildings.HeatTransfer.Data.BoreholeFillings.Bentonite matFil,
          redeclare parameter Buildings.HeatTransfer.Data.Soil.Sandstone matSoi,
          TExt0_start=283.15,
          TFil0_start=283.15) "Borehole heat exchanger"
          annotation (Placement(transformation(extent={{-24,-50},{8,-18}},rotation=0)));

            inner Modelica.Fluid.System system
          annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
        Buildings.Fluid.Sources.Boundary_ph sin(nPorts=1, redeclare package
            Medium = Medium) "Sink"
          annotation (Placement(transformation(extent={{44,-30},{24,-10}})));
        Buildings.Fluid.Sources.MassFlowSource_T sou(
          nPorts=1,
          redeclare package Medium = Medium,
          use_m_flow_in=true,
          T=298.15) "Source"
          annotation (Placement(transformation(extent={{-54,-30},{-34,-10}})));
        Modelica.Blocks.Sources.Pulse pulse(
          amplitude=0.3,
          period=86400,
          startTime=86400/4)
          annotation (Placement(transformation(extent={{-90,-30},{-70,-10}})));
      equation
        connect(sou.ports[1], borHol.port_a)       annotation (Line(
            points={{-34,-20},{-22,-20},{-22,-20.24},{-21.84,-20.24}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(borHol.port_b, sin.ports[1])      annotation (Line(
            points={{5.84,-20.32},{24,-20.32},{24,-20}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(pulse.y, sou.m_flow_in)       annotation (Line(
            points={{-69,-20},{-60,-20},{-60,-12},{-54,-12}},
            color={0,0,127},
            smooth=Smooth.None));
       annotation(__Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/Examples/UTube.mos"
              "Simulate and plot"),
                Diagram(coordinateSystem(preserveAspectRatio=false,extent={{-100,-100},
                  {100,100}}), graphics),
                        Documentation(info="<html>
<p>
This example models a borehole heat exchanger with two pipes that are
symmetrically spaced. 
The simulation period is 5 years.
From the 4th to the 10th months, the mass flow source switches on the 
flow rate through the borehole. The leaving
water of the mass flow source is <i>25</i>&deg;C,
and the water that returns from the borehole is between 
<i>20.5</i>&deg;C
and 
<i>21.5</i>&deg;C.
</p>
</html>",       revisions="<html>
<ul>
<li>
September 27, 2013, by Michael Wetter:<br/>
Corrected <code>StopTime</code> annotation.
</li>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"),experiment(
            StopTime=157680000,
            Tolerance=1e-05));
      end UTube;
    end Examples;

    package BaseClasses "Base classes for Borehole"
     extends Modelica.Icons.BasesPackage;

      model BoreholeSegment "Vertical segment of a borehole"
        extends Buildings.Fluid.Interfaces.PartialFourPortInterface(
           redeclare final package Medium1 = Medium,
           redeclare final package Medium2 = Medium,
           final m1_flow_nominal = m_flow_nominal,
           final m2_flow_nominal = m_flow_nominal,
           final m1_flow_small =   m_flow_small,
           final m2_flow_small =   m_flow_small,
           final allowFlowReversal1=allowFlowReversal,
           final allowFlowReversal2=allowFlowReversal);
        extends Buildings.Fluid.Interfaces.TwoPortFlowResistanceParameters;
        extends Buildings.Fluid.Interfaces.LumpedVolumeDeclarations(T_start=TFil_start);
        replaceable package Medium = Modelica.Media.Interfaces.PartialMedium
          "Medium in the component" annotation (choicesAllMatching=true);
        replaceable parameter Buildings.HeatTransfer.Data.Soil.Generic matSoi
          "Thermal properties of soil"
          annotation (choicesAllMatching=true, Dialog(group="Soil"),
          Placement(transformation(extent={{2,70},{22,90}})));
        replaceable parameter
          Buildings.HeatTransfer.Data.BoreholeFillings.Generic                     matFil
          "Thermal properties of the filling material"
          annotation (choicesAllMatching=true, Dialog(group="Filling material"),
          Placement(transformation(extent={{-68,70},{-48,90}})));

        parameter Modelica.SIunits.MassFlowRate m_flow_nominal
          "Nominal mass flow rate"
          annotation(Dialog(group = "Nominal condition"));
        parameter Modelica.SIunits.MassFlowRate m_flow_small(min=0) = 1E-4*abs(m_flow_nominal)
          "Small mass flow rate for regularization of zero flow"
          annotation(Dialog(tab = "Advanced"));
        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));

        parameter Modelica.SIunits.Radius rTub=0.02 "Radius of the tubes"
          annotation (Dialog(group="Tubes"));
        parameter Modelica.SIunits.ThermalConductivity kTub=0.5
          "Thermal conductivity of the tubes" annotation (Dialog(group="Tubes"));
        parameter Modelica.SIunits.Length eTub=0.002 "Thickness of the tubes"
          annotation (Dialog(group="Tubes"));
        parameter Modelica.SIunits.Temperature TFil_start=283.15
          "Initial temperature of the filling material"
          annotation (Dialog(group="Filling material"));
        parameter Modelica.SIunits.Radius rExt=3
          "Radius of the soil used for the external boundary condition"
          annotation (Dialog(group="Soil"));
        parameter Modelica.SIunits.Temperature TExt_start=283.15
          "Initial far field temperature" annotation (Dialog(group="Soil"));
        parameter Integer nSta(min=1) = 10
          "Number of state variables in the soil"
          annotation (Dialog(group="Soil"));
        parameter Modelica.SIunits.Time samplePeriod=604800
          "Sample period for the external boundary condition"
          annotation (Dialog(group="Soil"));
        parameter Modelica.SIunits.Radius rBor=0.1 "Radius of the borehole";
        parameter Modelica.SIunits.Height hSeg "Height of the element";
        parameter Modelica.SIunits.Length xC=0.05
          "Shank spacing, defined as the distance between the center of a pipe and the center of the borehole";
        parameter Real B0=17.44 "Shape coefficient for grout resistance";
        parameter Real B1=-0.6052 "Shape coefficient for grout resistance";

       parameter Boolean allowFlowReversal = true
          "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"
          annotation(Dialog(tab="Assumptions"), Evaluate=true);

       CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.HexInternalElement pipFil(
          redeclare final package Medium = Medium,
          final matFil=matFil,
          final hSeg=hSeg,
          final rTub=rTub,
          final eTub=eTub,
          final kTub=kTub,
          final kSoi=matSoi.k,
          final xC=xC,
          final rBor=rBor,
          final TFil_start=TFil_start,
          final B0=B0,
          final B1=B1,
          final m1_flow_nominal=m_flow_nominal,
          final m2_flow_nominal=m_flow_nominal,
          final dp1_nominal=dp_nominal,
          final dp2_nominal=0,
          final from_dp1=from_dp,
          final from_dp2=from_dp,
          final linearizeFlowResistance1=linearizeFlowResistance,
          final linearizeFlowResistance2=linearizeFlowResistance,
          final deltaM1=deltaM,
          final deltaM2=deltaM,
          final m1_flow_small=m_flow_small,
          final m2_flow_small=m_flow_small,
          final allowFlowReversal1=allowFlowReversal,
          final allowFlowReversal2=allowFlowReversal,
          final homotopyInitialization=homotopyInitialization,
          final energyDynamics=energyDynamics,
          final massDynamics=massDynamics,
          final p1_start=p_start,
          T1_start=T_start,
          X1_start=X_start,
          C1_start=C_start,
          C1_nominal=C_nominal,
          final p2_start=p_start,
          T2_start=T_start,
          X2_start=X_start,
          C2_start=C_start,
          C2_nominal=C_nominal)
          "Internal part of the borehole including the pipes and the filling material"
          annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
        Buildings.HeatTransfer.Conduction.SingleLayerCylinder soi(
          final material=matSoi,
          final h=hSeg,
          final nSta=nSta,
          final r_a=rBor,
          final r_b=rExt,
          final steadyStateInitial=false,
          final TInt_start=TFil_start,
          final TExt_start=TExt_start) "Heat conduction in the soil"
          annotation (Placement(transformation(extent={{0,-10},{20,10}})));
        CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.SingleUTubeBoundaryCondition
          TBouCon(
          final matSoi=matSoi,
          final rExt=rExt,
          final hSeg=hSeg,
          final TExt_start=TExt_start,
          final samplePeriod=samplePeriod)
          "Thermal boundary condition for the far-field"
          annotation (Placement(transformation(extent={{48,-10},{68,10}})));
      protected
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heaFlo
          annotation (Placement(transformation(extent={{-30,-10},{-10,10}})));
      equation
        connect(pipFil.port_b1, port_b1)
                                      annotation (Line(
            points={{-50,6},{-40,6},{-40,60},{100,60}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(pipFil.port_a2, port_a2)
                                      annotation (Line(
            points={{-50,-6},{-40,-6},{-40,-60},{100,-60}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(pipFil.port_b2, port_b2)
                                      annotation (Line(
            points={{-70,-6},{-80,-6},{-80,-60},{-100,-60}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(pipFil.port, heaFlo.port_a)
                                           annotation (Line(
            points={{-50,6.10623e-16},{-45,6.10623e-16},{-45,1.22125e-15},{-40,
                1.22125e-15},{-40,6.10623e-16},{-30,6.10623e-16}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(heaFlo.port_b, soi.port_a) annotation (Line(
            points={{-10,6.10623e-16},{-7.5,6.10623e-16},{-7.5,1.22125e-15},{-5,
                1.22125e-15},{-5,6.10623e-16},{-5.55112e-16,6.10623e-16}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(soi.port_b, TBouCon.port) annotation (Line(
            points={{20,6.10623e-16},{30,6.10623e-16},{30,20},{80,20},{80,6.10623e-16},
                {67.6,6.10623e-16}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(port_a1, pipFil.port_a1) annotation (Line(
            points={{-100,60},{-80,60},{-80,6},{-70,6}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(heaFlo.Q_flow, TBouCon.Q_flow) annotation (Line(
            points={{-20,-10},{-20,-20},{40,-20},{40,-8},{48,-8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Icon(graphics={
              Rectangle(
                extent={{-72,80},{68,-80}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{88,54},{-88,64}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{88,-64},{-88,-54}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-72,80},{68,68}},
                lineColor={0,0,0},
                fillColor={192,192,192},
                fillPattern=FillPattern.Backward),
              Rectangle(
                extent={{-72,-68},{68,-80}},
                lineColor={0,0,0},
                fillColor={192,192,192},
                fillPattern=FillPattern.Backward)}),
          Documentation(info="<html>
<p>
Horizontal layer that is used to model a U-tube borehole heat exchanger. 
This model combines three models, each simulating a different aspect 
of a borehole heat exchanger. 
</p>
<p>
The instance <code>pipFil</code> computes the heat transfer in the pipes and the filling material. 
This computation is done using the model
<a href=\"modelica://Buildings.Fluid.Boreholes.BaseClasses.HexInternalElement\">
Buildings.Fluid.Boreholes.BaseClasses.HexInternalElement</a>.
</p>
<p>
The instance <code>soi</code> computes transient and steady state heat transfer in the soil using a vertical cylinder.
The computation is done using the model <a href=\"modelica://Buildings.HeatTransfer.Conduction.SingleLayerCylinder\">
Buildings.HeatTransfer.Conduction.SingleLayerCylinder</a>.
</p>
<p>
The model <code>TBouCon</code> computes the far-field temperature boundary condition, i.e., the temperature at the outer
surface of the above cylindrical heat transfer computation.
The computation is done using the model
<a href=\"modelica://Buildings.Fluid.Boreholes.BaseClasses.TemperatureBoundaryCondition\">
Buildings.Fluid.Boreholes.BaseClasses.TemperatureBoundaryCondition</a>.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 8, 2013, by Michael Wetter:<br/>
Removed parameter <code>show_V_flow</code>.
</li>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end BoreholeSegment;

      model HexInternalElement "Internal part of a borehole"
        extends Buildings.Fluid.Interfaces.FourPortHeatMassExchanger(
          redeclare final package Medium1 = Medium,
          redeclare final package Medium2 = Medium,
          T1_start=TFil_start,
          T2_start=TFil_start,
          final tau1=Modelica.Constants.pi*rTub^2*hSeg*rho1_nominal/m1_flow_nominal,
          final tau2=Modelica.Constants.pi*rTub^2*hSeg*rho2_nominal/m2_flow_nominal,
          final show_T=false,
          vol1(final energyDynamics=energyDynamics,
               final massDynamics=massDynamics,
               final prescribedHeatFlowRate=false,
               final homotopyInitialization=homotopyInitialization,
               final allowFlowReversal=allowFlowReversal1,
               final V=m2_flow_nominal*tau2/rho2_nominal,
               final m_flow_small=m1_flow_small),
          final vol2(final energyDynamics=energyDynamics,
               final massDynamics=massDynamics,
               final prescribedHeatFlowRate=false,
               final homotopyInitialization=homotopyInitialization,
               final V=m1_flow_nominal*tau1/rho1_nominal,
               final m_flow_small=m2_flow_small));

        replaceable package Medium = Modelica.Media.Interfaces.PartialMedium
          "Medium in the component" annotation (choicesAllMatching=true);

        replaceable parameter
          Buildings.HeatTransfer.Data.BoreholeFillings.Generic                     matFil
          "Thermal properties of the filling material"
          annotation (choicesAllMatching=true, Dialog(group="Filling material"),
                      Placement(transformation(extent={{42,70},{62,90}})));

        parameter Modelica.SIunits.Radius rTub=0.02 "Radius of the tubes"
          annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.ThermalConductivity kTub=0.5
          "Thermal conductivity of the tubes" annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.Length eTub=0.002 "Thickness of the tubes"
          annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.ThermalConductivity kSoi
          "Thermal conductivity of the soil used for the calculation of the internal interference resistance";

        parameter Modelica.SIunits.Temperature TFil_start=283.15
          "Initial temperature of the filling material"
          annotation (Dialog(group="Filling material"));

        parameter Modelica.SIunits.Radius rBor "Radius of the borehole";
        parameter Modelica.SIunits.Height hSeg "Height of the element";

        parameter Real B0=17.44268 "Shape coefficient for grout resistance";
        parameter Real B1=-0.60515 "Shape coefficient for grout resistance";

        parameter Modelica.SIunits.Length xC=0.05
          "Shank spacing definied as half the center-to-center distance between the two pipes";

        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port
          "Heat port that connects to filling material"
          annotation (Placement(transformation(extent={{90,-10},{110,10}})));
      protected
        final parameter Modelica.SIunits.SpecificHeatCapacity cpFil=matFil.c
          "Specific heat capacity of the filling material";
        final parameter Modelica.SIunits.ThermalConductivity kFil=matFil.k
          "Thermal conductivity of the filling material";
        final parameter Modelica.SIunits.Density dFil=matFil.d
          "Density of the filling material";
        parameter Modelica.SIunits.HeatCapacity Co_fil=0.5*dFil*cpFil*hSeg*Modelica.Constants.pi
            *(rBor^2 - 2*(rTub + eTub)^2)
          "Heat capacity of the filling material";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor cap2(C=Co_fil, T(start=
               TFil_start)) "Heat capacity of the filling material" annotation (
            Placement(transformation(
              extent={{-90,-36},{-70,-16}},
              rotation=-90,
              origin={76,-140})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor cap1(C=Co_fil,T(start=
                TFil_start)) "Heat capacity of the filling material" annotation (
            Placement(transformation(
              extent={{-102,14},{-82,34}},
              rotation=0,
              origin={12,26})));
        BoreholeResistance con1(
          redeclare final package Medium = Medium,
          final rBor=rBor,
          final rTub=rTub,
          final eTub=eTub,
          final kTub=kTub,
          final kFil=kFil,
          final hSeg=hSeg,
          final B0=B0,
          final B1=B1,
          final m_flow_nominal=m1_flow_nominal,
          homotopyInitialization=homotopyInitialization)
          "Thermal resistance from the fluid to the wall of the borehole"
          annotation (Placement(transformation(extent={{-20,10},{0,30}})));
        BoreholeResistance con2(
          redeclare final package Medium = Medium,
          final rBor=rBor,
          final rTub=rTub,
          final eTub=eTub,
          final kTub=kTub,
          final kFil=kFil,
          final hSeg=hSeg,
          final B0=B0,
          final B1=B1,
          final m_flow_nominal=m1_flow_nominal,
          homotopyInitialization=homotopyInitialization)
          "Thermal resistance from the fluid to the wall of the borehole"
          annotation (Placement(transformation(extent={{-20,-30},{0,-10}})));

        InterferenceResistance con12(
          redeclare final package Medium = Medium,
          final rBor=rBor,
          final rTub=rTub,
          final eTub=eTub,
          final kTub=kTub,
          final kFil=kFil,
          final kSoi=kSoi,
          final hSeg=hSeg,
          final xC=xC,
          final B0=B0,
          final B1=B1,
          final m_flow_nominal=m1_flow_nominal,
          homotopyInitialization=homotopyInitialization)
          "Interference resistance between the two pipes" annotation (Placement(
              transformation(
              extent={{-74,-12},{-54,8}},
              rotation=-90,
              origin={-78,-74})));

        Modelica.Blocks.Sources.RealExpression m_flow(y=port_a1.m_flow)
          "Mass flow rate"
          annotation (Placement(transformation(extent={{-74,20},{-54,40}})));
      equation
        connect(vol1.heatPort, cap1.port) annotation (Line(
            points={{-10,60},{-60,60},{-60,40},{-80,40}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(vol2.heatPort, cap2.port) annotation (Line(
            points={{12,-60},{40,-60}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(cap1.port, con12.port_a) annotation (Line(
            points={{-80,40},{-80,5.55112e-016}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(cap1.port, con1.port_a) annotation (Line(
            points={{-80,40},{-80,20},{-20,20}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(con12.port_b, cap2.port) annotation (Line(
            points={{-80,-20},{-80,-40},{40,-40},{40,-60}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(con2.port_a, cap2.port) annotation (Line(
            points={{-20,-20},{-40,-20},{-40,-40},{40,-40},{40,-60}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(con1.port_b, port)   annotation (Line(
            points={{5.55112e-16,20},{60,20},{60,5.55112e-16},{100,5.55112e-16}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(con2.port_b, port)   annotation (Line(
            points={{5.55112e-16,-20},{60,-20},{60,5.55112e-16},{100,5.55112e-16}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(m_flow.y, con1.m_flow) annotation (Line(
            points={{-53,30},{-40,30},{-40,26},{-22,26}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(m_flow.y, con2.m_flow) annotation (Line(
            points={{-53,30},{-40,30},{-40,-14},{-22,-14}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(m_flow.y, con12.m_flow) annotation (Line(
            points={{-53,30},{-40,30},{-40,12},{-74,12},{-74,2}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Icon(graphics={Rectangle(
                extent={{88,54},{-88,64}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid), Rectangle(
                extent={{88,-66},{-88,-56}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid)}),
          Documentation(info="<html>
<p>
Model for the heat transfer between the fluid and within the borehole filling.
This model computes the dynamic response of the fluid in the tubes, and the heat transfer between the
fluid and the borehole filling, and the heat storage within the fluid and the borehole filling.
</p>
<p>
The heat conduction in the filling material is modeled using three three resistances model that are
arranged in a triangular configuration. 
Two of these resistances represent the heat conduction from the fluids to the external radius of
the borehole, and the other resistance represents the thermal interference between the two pipes.
</p>
<p>
The resistance between the fluid and the borehole wall are the sum of the 
convective resistance inside the tubes, the conductive resistance
of the tube wall and the conductive resistance of the filling material. 
They are obtained using
</p>
 <p align=\"center\" style=\"font-style:italic;\">
 G<sub>Con</sub> = 2 &pi; h<sub>seg</sub> r<sub>tub</sub> h<sub>in</sub> , 
 </p>
<p align=\"center\" style=\"font-style:italic;\">
G<sub>tub</sub> = 4 &pi; k<sub>tub</sub> h<sub>seg</sub> &frasl; ln( ( r<sub>tub</sub>+e<sub>tub</sub> ) &frasl; r<sub>tub</sub> ),
</p>
<p align=\"center\" style=\"font-style:italic;\">
G<sub>fil</sub>= k<sub>fil</sub> h<sub>seg</sub> &beta;<sub>0</sub> ( r<sub>Bor</sub> &frasl; r<sub>tub</sub> ) <sup>&beta;<sub>1</sub></sup> ,
</p>
<p> 
where <i>h<sub>seg</sub></i> is the height of the tube, 
<i>h<sub>in</sub></i> is the convection coefficient,
<i>k<sub>tub</sub></i> is the thermal conductivity of the tube, 
<i>e<sub>tub</sub></i> is the thickness of the tube,
and <i>&beta;<sub>0</sub>, &beta;<sub>1</sub></i> are the resistance shape factor coefficients
(Paul, 1996).
Paul's shape factors are based on experimental and finite element analysis of typical borehole.
The default values used for these coefficients are &beta;<sub>0</sub>= 20.100 and &beta;<sub>1</sub>=-0.94467.
Values listed by Paul are given in the table below.
</p>
  <table summary=\"summary\">
  <tr><th>pipe spacing</th><th><i>&beta;<sub>0</sub></i></th><th><i>&beta;<sub>1</sub></i></th></tr>
  <tr><td> close  </td><td> 20.100377 </td><td> -0.94467 </td></tr>
  <tr><td> middle  </td><td> 17.44 </td><td> -0.6052  </td></tr>
  <tr><td> spaced </td><td> 21.91 </td><td> -0.3796 </td></tr>
  </table>
<h4>Implementation</h4>
<p>
The resistances between the fluid and the borehole wall are computed in
 <a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.BoreholeResistance\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.BoreholeResistance</a>.
The resistance for the interference of the pipes is computed in
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.InterferenceResistance\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.InterferenceResistance</a>. 
</p>
</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"),Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}), graphics));
      end HexInternalElement;

      model BoreholeResistance "Thermal resistance of the borehole"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.PartialBoreholeResistance;

      equation
        if homotopyInitialization then
          Rb = homotopy(actual=
            CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.boreholeThermalResistance(
                  hSeg=hSeg,
                  rBor=rBor,
                  rTub=rTub,
                  eTub=eTub,
                  kTub=kTub,
                  kFil=kFil,
                  kMed=kMed,
                  mueMed=mueMed,
                  cpFluid=cpFluid,
                  m_flow=m_flow,
                  m_flow_nominal=m_flow_nominal,
                  B0=B0,
                  B1=B1), simplified=
            CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.boreholeThermalResistance(
                  hSeg=hSeg,
                  rBor=rBor,
                  rTub=rTub,
                  eTub=eTub,
                  kTub=kTub,
                  kFil=kFil,
                  kMed=kMed,
                  mueMed=mueMed,
                  cpFluid=cpFluid,
                  m_flow=m_flow_nominal,
                  m_flow_nominal=m_flow_nominal,
                  B0=B0,
                  B1=B1));
        else
          Rb =
            CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.boreholeThermalResistance(
                  hSeg=hSeg,
                  rBor=rBor,
                  rTub=rTub,
                  eTub=eTub,
                  kTub=kTub,
                  kFil=kFil,
                  kMed=kMed,
                  mueMed=mueMed,
                  cpFluid=cpFluid,
                  m_flow=m_flow,
                  m_flow_nominal=m_flow_nominal,
                  B0=B0,
                  B1=B1);
        end if;
        G = 1/(2*Rb);
        annotation (
          Documentation(info="<html>
<p>
This model computes the total thermal resistance from the fluid to the borehole wall. 
This thermal resistance is then used for a three-resistance model.
It assumes that the pipe configuration is symmetric. 
The resistance is obtain using
</p>
<p align=\"center\" style=\"font-style:italic;\">
 R = 2 R<sub>b</sub>,
</p>
<p>
where <i>R<sub>b</sub></i> is the total borehole resistance as defined by Hellstrom (1991). 
</p>
<p>
The resistance <i>R<sub>b</sub></i> includes three different thermal resistances:
</p>
<ol>
<li>
a convective resistance from the brine to the pipe wall,
</li>
<li>
a thermal resistance of the pipe wall, and
</li>
<li>
the thermal resistance of the filling material.
</li>
</ol>
<h4>Implementation</h4>
<p>
The calculation of <i>R<sub>b</sub></i> is done using the function
<a href=\"modelica://Buildings.Fluid.Boreholes.BaseClasses.boreholeThermalResistance\">
Buildings.Fluid.Boreholes.BaseClasses.boreholeThermalResistance</a>.
</p>
<h4>References</h4>
<p>
Hellstrom, G (1991). <br/>
 <a href=\"http://intraweb.stockton.edu/eyos/energy_studies/content/docs/proceedings/HELLS.PDF\">
 Thermal Performance of Borehole Heat Exchangers</a>.<br/> 
Department of Mathematical Physics, Lund Institute of Technology.
</p>
</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end BoreholeResistance;

      model InterferenceResistance
        "Total interference resistance between the two pipes of a borehole"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.PartialBoreholeResistance;

        parameter Modelica.SIunits.Length xC
          "Shank spacing definied as half the center-to-center distance between the two pipes";

        parameter Modelica.SIunits.ThermalConductivity kSoi
          "Thermal conductivity of the soil used for the calculation of the internal interference resistance";

      protected
        parameter Modelica.SIunits.ThermalResistance Ra=boreholeInternalResistance(
            hSeg=hSeg,
            rBor=rBor,
            rTub=rTub,
            eTub=eTub,
            xC=xC,
            kFil=kFil,
            kSoi=kSoi) "Borehole internal resistance";

      equation
        if homotopyInitialization then
          Rb = homotopy(actual=boreholeThermalResistance(
                  hSeg=hSeg, rBor=rBor, rTub=rTub, eTub=eTub, kTub=kTub,
                  kFil=kFil, kMed=kMed, mueMed=mueMed, cpFluid=cpFluid, m_flow=m_flow,
                  m_flow_nominal=m_flow_nominal, B0=B0, B1=B1),
               simplified=boreholeThermalResistance(
                  hSeg=hSeg, rBor=rBor, rTub=rTub, eTub=eTub, kTub=kTub,
                  kFil=kFil, kMed=kMed, mueMed=mueMed, cpFluid=cpFluid, m_flow=m_flow_nominal,
                  m_flow_nominal=m_flow_nominal, B0=B0, B1=B1));
        else
         Rb = boreholeThermalResistance(
          hSeg=hSeg, rBor=rBor, rTub=rTub, eTub=eTub, kTub=kTub,
          kFil=kFil, kMed=kMed, mueMed=mueMed, cpFluid=cpFluid, m_flow=m_flow,
          m_flow_nominal=m_flow_nominal, B0=B0, B1=B1);
        end if;
        G = (4*Rb - Ra)/(4*Rb*Ra);
        annotation (
          Documentation(info="<html>
<p>
This model computes the interference resistance between the two pipes of a U-tube borehole. 
It computes the resistance using the 
internal resistance <i>R<sub>a</sub></i> and
the borehole total resistance <i>R<sub>b</sub></i>.
</p>
<p>
The coupling resistance is obtained using
</p>
<p align=\"center\" style=\"font-style:italic;\">
  R<sub>i</sub> = 4 R<sub>b</sub> R<sub>a</sub> &frasl; (4 R<sub>b</sub>- R<sub>a</sub>).
</p>
<h4>Implementation</h4>
<p>
The two resistances are calculated by the functions 
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.boreholeThermalResistance\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.boreholeThermalResistance</a> for <i>R<sub>b</sub></i> 
 and 
 <a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.boreholeInternalResistance\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.boreholeInternalResistance</a> for <i>R<sub>a</sub></i>.
</p>
</html>",       revisions="<html>
<ul>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end InterferenceResistance;

      partial model PartialBoreholeResistance
        "Partial model for thermal resistance of the borehole"
        replaceable package Medium = Modelica.Media.Interfaces.PartialMedium
          "Medium in the component" annotation (choicesAllMatching=true);
        parameter Modelica.SIunits.Radius rTub "Radius of the tubes"
          annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.ThermalConductivity kTub=4
          "Thermal conductivity of the tubes" annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.Length eTub=0.002 "Thickness of the tubes"
          annotation (Dialog(group="Pipes"));
        parameter Modelica.SIunits.Radius rBor "Radius of the borehole";
        parameter Modelica.SIunits.ThermalConductivity kFil;
        parameter Modelica.SIunits.Height hSeg "Height of the segment";
        parameter Real B0=17.44268 "Shape coefficient for grout resistance";
        parameter Real B1=-0.60515 "Shape coefficient for grout resistance";
        parameter Modelica.SIunits.MassFlowRate m_flow_nominal
          "Nominal mass flow rate" annotation (Dialog(group="Nominal condition"));

        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));

        Modelica.Blocks.Interfaces.RealInput m_flow(unit="kg/s")
          "Mass flow rate"
          annotation (Placement(transformation(extent={{-140,40},{-100,80}}),
              iconTransformation(extent={{-140,40},{-100,80}})));

        Modelica.SIunits.ThermalConductance G "Thermal conductance";
        Modelica.SIunits.HeatFlowRate Q_flow
          "Heat flow rate from port_a to port_b";
        Modelica.SIunits.TemperatureDifference dT "= port_a.T - port_b.T";
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
            Placement(transformation(extent={{-110,-10},{-90,10}}, rotation=0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
            Placement(transformation(extent={{90,-10},{110,10}}, rotation=0)));

      protected
        parameter Modelica.SIunits.SpecificHeatCapacity cpFluid=
            Medium.specificHeatCapacityCp(Medium.setState_pTX(
            Medium.p_default,
            Medium.T_default,
            Medium.X_default)) "Specific heat capacity of the fluid";
        parameter Modelica.SIunits.ThermalConductivity kMed=
            Medium.thermalConductivity(Medium.setState_pTX(
            Medium.p_default,
            Medium.T_default,
            Medium.X_default)) "Thermal conductivity of the fluid";
        parameter Modelica.SIunits.DynamicViscosity mueMed=Medium.dynamicViscosity(
            Medium.setState_pTX(
            Medium.p_default,
            Medium.T_default,
            Medium.X_default)) "Dynamic viscosity of the fluid";
        Modelica.SIunits.ThermalResistance Rb "Borehole thermal resistance";
      equation
        dT = port_a.T - port_b.T;
        port_a.Q_flow = Q_flow;
        port_b.Q_flow = -Q_flow;
        Q_flow = G*dT;
        annotation (
          Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
                  100}}), graphics={
              Rectangle(
                extent={{-90,70},{90,-70}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillColor={192,192,192},
                fillPattern=FillPattern.Backward),
              Line(
                points={{-90,70},{-90,-70}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{90,70},{90,-70}},
                color={0,0,0},
                thickness=0.5),
              Text(
                extent={{-150,115},{150,75}},
                textString="%name",
                lineColor={0,0,255})}),
          Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
                  100}}), graphics={
              Line(
                points={{-80,0},{80,0}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Text(
                extent={{-26,-10},{27,-39}},
                lineColor={255,0,0},
                textString="Q_flow"),
              Text(
                extent={{-80,50},{80,20}},
                lineColor={0,0,0},
                textString="dT = port_a.T - port_b.T")}),
          Documentation(info="<html>
<p>
Partial model for the thermal resistance of the borehole.
</p>
</html>",       revisions="<html>
<ul>
<li>
September 9 2011, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end PartialBoreholeResistance;

      model SingleUTubeBoundaryCondition
        "Prescribed temperature at the outer boundary of a single U tube borehole"
        replaceable parameter Buildings.HeatTransfer.Data.Soil.Generic matSoi
          "Thermal properties of the soil"
           annotation (choicesAllMatching=true);
        parameter Modelica.SIunits.Radius rExt=3
          "Distance from the brine where the calculation is performed";
        parameter Modelica.SIunits.Height hSeg=10 "Height of the segment";
        parameter Modelica.SIunits.Temperature TExt_start=283.15
          "Initial external temperature";
        parameter Modelica.SIunits.Time samplePeriod=604800
          "Period between two samples";
        ExtendableArray table=ExtendableArray()
          "Extentable array, used to store history of rate of heat flows";
        Modelica.SIunits.HeatFlowRate QAve_flow
          "Average heat flux over a time period";
        Modelica.Blocks.Interfaces.RealInput Q_flow(unit="W")
          "Heat flow rate at the center of the borehole, positive if heat is added to soil"
           annotation (Placement(transformation(extent={{-120,-100},{-80,-60}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port "Heat port"
          annotation (Placement(transformation(extent={{86,-10},
                  {106,10}},      rotation=0), iconTransformation(extent={{86,-10},
                  {106,10}})));
      protected
        final parameter Modelica.SIunits.SpecificHeatCapacity c= matSoi.c
          "Specific heat capacity of the soil";
        final parameter Modelica.SIunits.ThermalConductivity k= matSoi.k
          "Thermal conductivity of the soil";
        final parameter Modelica.SIunits.Density d = matSoi.d
          "Density of the soil";
        Modelica.SIunits.Energy UOld "Internal energy at the previous period";
        Modelica.SIunits.Energy U
          "Current internal energy, defined as U=0 for t=tStart";
        final parameter Modelica.SIunits.Time startTime(fixed=false)
          "Start time of the simulation";
        Integer iSam(min=1)
          "Counter for how many time the model was sampled. Defined as iSam=1 when called at t=0";
      initial algorithm
        U         := 0;
        UOld      := 0;
        startTime := time;
        iSam      := 1;
      equation
        der(U) = Q_flow;
      algorithm
        when initial() or sample(startTime,samplePeriod) then
          QAve_flow := (U-UOld)/samplePeriod;
          UOld      := U;
          port.T := TExt_start +
            CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.temperatureDrop(
                  table=table,
                  iSam=iSam,
                  Q_flow=QAve_flow,
                  samplePeriod=samplePeriod,
                  rExt=rExt,
                  hSeg=hSeg,
                  k=k,
                  d=d,
                  c=c);
          iSam := iSam+1;
        end when;

      annotation (
          Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={
              Rectangle(
                extent={{-100,100},{100,-100}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillColor={159,159,223},
                fillPattern=FillPattern.Backward),
              Line(
                points={{-102,0},{64,0}},
                color={191,0,0},
                thickness=0.5),
              Text(
                extent={{0,0},{-100,-100}},
                lineColor={0,0,0},
                textString="K"),
              Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255}),
              Polygon(
                points={{40,-18},{40,22},{80,2},{40,-18}},
                lineColor={191,0,0},
                fillColor={191,0,0},
                fillPattern=FillPattern.Solid)}),
                Documentation(info="<html>
<p>
This model computes the temperature boundary condition at the outer boundary of the borehole.
It takes as an input the heat flow rate at the center of the borehole.
This heat flow rate is averaged over the sample period.
At each sampling interval, typically every one week, a new temperature boundary conditions is computed using
the analytical solution to a line source heat transfer problem.
</p>
<h4>Implementation</h4>
<p>
The computation of the temperature change of the boundary is computed using the function
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.temperatureDrop\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.temperatureDrop</a>.
</p>
</html>",
      revisions="<html>
<ul>
<li>
September 27, 2013, by Michael Wetter:<br/>
Moved assignment of <code>startTime</code> to <code>initial algorithm</code> section
to avoid an error in OpenModelica.
</li>
<li>
November 3 2011, by Michael Wetter:<br/>
Moved <code>der(U) := Q_flow;</code> from the algorithm section to the equation section
as this assignment does not conform to the Modelica specification.
</li>
<li>
September 9 2011, by Michael Wetter:<br/>
Moved <code>equation</code> section into <code>algorithm</code> section to make sure that the equations
in the <code>when</code> block are ordered correctly.
</li>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end SingleUTubeBoundaryCondition;

      class ExtendableArray
        "class used to create the external object: ExtendableArray"
      extends ExternalObject;
          function constructor
          "Construct an extendable array that can be used to store double values"
          output ExtendableArray table;
          external "C" table = initArray()
          annotation(Include="#include <initArray.c>",
          IncludeDirectory=
                "modelica://CO2GCHPModels_Master_Monjur/Resources/C-Sources");
          annotation(Documentation(info="<html>
<p>
The function <code>constructor</code> is a C function that is called by a Modelica simulator
exactly once during the initialization.
The function returns the object <code>ExtendableArray</code> that
will be used to store double values in the function
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.storeValues\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.storeValues</a>.
</p>
<h4>Implementation</h4>
<p>
This function has been implemented to allow storing an increasing number of
double values. Since Modelica requires the size of an array to be known at
compile time, the implementation is done in a C function.
</p>
</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
          end constructor;

        function destructor
          "Release storage of table and close the external object"
          input ExtendableArray  table;
          external "C" freeArray(table)
          annotation(Include=" #include <freeArray.c>",
          IncludeDirectory=
                "modelica://CO2GCHPModels_Master_Monjur/Resources/C-Sources");
        annotation(Documentation(info="<html>
<p>
Destructor that frees the memory of the object
<code>ExtendableArray</code>.
</p>
</html>",       revisions="<html>
<ul>
<li>
December 5, 2011, by Michael Wetter:<br/>
Fixed bug in <code>freeArray.c</code>, which called <code>free(table->n)</code>,
where <code>n</code> is an <code>int</code>. This caused Dymola 2012-FD01 to hang.
</li>
<li>
July 27, 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
        end destructor;
      annotation(Documentation(info="<html>
<p>
Class derived from <code>ExternalObject</code> having two local external function definition, 
named <code>destructor</code> and <code>constructor</code> respectively.
<p>
These functions create and release an external object that allows the the storage 
of real parameters in an array of extendable dimension.

</html>",
      revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end ExtendableArray;

      function boreholeInternalResistance
        "Calculate the internal resistance of the borehole"
        input Modelica.SIunits.Height hSeg "Height of the element";
        input Modelica.SIunits.Radius rBor "Radius of the borehole";
        input Modelica.SIunits.Radius rTub "Radius of the tube";
        input Modelica.SIunits.Length eTub "Thickness of the tubes";
        input Modelica.SIunits.Length xC
          "Shank spacing, defined as half the center-to-center distance between the two pipes";
        input Modelica.SIunits.ThermalConductivity kFil
          "Thermal conductivity of the filling material";
        input Modelica.SIunits.ThermalConductivity kSoi
          "Thermal conductivity of the soil";
        output Modelica.SIunits.ThermalResistance R
          "Internal resistance of the borehole";
      protected
        final parameter Real P1=rBor/(rTub + eTub)
          "Non-dimensional geometrical parameter ";
        final parameter Real P2=rBor/xC
          "Non-dimensional geometrical parameter ";
        final parameter Real P3=(kFil - kSoi)/(kFil + kSoi)
          "Non-dimensional parameter for filling and soil conductivity";
      algorithm
        assert(xC > (rTub + eTub) and xC < rBor - (rTub + eTub),
        "Parameters do not correspond to physically possible location of borehole tube.
    xC   = "       + String(xC) + "
    rTub = "       + String(rTub) + "
    eTub = "       + String(eTub) + ".");
        R := Modelica.Math.log((2*P1*(P2^2 + 1)^P3)/(P2*(P2^2 - 1)^P3))/
                 (Modelica.Constants.pi*kFil*hSeg);
        annotation (Documentation(info="<html>
<p>
This model computes the internal resistance <i>R</i> of a single U-tube borehole, 
as defined by Hellstrom (1991), as 
</p>
<p align=\"center\" style=\"font-style:italic;\">
 k = ( 2 P<sub>1</sub> ( P<sub>2</sub><sup>2</sup> + 1 ) <sup>W</sup> ) / ( P<sub>2</sub> ( P<sub>2</sub><sup>2</sup> - 1 )<sup>W</sup> ),
</p>
<p align=\"center\" style=\"font-style:italic;\">
 R = ln(k) / (&pi; k<sub>fil</sub> h<sub>seg</sub>) ,
 </p>
where <i>P<sub>1</sub> </i> and <i>P<sub>2</sub></i> are two dimensionless geometrical factors and
<i>W</i> is a conductivity ratio.
The geometrical factors are defined as
<i>P<sub>1</sub> = r<sub>bor</sub>/(r<sub>tub</sub> + e<sub>tub</sub>)</i>, 
where <i>r<sub>bor</sub></i> is the borehole radius and  <i>r<sub>tub</sub> + e<sub>tub</sub> </i> is
the external radius of a pipe and
<i>P<sub>2</sub> = r<sub>bor</sub>/ x<sub>c</sub> </i>, where
<i>x<sub>c</sub></i> is the shank spacing defined as half the center-to-center distance 
between the two pipes, and
<i>W = k<sub>fil</sub> - k<sub>soi</sub>/ (k<sub>soi</sub> + k<sub>fil</sub>)</i>.
<br/>
<h4>References</h4>

Hellstrom, G (1991). <br/>
 <a href=\"http://intraweb.stockton.edu/eyos/energy_studies/content/docs/proceedings/HELLS.PDF\">
 Thermal Performance of Borehole Heat Exchangers</a>.<br/> 
Department of Mathematical Physics, Lund Institute of Technology.

</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end boreholeInternalResistance;

      function boreholeThermalResistance
        "Calculate the total thermal resistance of the borehole from the fluid to the soil"
        input Modelica.SIunits.Height hSeg "Height of the element";
        input Modelica.SIunits.Radius rBor "Radius of the borehole";
        input Modelica.SIunits.Radius rTub "Radius of the tube";
        input Modelica.SIunits.Length eTub "Thickness of the tubes";
        input Modelica.SIunits.ThermalConductivity kTub
          "Thermal conductivity of the tubes";
        input Modelica.SIunits.ThermalConductivity kFil
          "Thermal conductivity of the filling material";
        input Modelica.SIunits.ThermalConductivity kMed
          "Thermal conductivity of the fluid";
        input Modelica.SIunits.DynamicViscosity mueMed
          "Dynamic viscosity of the fluid";
        input Modelica.SIunits.SpecificHeatCapacity cpFluid
          "Specific heat capacity of the fluid";
        input Modelica.SIunits.MassFlowRate m_flow
          "Mass flow rate of the fluid";
        input Modelica.SIunits.MassFlowRate m_flow_nominal
          "Nominal mass flow rate";
        input Real B0 "Shape coefficient for grout resistance";
        input Real B1 "Shape coefficient for grout resistance";
        output Modelica.SIunits.ThermalResistance Rb
          "Borehole thermal resistance";
      protected
        Modelica.SIunits.CoefficientOfHeatTransfer h
          "Convective heat transfer coefficient of the fluid";
        Modelica.SIunits.ThermalResistance RCon
          "Convective thermal resistance of the fluid";
        Modelica.SIunits.ThermalResistance RTub
          "Thermal resistance of the pipe's wall";
        Modelica.SIunits.ThermalResistance RFil
          "Thermal resistance of the filling material";
        Real k(unit="s/kg")
          "Coefficient used in the computation of the convective heat transfer coefficient";
      algorithm
        k :=2/(mueMed*Modelica.Constants.pi*rTub);
        h := 0.023*kMed*(cpFluid*mueMed/kMed)^(0.35)/(2*rTub) *
          Buildings.Utilities.Math.Functions.regNonZeroPower(
          x=m_flow*k, n=0.8,
          delta=0.01*m_flow_nominal*k);
        RCon := 1/(4*Modelica.Constants.pi*rTub*hSeg*h);
        RTub := Modelica.Math.log((rTub + eTub)/rTub)/(4*Modelica.Constants.pi*hSeg*kTub);
        RFil := 1/(hSeg*kFil*B0*(rBor/(rTub + eTub))^B1);
        Rb := RCon + RTub + RFil;
        annotation (Diagram(graphics), Documentation(info="<html>
<p>
This model computes the borehole total thermal resistance for a single U-tube.
The computation is as defined in Hellstom (1991).
The total thermal resistance is the contribution of three different resistances as
</p>
<p align=\"center\" style=\"font-style:italic;\">
 R<sub>tot</sub>= R<sub>Con</sub> + R<sub>tub</sub> + R<sub>fil</sub>.
</p>
<p>
where 
<i>R<sub>Con</sub></i> is the convective resistance of the fluid, 
<i>R<sub>tub</sub></i> is the conductive resistance of the tube wall and 
<i>R<sub>fil</sub></i> is the resistance of the filling material.
</p>
<p>
The convective resistance is obtained as</p>
<p align=\"center\" style=\"font-style:italic;\">
 R<sub>Con</sub> = 1 &frasl; (4 &pi; h<sub>seg</sub> r<sub>tub</sub> h<sub>in</sub>),
</p>
<p>
where <i>h<sub>seg</sub></i> is the height of the segment and 
<i>h<sub>in</sub></i> is the convective heat transfer coefficient. 
The convective heat transfer coefficient is determined using the 
Dittus-Boelter correlation,
</p>
<p align=\"center\" style=\"font-style:italic;\">
 h<sub>in</sub>= 0.023 k<sub>med</sub> Pr<sup>0.35</sup> Re<sup>0.8</sup> &frasl; 2 r<sub>tub</sub>,
</p>
<p>
where <i>k<sub>med</sub></i> is the thermal conductivity of the fluid, 
<i>Pr</i> is the Prandtl number, 
<i>Re</i> is the Reynolds number and 
<i>r<sub>tub</sub></i> is the inside radius of the pipe.
</p>

<p>
The conductive resistance is determined using</p>
<p align=\"center\" style=\"font-style:italic;\">
R<sub>tub</sub>= ln[ ( r<sub>tub</sub>+e<sub>tub</sub> ) &frasl; r<sub>tub</sub> ] &frasl; 4 &pi; 
   k<sub>tub</sub> h<sub>seg</sub>,
</p>
<p>
where <i>k<sub>tub</sub></i> the heat conductivity of the pipe and 
<i>e<sub>tub</sub></i> is the thickness of the wall.
</p>

<p>
The resistance of the filling material is determined using the correlation from Paul (1996) :</p>
<p align=\"center\" style=\"font-style:italic;\">
R<sub>fil</sub> = k<sub>fil</sub> h<sub>seg</sub> &beta;<sub>0</sub> 
  (r<sub>Bor</sub> &frasl; (r<sub>tub</sub> + e<sub>tub</sub>)) <sup>&beta;<sub>1</sub></sup> ,
</p>
<p>
where <i>k<sub>fil</sub></i> is the thermal conductivity of the filling material and 
<i>&beta;<sub>0</sub>, &beta;<sub>1</sub></i> are the resistance shape factors
(Paul 1996) based on U-tube shank spacing.
Paul's shape factors are based on experimental and finite element analysis of typical borehole.
The default values used for these coefficients are &beta;<sub>0</sub>= 20.100 and &beta;<sub>1</sub>=-0.94467.
Values listed by Paul are given in the table below.</p>

  <table summary=\"summary\" >
  <tr><th>pipe spacing</th><th><i>&beta;<sub>0</sub></i></th><th><i>&beta;<sub>1</sub></i></th></tr>
  <tr><td> close  </td><td> 20.100377 </td><td> -0.94467 </td></tr>
  <tr><td> middle  </td><td> 17.44 </td><td> -0.6052  </td></tr>
  <tr><td> spaced </td><td> 21.91 </td><td> -0.3796 </td></tr>
  </table>

<h4>References</h4>
<p>
Hellstrom, G (1991). <br/>
 <a href=\"http://intraweb.stockton.edu/eyos/energy_studies/content/docs/proceedings/HELLS.PDF\">
 Thermal Performance of Borehole Heat Exchangers</a>.<br/> 
Department of Mathematical Physics, Lund Institute of Technology.
</p>
<p>
Paul, N.D (1996). <i>The effect of grout thermal conductivity on vertical geothermal heat exchanger design
and performance.</i> 
Master of Science Thesis, South Dakota State University.
</p>
</html>",       revisions="<html>
<ul>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end boreholeThermalResistance;

      function exchangeValues
        "Store the value u at the element n in the external object, and return the value of the element i"
        input ExtendableArray table "External object";
        input Integer iX
          "One-based index where u needs to be stored in the array of the external object";
        input Real x "Value to store in the external object";
        input Integer iY
          "One-based index of the element that needs to be returned from C to Modelica";
        output Real y "Value of the i-th element";
      external"C" y = exchangeValues(table, iX, x, iY) annotation (Include="#include <exchangeValues.c>",
                         IncludeDirectory=
              "modelica://CO2GCHPModels_Master_Monjur/Resources/C-Sources");
        annotation (Documentation(info="<html>
<p>
External function that stores the input value <code>x</code> as the element
<code>a[iX]</code> in the array 
<code>a = [a[1], a[2], ...]</code>,
and that returns the element <code>a[iY]</code>.
The size of the array <code>a</code> is automatically enlarged as needed.
</p>
</html>",       revisions="<html>
<ul><li>
September 9, 2011, by Michael Wetter:<br/>
Revised implementation.
</li>
<li>
July 27, 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end exchangeValues;

      function factorial "Calculates the factorial value of the input"
        input Integer j;
        output Integer f;
      algorithm
        f := 1;
        for i in 1:j loop
          f := f*i;
        end for;
      annotation (Documentation(info="<html>
<p>
This function computes <i>y = j!</i>.
</p>
</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end factorial;

      function powerSeries "Power series used to compute far-field temperature"
        input Real u "u";
        input Integer N "Number of coefficients";
        output Real W "Power series";
      algorithm
        W := -0.5772 - Modelica.Math.log(u) + sum((-1)^(j + 1)*u^j/(j*factorial(j))
          for j in 1:N);
        annotation (Diagram(graphics), Documentation(info="<html>
          <p>
This function computes the power series that is used to compute the far-field 
temperature.
</p>
</html>",       revisions="<html>
<ul>
<li>
July 28 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end powerSeries;

      function temperatureDrop
        "Calculate the temperature drop of the soil at the external boundary of the cylinder"
      input ExtendableArray table
          "External object that contains the history terms of the heat flux";
      input Integer iSam(min=1)
          "Counter for how many time the model was sampled. Defined as iSam=1 when called at t=0";

      input Modelica.SIunits.HeatFlowRate Q_flow
          "Heat flow rate to be stored in the external object";
      input Modelica.SIunits.Time samplePeriod "Period between two samples";
      input Modelica.SIunits.Radius rExt "External radius of the cylinder";
      input Modelica.SIunits.Height hSeg "Height of the cylinder";
      input Modelica.SIunits.ThermalConductivity k
          "Thermal conductivity of the soil";
      input Modelica.SIunits.Density d "Density of the soil";
      input Modelica.SIunits.SpecificHeatCapacity c
          "Specific heat capacity of the soil";
      output Modelica.SIunits.TemperatureDifference dT
          "Temperature drop of the soil";
      protected
       Modelica.SIunits.Time minSamplePeriod= rExt^2/(4*(k/c/d)*3.8)
          "Minimal lenght of the sampling period";
       Modelica.SIunits.HeatFlowRate QL_flow
          "Intermediate variable for heat flow rate at the lower bound of the time interval";
       Modelica.SIunits.HeatFlowRate QU_flow
          "Intermediate variable for heat flow rate at the upper bound of the time interval";

      algorithm
        assert(rExt*rExt/(4*(k/c/d)*samplePeriod)<=3.8,
        "The samplePeriod has to be bigger than " + String(minSamplePeriod) + " for convergence purpose.
  samplePeriod = "      + String(samplePeriod));
        if iSam == 1 then
          // First call, at t=0
          dT := 0;
          QL_flow :=
            CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                  table=table,
                  iX=iSam,
                  x=Q_flow,
                  iY=iSam);
        else
          dT := 0;
          // The first evaluation is at iSam=2, in which case we have one term of the sum,
          // and t=samplePeriod=(iSam-1)*samplePeriod
         for i in 1:(iSam-1) loop
            QL_flow :=
              CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=iSam,
                    x=Q_flow,
                    iY=iSam + 1 - i);
            QU_flow :=
              CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=iSam,
                    x=Q_flow,
                    iY=iSam - i);
            // The division by hSeg is because QU_flow and QL_flow are in [W], but the equation
            // requires [W/m], i.e., heat flow rate per unit length of the line source.
            dT := dT + 1/(4*Modelica.Constants.pi*k)*
              CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.powerSeries(u=c
              *d/(4*k*i*samplePeriod)*rExt^2, N=10)*(QL_flow - QU_flow)/hSeg;
       end for;
        end if;
      annotation(Documentation(info="<html>
<p>
This function calculates the temperature drop of the soil at the outer boundary of the cylinder.
The analytical formula of Hart and Couvillion (1986) for constant 
heat extraction is adapted to a non-constant heat flux. 
To adapt the formula for a variable rate of heat extraction,
different constant heat extraction rates, starting at different time instances, 
are super-imposed.
To obtain the temperature drop at the time <i>t=n*&Delta;t</i>, the effects of 
constant rate of heat extractions are super-imposed as
</p>
<p align=\"center\" style=\"font-style:italic;\">
&Delta;T ( r , t=n &Delta;t )= 1 &frasl; ( 4 &pi; k ) 
  &sum;  W(u(r, t= i &Delta;t)) (q<sub>n-i+1</sub>-q<sub>n-i</sub>),
</p>
<p>
where <i>r</i> is the radius for which the temperature is computed,
<i>k</i> is the thermal conductivity of the material,
<i>W</i> is a solution of the heat conduction in polar coordinates and
<i>q<sub>i</sub>=Q<sub>i</sub>/h</i> is
the specific rate of heat extraction per unit lenght at time 
<i>t=i &Delta;t</i>.
The value of 
<i>W</i> is obtained using
</p>
<p align=\"center\" style=\"font-style:italic;\">
W(u)=[-0.5772 - ln(u) + u - u<sup>2</sup>/(2 &nbsp; 2!) +u<sup>3</sup>/(3 &nbsp; 3!) - u<sup>4</sup>/(4 &nbsp; 4!) + ....].
</p>
<p>
where
<i>u(r,t)= c &rho; r<sup>2</sup> &frasl; (4 t k) </i>,
<i>&rho;</i> is the mass density and
<i>c</i> is the specific heat capacity per unit mass.
</p>
<h4>Implementation</h4>
<p>
The rate of heat flow <i>Q<sub>i</sub></i> is obtained from the function
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.exchangeValues\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.exchangeValues</a>.
</p>
<h4>References</h4>
<p>
Hart and Couvillion, (1986). <i>Earth Coupled Heat Transfer.</i>
Publication of the National Water Well Association. 
</p>
</html>",
      revisions="<html>
<ul>
<li>
July 27, 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
      end temperatureDrop;

      package Examples "Example models to test base classes"
      extends Modelica.Icons.ExamplesPackage;
        model BoreholeSegment
          "Model that tests a basic segment that is used to built a borehole"
          extends Modelica.Icons.Example;
           inner Modelica.Fluid.System system
            annotation (Placement(transformation(extent={{-80,-80},{-60,-60}})));
         package Medium = Buildings.Media.ConstantPropertyLiquidWater;
         Buildings.HeatTransfer.Data.BoreholeFillings.Bentonite                    bento;
         CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.BoreholeSegment seg(
            redeclare package Medium = Medium,
            matFil=bento,
            m_flow_nominal=0.2,
            dp_nominal=5,
            rTub=0.02,
            eTub=0.002,
            rBor=0.1,
            rExt=3,
            B0=17.44,
            B1=-0.605,
            nSta=9,
            samplePeriod=604800,
            kTub=0.5,
            hSeg=10,
            xC=0.05,
            redeclare Buildings.HeatTransfer.Data.Soil.Concrete matSoi,
            TFil_start=283.15,
            TExt_start=283.15)
            annotation (Placement(transformation(extent={{-13,-13},{13,13}},
                rotation=270,
                origin={11,-1})));
        Buildings.Fluid.Sources.Boundary_pT sou_1(
            redeclare package Medium = Medium,
            nPorts=1,
            use_T_in=false,
            p=101340,
            T=303.15)             annotation (Placement(transformation(extent={{-60,40},
                    {-40,60}}, rotation=0)));
         Buildings.Fluid.Sources.Boundary_pT sin_2(
            redeclare package Medium = Medium,
            use_p_in=false,
            use_T_in=false,
            nPorts=1,
            p=101330,
            T=283.15)             annotation (Placement(transformation(extent={{-60,10},
                    {-40,30}},  rotation=0)));
        equation
          connect(sou_1.ports[1], seg.port_a1) annotation (Line(
              points={{-40,50},{20,50},{20,12},{18.8,12}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(seg.port_b1, seg.port_a2) annotation (Line(
              points={{18.8,-14},{14.9,-14},{14.9,-14},{11,-14},{11,-14},{3.2,-14}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(seg.port_b2, sin_2.ports[1]) annotation (Line(
              points={{3.2,12},{4,12},{4,20},{-40,20}},
              color={0,127,255},
              smooth=Smooth.None));
         annotation (
        experiment(StopTime=157680000),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/BaseClasses/Examples/BoreholeSegment.mos"
                "Simulate and plot"),
                Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                    {100,100}})),
                          Documentation(info="<html>
This example illustrates modeling a segment of a borehole heat exchanger.
It simulates the behavior of the borehole on a single horizontal section including the ground and the
boundary condition.
</html>",         revisions="<html>
<ul>
<li>
August 30, 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
        end BoreholeSegment;

        model Factorial "Test the function factorial"
         extends Modelica.Icons.Example;
          parameter Integer x[:] = {1, 2, 3, 4, 5};
          Integer y[5];
        equation
          y = CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.factorial(x);
          assert(abs(120-y[5]) < 1E-10, "Error: Factorial function yields wrong result.");
        annotation (
        experiment(StopTime=1),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/BaseClasses/Examples/Factorial.mos"
                "Simulate and plot"),
                Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                    -100},{100,100}})),
            Documentation(info="<html>
<p>
This example tests the function
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.factorial\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.factorial</a>.
</p>
</html>",         revisions="<html>
<ul>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
        end Factorial;

        model HexInternalElement
          "Model that tests the basic element that is used to built borehole models"
          extends Modelica.Icons.Example;
          inner Modelica.Fluid.System system
            annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
          package Medium = Buildings.Media.ConstantPropertyLiquidWater;
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.HexInternalElement hex(
            redeclare package Medium = Medium,
            m1_flow_nominal=0.3,
            m2_flow_nominal=0.3,
            rTub=0.02,
            kTub=0.5,
            rBor=0.1,
            xC=0.025,
            kSoi=3.1,
            B0=21.91,
            B1=-0.3796,
            dp1_nominal=5,
            dp2_nominal=5,
            hSeg=20,
            redeclare Buildings.HeatTransfer.Data.BoreholeFillings.Bentonite
              matFil,
            TFil_start=283.15)
                     annotation (Placement(transformation(extent={{10,-16},{30,4}})));
          Buildings.Fluid.Sources.Boundary_pT sou_1(
            redeclare package Medium = Medium,
            nPorts=1,
            use_T_in=false,
            p=101340,
            T=303.15) annotation (Placement(transformation(extent={{-60,-10},{-40,10}},
                  rotation=0)));
          Buildings.Fluid.Sources.Boundary_pT sin_2(
            redeclare package Medium = Medium,
            nPorts=1,
            use_p_in=false,
            use_T_in=false,
            p=101330,
            T=283.15) annotation (Placement(transformation(extent={{-60,-40},{-40,-20}},
                  rotation=0)));
        equation
          connect(sou_1.ports[1], hex.port_a1) annotation (Line(
              points={{-40,6.66134e-16},{-16,6.66134e-16},{-16,1.22125e-15},{10,
                  1.22125e-15}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hex.port_b1, hex.port_a2) annotation (Line(
              points={{30,1.22125e-15},{54,1.22125e-15},{54,-12},{30,-12}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hex.port_b2, sin_2.ports[1]) annotation (Line(
              points={{10,-12},{-16,-12},{-16,-30},{-40,-30}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation (
        experiment(StopTime=3600),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/BaseClasses/Examples/HexInternalElement.mos"
                "Simulate and plot"),
            Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
                    100}})),
            Documentation(info="<html>
This example illustrates modeling the internal part of a borehole heat exchanger.
The borehole is constitued with two pipes that are symetricaly spaced in the borehole. 
</html>",         revisions="<html>
<ul>
<li>
August 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
        end HexInternalElement;

        model SingleUTubeBoundaryCondition
          "Test model the temperature boundary condition of a single U tube heat exchanger"
          extends Modelica.Icons.Example;
          parameter Modelica.SIunits.HeatFlowRate  Q_flow=-50
            "Heat flow rate extracted at center of cylinder";
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.SingleUTubeBoundaryCondition
            TBouSte(
            final rExt=3,
            final samplePeriod=604800,
            hSeg=1,
            redeclare final Buildings.HeatTransfer.Data.Soil.Sandstone matSoi,
            TExt_start=293.15) "Boundary condition"
            annotation (Placement(transformation(extent={{-20,20},{0,40}})));
         Modelica.Blocks.Sources.Step step(
            height=Q_flow,
            offset=0,
            startTime=0)
            annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.SingleUTubeBoundaryCondition
            TBouCon(
            final rExt=3,
            final samplePeriod=604800,
            hSeg=1,
            redeclare final Buildings.HeatTransfer.Data.Soil.Sandstone matSoi,
            TExt_start=293.15) "Boundary condition"
            annotation (Placement(transformation(extent={{-20,60},{0,80}})));
         Modelica.Blocks.Sources.Constant con(k=Q_flow)
            annotation (Placement(transformation(extent={{-60,60},{-40,80}})));
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.SingleUTubeBoundaryCondition
            TBouPul(
            final rExt=3,
            final samplePeriod=604800,
            hSeg=1,
            redeclare final Buildings.HeatTransfer.Data.Soil.Sandstone matSoi,
            TExt_start=293.15) "Boundary condition"
            annotation (Placement(transformation(extent={{-20,-20},{0,0}})));
         Modelica.Blocks.Sources.Pulse pulse(
            offset=0,
            startTime=0,
            amplitude=2*Q_flow,
            period=7200)
            annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
        equation
          connect(con.y, TBouCon.Q_flow) annotation (Line(
              points={{-39,70},{-30,70},{-30,62},{-20,62}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(step.y, TBouSte.Q_flow) annotation (Line(
              points={{-39,30},{-30,30},{-30,22},{-20,22}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(pulse.y, TBouPul.Q_flow) annotation (Line(
              points={{-39,-10},{-30,-10},{-30,-18},{-20,-18}},
              color={0,0,127},
              smooth=Smooth.None));
          annotation (
        experiment(StopTime=1.5768e+08),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/BaseClasses/Examples/SingleUTubeBoundaryCondition.mos"
                "Simulate and plot"),
                Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                    100,100}}),        graphics),
            Documentation(info="<html>
This example tests the temperature boundary condition at the external part of a cylinder.

</html>",         revisions="<html>
<ul>
<li>
April 14 2011, by Pierre Vigouroux:<br/>
First implementation.
</li>
</ul>
</html>"));
        end SingleUTubeBoundaryCondition;

        model ExchangeValues
          "Test problem for the function that exchanges values"
         extends Modelica.Icons.Example;
          parameter Real x = 3;
          Real y;
          CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.ExtendableArray table=
              ExtendableArray()
            "Extentable array, used to store history of rate of heat flows";

        algorithm
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=1,
                    x=x,
                    iY=1);
          assert(abs(y-3) < 1E-10, "Error in implementation of exchangeVaules.");
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=2,
                    x=4*x,
                    iY=1);
          assert(abs(y-3) < 1E-10, "Error in implementation of exchangeVaules.");
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=2,
                    x=4*x,
                    iY=2);
          assert(abs(y-12) < 1E-10, "Error in implementation of exchangeVaules.");
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=200,
                    x=5*x,
                    iY=1);
          assert(abs(y-3) < 1E-10, "Error in implementation of exchangeVaules.");
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=10,
                    x=6*x,
                    iY=200);
          assert(abs(y-15) < 1E-10, "Error in implementation of exchangeVaules.");
          y := CO2GCHPModels_Master_Monjur.Boreholes.BaseClasses.exchangeValues(
                    table=table,
                    iX=10,
                    x=6*x,
                    iY=1);
          assert(abs(y-3) < 1E-10, "Error in implementation of exchangeVaules.");

        annotation (
        experiment(StopTime=1),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/HeatExchangers/Boreholes/BaseClasses/Examples/ExchangeValues.mos"
                "Simulate"),
                Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                    -100},{100,100}})),
            Documentation(info="<html>
<p>
This example tests the function
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.exchangeValues\">
Buildings.Fluid.HeatExchangers.Boreholes.BaseClasses.exchangeValues</a> by 
assigning and reading different elements of the array.
The assert statements check whether the returned values is correct.
</p>
</html>",         revisions="<html>
<ul>
<li>
September 10, 2011, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
        end ExchangeValues;
      end Examples;
    annotation (preferredView="info", Documentation(info="<html>
<p>
This package contains base classes that are used to construct the models in
<a href=\"modelica://Buildings.Fluid.HeatExchangers.Boreholes\">Buildings.Fluid.HeatExchangers.Boreholes</a>.
</p>
</html>"));
    end BaseClasses;

    package Interfaces "Package with interfaces for fluid models"
      extends Modelica.Icons.InterfacesPackage;

    package UsersGuide "User's Guide"
      extends Modelica.Icons.Information;
      annotation (preferredView="info",
      Documentation(info="<html>
<p>
The package <code>Buildings.Fluid.Interface</code> consists of basic
classes that can be used by developers to create new component models.
</p>
<p>
The classes whose name contains <code>TwoPort</code> or 
<code>FourPort</code> can be used for components with 
two or four fluid ports, respectively. If a class name contains
<code>Static</code>, then it can only be used for a steady-state model.
Otherwise, it may be used for a steady-state or a dynamic model.
</p>
<p>
The most basic classes are the records
<a href=\"modelica://Buildings.Fluid.Interfaces.TwoPortFlowResistanceParameters\">
Buildings.Fluid.Interfaces.TwoPortFlowResistanceParameters</a>,
<a href=\"modelica://Buildings.Fluid.Interfaces.FourPortFlowResistanceParameters\">
Buildings.Fluid.Interfaces.FourPortFlowResistanceParameters</a> and
<a href=\"modelica://Buildings.Fluid.Interfaces.LumpedVolumeDeclarations\">
Buildings.Fluid.Interfaces.LumpedVolumeDeclarations</a>.
These define parameters that are needed by many fluid flow components.
</p>

<p>
Next, we describe the basic classes. For a more detailed description,
see the <i>info</i> section of the class.
</p>
<table summary=\"summary\" border=\"1\" cellspacing=0 cellpadding=2 style=\"border-collapse:collapse;\">
<tr>
<!-- ============================================== -->
  <td><a href=\"modelica://Buildings.Fluid.Interfaces.ConservationEquation\">
      Buildings.Fluid.Interfaces.ConservationEquation</a>
  </td>
  <td><p>
      This is a basic model for an ideally mixed fluid volume.
      It implements conservation equations for mass and energy.
      The conservation equations can be dynamic or steady-state.
      The model can have an arbitrary number of fluid ports.
      Models that instanciate this model need to define the input
      <code>fluidVolume</code>, which is the actual volume occupied by the fluid.
      For most components, this can be set to a parameter. However, for components such as 
      expansion vessels, the fluid volume can change in time.
      </p>
      
      The model has the following input connectors:<br/>
<ul>
<li>
<code>Q_flow</code>, which is the sensible plus latent heat flow rate added to the medium, and
</li>
<li>
<code>mXi_flow</code>, which is the species mass flow rate added to the medium.
</li>
</ul> 
 
  <p>
  Models that instanciate this model can used these connectors to interface with the conservation equations.
  </p>
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td><a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortConservationEquation\">
      Buildings.Fluid.Interfaces.StaticTwoPortConservationEquation</a>
  </td>
  <td><p>
      This is a basic model for steady-state conservation equations
      for mass and energy of a component with two fluid ports.
      </p>
      
      The model has the following input connectors:<br/>
<ul>
<li>
<code>Q_flow</code>, which is the sensible plus latent heat flow rate added to the medium, and
</li>
<li>
<code>mXi_flow</code>, which is the species mass flow rate added to the medium.
</li>
</ul>

  <p>
  Models that instanciate this model can used these connectors to interface with the conservation equations.
  </p>
 <p>
  Compared to 
  <a href=\"modelica://Buildings.Fluid.Interfaces.ConservationEquation\">
      Buildings.Fluid.Interfaces.ConservationEquation</a>
  this model provides a more efficient implementation of the steady-state conservation equations for
  models with two fluid ports.
  </p>
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.FourPort\">
                          Buildings.Fluid.Interfaces.FourPort</a>
  </td>
  <td>
     This model defines an interface for components with four ports. 
     Only parameters and fluid definitions are provided, but no
     equations.
     The model is identical to 
     <a href=\"modelica://Modelica.Fluid.Interfaces.PartialTwoPort\">
     Modelica.Fluid.Interfaces.PartialTwoPort</a>, except that it has 
     four ports.
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.PartialTwoPortInterface\">
                          Buildings.Fluid.Interfaces.PartialTwoPortInterface</a>
  </td>
  <td>
     This model defines the interface for component models that transport
     fluid, and that can exchange heat and mass.
     It also defines the port pressure difference as 
     <i>&Delta;p = p<sub>a</sub>-p<sub>b</sub></i>. However, no equation is
     implemented to compute <i>&Delta;p(&sdot;)</i> as a function of the
     mass flow rate. The model also implements equations to obtain the
     thermodynamic state at the ports.
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.PartialFourPortInterface\">
                          Buildings.Fluid.Interfaces.PartialFourPortInterface</a>
  </td>
  <td>
     This model is identical to 
     <a href=\"modelica://Buildings.Fluid.Interfaces.PartialTwoPortInterface\">
                          Buildings.Fluid.Interfaces.PartialTwoPortInterface</a>
     but it can be used for components with four fluid ports.
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger</a>
  </td>
  <td>
     This model implements the pressure drop as a function of the mass flow rate. 
     It also implements the steady-state energy and mass conservation 
     equations. However, it does not implement an equation that computes 
     <code>Q_flow</code>, the 
     sensible and latent heat transfer to the medium flow, nor
     does it implement an equation for <code>mXi_flow</code>, 
     the species mass flow rate added to or removed from the medium. 
     Models that extend this model need to provide equations
     for <code>Q_flow</code> and <code>mXi_flow</code>.
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.StaticFourPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.StaticFourPortHeatMassExchanger</a>
  </td>
  <td>
     This model is identical to 
     <a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger</a>
     except that it has four ports.
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.TwoPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.TwoPortHeatMassExchanger</a>
  </td>
  <td>
     This model implements the pressure drop as a function of the mass flow rate. 
     It also implements the energy and mass conservation equations, which may be
     configured as steady-state or dynamic balances based on a parameter. 
  </td>
</tr>
<!-- ============================================== -->
<tr>
  <td>
     <a href=\"modelica://Buildings.Fluid.Interfaces.FourPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.FourPortHeatMassExchanger</a>
  </td>
  <td>
     This model is identical to 
     <a href=\"modelica://Buildings.Fluid.Interfaces.TwoPortHeatMassExchanger\">
                          Buildings.Fluid.Interfaces.TwoPortHeatMassExchanger</a>
     except that it has four ports.
  </td>
</tr>
</table>

</html>"));

    end UsersGuide;

      model FourPort "Partial model with four ports"
        import Modelica.Constants;
        outer Modelica.Fluid.System system "System wide properties";

        replaceable package Medium1 =
            Modelica.Media.Interfaces.PartialMedium "Medium 1 in the component"
            annotation (choicesAllMatching = true);
        replaceable package Medium2 =
            Modelica.Media.Interfaces.PartialMedium "Medium 2 in the component"
            annotation (choicesAllMatching = true);

        parameter Boolean allowFlowReversal1 = system.allowFlowReversal
          "= true to allow flow reversal in medium 1, false restricts to design direction (port_a -> port_b)"
          annotation(Dialog(tab="Assumptions"), Evaluate=true);
        parameter Boolean allowFlowReversal2 = system.allowFlowReversal
          "= true to allow flow reversal in medium 2, false restricts to design direction (port_a -> port_b)"
          annotation(Dialog(tab="Assumptions"), Evaluate=true);

        parameter Modelica.SIunits.SpecificEnthalpy h_outflow_a1_start = Medium1.h_default
          "Start value for enthalpy flowing out of port a1"
          annotation (Dialog(tab="Advanced", group="Initialization"));

        parameter Modelica.SIunits.SpecificEnthalpy h_outflow_b1_start = Medium1.h_default
          "Start value for enthalpy flowing out of port b1"
          annotation (Dialog(tab="Advanced", group="Initialization"));

        parameter Modelica.SIunits.SpecificEnthalpy h_outflow_a2_start = Medium2.h_default
          "Start value for enthalpy flowing out of port a2"
          annotation (Dialog(tab="Advanced", group="Initialization"));

        parameter Modelica.SIunits.SpecificEnthalpy h_outflow_b2_start = Medium2.h_default
          "Start value for enthalpy flowing out of port b2"
          annotation (Dialog(tab="Advanced", group="Initialization"));

        Modelica.Fluid.Interfaces.FluidPort_a port_a1(
                           redeclare package Medium = Medium1,
                           m_flow(min=if allowFlowReversal1 then -Constants.inf else 0),
                           h_outflow(nominal=1E5, start=h_outflow_a1_start),
                           Xi_outflow(each nominal=0.01))
          "Fluid connector a1 (positive design flow direction is from port_a1 to port_b1)"
          annotation (Placement(transformation(extent={{-110,50},{-90,70}},
                  rotation=0)));
        Modelica.Fluid.Interfaces.FluidPort_b port_b1(
                           redeclare package Medium = Medium1,
                           m_flow(max=if allowFlowReversal1 then +Constants.inf else 0),
                           h_outflow(nominal=1E5, start=h_outflow_b1_start),
                           Xi_outflow(each nominal=0.01))
          "Fluid connector b1 (positive design flow direction is from port_a1 to port_b1)"
          annotation (Placement(transformation(extent={{110,50},{90,70}},  rotation=
                   0), iconTransformation(extent={{110,50},{90,70}})));

        Modelica.Fluid.Interfaces.FluidPort_a port_a2(
                           redeclare package Medium = Medium2,
                           m_flow(min=if allowFlowReversal2 then -Constants.inf else 0),
                           h_outflow(nominal=1E5,start=h_outflow_a2_start),
                           Xi_outflow(each nominal=0.01))
          "Fluid connector a2 (positive design flow direction is from port_a2 to port_b2)"
          annotation (Placement(transformation(extent={{90,-70},{110,-50}},
                  rotation=0)));
        Modelica.Fluid.Interfaces.FluidPort_b port_b2(
                           redeclare package Medium = Medium2,
                           m_flow(max=if allowFlowReversal2 then +Constants.inf else 0),
                           h_outflow(nominal=1E5, start=h_outflow_b2_start),
                           Xi_outflow(each nominal=0.01))
          "Fluid connector b2 (positive design flow direction is from port_a2 to port_b2)"
          annotation (Placement(transformation(extent={{-90,-70},{-110,-50}},
                                rotation=0),
                      iconTransformation(extent={{-90,-70},{-110,-50}})));

        annotation (
          preferredView="info",
          Diagram(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={1,1})),
          Documentation(info="<html>
<p>
This model defines an interface for components with four ports. 
The parameters <code>allowFlowReversal1</code> and
<code>allowFlowReversal2</code> may be used by models that extend
this model to treat flow reversal.
</p>
<p>
This model is identical to 
<a href=\"modelica://Modelica.Fluid.Interfaces.PartialTwoPort\">
Modelica.Fluid.Interfaces.PartialTwoPort</a>, except that it has four ports.
</p>
</html>",       revisions="<html>
<ul>
<li>
September 26, 2013 by Michael Wetter:<br/>
Added missing <code>each</code> keyword in declaration of nominal value for 
<code>Xi_outflow</code>.
</li>
<li>
September 17, 2010 by Michael Wetter:<br/>
Fixed bug: The start value for <code>port_b1.h_outflow</code>
was set to <code>h_outflow_b2_start</code> instead of <code>h_outflow_b1_start</code>.
</li>
<li>
February 26, 2010 by Michael Wetter:<br/>
Added start values for outflowing enthalpy because they 
are often iteration variables in nonlinear equation systems.
</li>
</ul>
</html>"),Icon(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={1,1}), graphics={Text(
                extent={{-151,147},{149,107}},
                lineColor={0,0,255},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={0,127,255},
                textString="%name")}));
      end FourPort;

      model TwoPortHeatMassExchanger
        "Partial model transporting one fluid stream with storing mass or energy"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialTwoPortInterface(
            port_a(h_outflow(start=h_outflow_start)), port_b(h_outflow(start=
                  h_outflow_start)));
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.TwoPortFlowResistanceParameters(
            final computeFlowResistance=true);
        import Modelica.Constants;

        parameter Modelica.SIunits.Time tau = 30
          "Time constant at nominal flow (if energyDynamics <> SteadyState)"
           annotation (Evaluate=true, Dialog(tab = "Dynamics", group="Nominal condition"));

        // Advanced
        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));

        // Dynamics
        parameter Modelica.Fluid.Types.Dynamics energyDynamics=Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
          "Formulation of energy balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));
        parameter Modelica.Fluid.Types.Dynamics massDynamics=energyDynamics
          "Formulation of mass balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));

        // Initialization
        parameter Medium.AbsolutePressure p_start = Medium.p_default
          "Start value of pressure"
          annotation(Dialog(tab = "Initialization"));
        parameter Medium.Temperature T_start = Medium.T_default
          "Start value of temperature"
          annotation(Dialog(tab = "Initialization"));
        parameter Medium.MassFraction X_start[Medium.nX] = Medium.X_default
          "Start value of mass fractions m_i/m"
          annotation (Dialog(tab="Initialization", enable=Medium.nXi > 0));
        parameter Medium.ExtraProperty C_start[Medium.nC](
             quantity=Medium.extraPropertiesNames)=fill(0, Medium.nC)
          "Start value of trace substances"
          annotation (Dialog(tab="Initialization", enable=Medium.nC > 0));

        replaceable Buildings.Fluid.MixingVolumes.MixingVolume vol
        constrainedby
          Buildings.Fluid.MixingVolumes.BaseClasses.PartialMixingVolume(
          redeclare final package Medium = Medium,
          nPorts = 2,
          V=m_flow_nominal*tau/rho_default,
          final m_flow_nominal = m_flow_nominal,
          final energyDynamics=energyDynamics,
          final massDynamics=massDynamics,
          final p_start=p_start,
          final T_start=T_start,
          final X_start=X_start,
          final C_start=C_start) "Volume for fluid stream"
           annotation (Placement(transformation(extent={{-9,0},{11,-20}},
               rotation=0)));

        Buildings.Fluid.FixedResistances.FixedResistanceDpM preDro(
          redeclare package Medium = Medium,
          final use_dh=false,
          final m_flow_nominal=m_flow_nominal,
          final deltaM=deltaM,
          final allowFlowReversal=allowFlowReversal,
          final show_T=false,
          final from_dp=from_dp,
          final linearized=linearizeFlowResistance,
          final homotopyInitialization=homotopyInitialization,
          final dp_nominal=dp_nominal) "Pressure drop model"
          annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));

      protected
        parameter Medium.ThermodynamicState sta_default=Medium.setState_pTX(
            T=Medium.T_default, p=Medium.p_default, X=Medium.X_default);
        parameter Modelica.SIunits.Density rho_default=Medium.density(sta_default)
          "Density, used to compute fluid volume";
        parameter Medium.ThermodynamicState sta_start=Medium.setState_pTX(
            T=T_start, p=p_start, X=X_start);
        parameter Modelica.SIunits.SpecificEnthalpy h_outflow_start = Medium.specificEnthalpy(sta_start)
          "Start value for outflowing enthalpy";

      initial algorithm
        assert((energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState) or
                tau > Modelica.Constants.eps,
      "The parameter tau, or the volume of the model from which tau may be derived, is unreasonably small.
 Set energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState to model steady-state.
 Received tau = "       + String(tau) + "\n");
        assert((massDynamics == Modelica.Fluid.Types.Dynamics.SteadyState) or
                tau > Modelica.Constants.eps,
      "The parameter tau, or the volume of the model from which tau may be derived, is unreasonably small.          
 Set massDynamics == Modelica.Fluid.Types.Dynamics.SteadyState to model steady-state.
 Received tau = "       + String(tau) + "\n");

      equation
        connect(vol.ports[2], port_b) annotation (Line(
            points={{1,0},{27.25,0},{27.25,0},{51.5,0},{51.5,0},{100,0}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(port_a, preDro.port_a) annotation (Line(
            points={{-100,0},{-90,0},{-90,0},{-80,0},{-80,0},{-60,0}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(preDro.port_b, vol.ports[1]) annotation (Line(
            points={{-40,0},{-30.25,0},{-30.25,0},{-20.5,0},{-20.5,0},{1,0}},
            color={0,127,255},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Documentation(info="<html>
<p>
This component transports one fluid stream. 
It provides the basic model for implementing dynamic and steady-state
models that exchange heat and water vapor with the fluid stream.
The model also computes the pressure drop due to the flow resistance.
By setting the parameter <code>dp_nominal=0</code>, the computation
of the pressure drop can be avoided.
The variable <code>vol.heatPort.T</code> always has the value of
the temperature of the medium that leaves the component.
For the actual temperatures at the port, the variables <code>sta_a.T</code>
and <code>sta_b.T</code> can be used. These two variables are provided by 
the base class
<a href=\"modelica://Buildings.Fluid.Interfaces.PartialTwoPortInterface\">
Buildings.Fluid.Interfaces.PartialTwoPortInterface</a>.
</p>

For models that extend this model, see for example
<ul>
<li>
the ideal heater or cooler
<a href=\"modelica://Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed\">
Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed</a>,
</li>
<li>
the ideal humidifier
<a href=\"modelica://Buildings.Fluid.MassExchangers.HumidifierPrescribed\">
Buildings.Fluid.MassExchangers.HumidifierPrescribed</a>, and
</li>
<li>
the boiler
<a href=\"modelica://Buildings.Fluid.Boilers.BoilerPolynomial\">
Buildings.Fluid.Boilers.BoilerPolynomial</a>.
</li>
</ul>

<h4>Implementation</h4>
<p>
The variable names follow the conventions used in 
<a href=\"modelica://Modelica.Fluid.Examples.HeatExchanger.BaseClasses.BasicHX\">
Modelica.Fluid.Examples.HeatExchanger.BaseClasses.BasicHX
</a>.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 8, 2013, by Michael Wetter:<br/>
Removed parameter <code>show_V_flow</code>.
</li>
<li>
December 14, 2012 by Michael Wetter:<br/>
Renamed protected parameters for consistency with the naming conventions.
</li>
<li>
October 17, 2012, by Michael Wetter:<br/>
Fixed broken link in documentation.
</li>
<li>
February 3, 2012, by Michael Wetter:<br/>
Removed assignment of <code>m_flow_small</code> as it is no
longer used in the pressure drop model.
</li>
<li>
January 15, 2011, by Michael Wetter:<br/>
Fixed wrong class reference in information section.
</li>
<li>
September 13, 2011, by Michael Wetter:<br/>
Changed assignment of <code>vol(mass/energyDynamics=...)</code> as the
previous assignment caused a non-literal start value that was ignored.
</li>
<li>
July 29, 2011, by Michael Wetter:<br/>
Added start value for outflowing enthalpy.
</li>
<li>
July 11, 2011, by Michael Wetter:<br/>
Changed parameterization of fluid volume so that steady-state balance is
used when <code>tau = 0</code>.
</li>
<li>
May 25, 2011, by Michael Wetter:<br/>
Removed temperature sensor and changed implementation of fluid volume
to allow use of this model for the steady-state and dynamic humidifier
<a href=\"modelica://Buildings.Fluid.MassExchangers.HumidifierPrescribed\">
Buildings.Fluid.MassExchangers.HumidifierPrescribed</a>.
</li>
<li>
March 25, 2011, by Michael Wetter:<br/>
Added homotopy operator.
</li>
<li>
March 21, 2010 by Michael Wetter:<br/>
Changed pressure start value from <code>system.p_start</code>
to <code>Medium.p_default</code> since HVAC models may have water and 
air, which are typically at different pressures.
</li>
<li>
April 13, 2009, by Michael Wetter:<br/>
Added model to compute flow friction.
</li>
<li>
January 29, 2009 by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-70,60},{70,-60}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-101,6},{100,-4}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{0,-4},{100,6}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={255,0,0},
                fillPattern=FillPattern.Solid)}));
      end TwoPortHeatMassExchanger;

      model FourPortHeatMassExchanger
        "Model transporting two fluid streams between four ports with storing mass or energy"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialFourPortInterface(
          final h_outflow_a1_start=h1_outflow_start,
          final h_outflow_b1_start=h1_outflow_start,
          final h_outflow_a2_start=h2_outflow_start,
          final h_outflow_b2_start=h2_outflow_start);
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.FourPortFlowResistanceParameters(
            final computeFlowResistance1=true, final computeFlowResistance2=
              true);
        import Modelica.Constants;

        parameter Modelica.SIunits.Time tau1 = 30
          "Time constant at nominal flow"
           annotation (Evaluate=true, Dialog(tab = "Dynamics", group="Nominal condition"));
        parameter Modelica.SIunits.Time tau2 = 30
          "Time constant at nominal flow"
           annotation (Evaluate=true, Dialog(tab = "Dynamics", group="Nominal condition"));

        // Advanced
        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));

        // Assumptions
        parameter Modelica.Fluid.Types.Dynamics energyDynamics=Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
          "Formulation of energy balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));
        parameter Modelica.Fluid.Types.Dynamics massDynamics=energyDynamics
          "Formulation of mass balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));

        // Initialization
        parameter Medium1.AbsolutePressure p1_start = Medium1.p_default
          "Start value of pressure"
          annotation(Dialog(tab = "Initialization", group = "Medium 1"));
        parameter Medium1.Temperature T1_start = Medium1.T_default
          "Start value of temperature"
          annotation(Dialog(tab = "Initialization", group = "Medium 1"));
        parameter Medium1.MassFraction X1_start[Medium1.nX] = Medium1.X_default
          "Start value of mass fractions m_i/m"
          annotation (Dialog(tab="Initialization", group = "Medium 1", enable=Medium1.nXi > 0));
        parameter Medium1.ExtraProperty C1_start[Medium1.nC](
             quantity=Medium1.extraPropertiesNames)=fill(0, Medium1.nC)
          "Start value of trace substances"
          annotation (Dialog(tab="Initialization", group = "Medium 1", enable=Medium1.nC > 0));
        parameter Medium1.ExtraProperty C1_nominal[Medium1.nC](
             quantity=Medium1.extraPropertiesNames) = fill(1E-2, Medium1.nC)
          "Nominal value of trace substances. (Set to typical order of magnitude.)"
         annotation (Dialog(tab="Initialization", group = "Medium 1", enable=Medium1.nC > 0));

        parameter Medium2.AbsolutePressure p2_start = Medium2.p_default
          "Start value of pressure"
          annotation(Dialog(tab = "Initialization", group = "Medium 2"));
        parameter Medium2.Temperature T2_start = Medium2.T_default
          "Start value of temperature"
          annotation(Dialog(tab = "Initialization", group = "Medium 2"));
        parameter Medium2.MassFraction X2_start[Medium2.nX] = Medium2.X_default
          "Start value of mass fractions m_i/m"
          annotation (Dialog(tab="Initialization", group = "Medium 2", enable=Medium2.nXi > 0));
        parameter Medium2.ExtraProperty C2_start[Medium2.nC](
             quantity=Medium2.extraPropertiesNames)=fill(0, Medium2.nC)
          "Start value of trace substances"
          annotation (Dialog(tab="Initialization", group = "Medium 2", enable=Medium2.nC > 0));
        parameter Medium2.ExtraProperty C2_nominal[Medium2.nC](
             quantity=Medium2.extraPropertiesNames) = fill(1E-2, Medium2.nC)
          "Nominal value of trace substances. (Set to typical order of magnitude.)"
         annotation (Dialog(tab="Initialization", group = "Medium 2", enable=Medium2.nC > 0));

        Buildings.Fluid.MixingVolumes.MixingVolume vol1(
          redeclare final package Medium = Medium1,
          nPorts = 2,
          V=m1_flow_nominal*tau1/rho1_nominal,
          final m_flow_nominal=m1_flow_nominal,
          energyDynamics=if tau1 > Modelica.Constants.eps
                               then energyDynamics else
                               Modelica.Fluid.Types.Dynamics.SteadyState,
          massDynamics=if tau1 > Modelica.Constants.eps
                               then massDynamics else
                               Modelica.Fluid.Types.Dynamics.SteadyState,
          final p_start=p1_start,
          final T_start=T1_start,
          final X_start=X1_start,
          final C_start=C1_start,
          final C_nominal=C1_nominal) "Volume for fluid 1"
                                     annotation (Placement(transformation(extent={{-10,70},
                  {10,50}},         rotation=0)));

        replaceable Buildings.Fluid.MixingVolumes.MixingVolume vol2
          constrainedby
          Buildings.Fluid.MixingVolumes.BaseClasses.PartialMixingVolume(
          redeclare final package Medium = Medium2,
          nPorts = 2,
          V=m2_flow_nominal*tau2/rho2_nominal,
          final m_flow_nominal = m2_flow_nominal,
          energyDynamics=if tau2 > Modelica.Constants.eps
                               then energyDynamics else
                               Modelica.Fluid.Types.Dynamics.SteadyState,
          massDynamics=if tau2 > Modelica.Constants.eps
                               then massDynamics else
                               Modelica.Fluid.Types.Dynamics.SteadyState,
          final p_start=p2_start,
          final T_start=T2_start,
          final X_start=X2_start,
          final C_start=C2_start,
          final C_nominal=C2_nominal) "Volume for fluid 2"
         annotation (Placement(transformation(
              origin={2,-60},
              extent={{-10,10},{10,-10}},
              rotation=180)));

        Modelica.SIunits.HeatFlowRate Q1_flow = vol1.heatPort.Q_flow
          "Heat flow rate into medium 1";
        Modelica.SIunits.HeatFlowRate Q2_flow = vol2.heatPort.Q_flow
          "Heat flow rate into medium 2";

        Buildings.Fluid.FixedResistances.FixedResistanceDpM preDro1(
          redeclare package Medium = Medium1,
          final use_dh=false,
          final m_flow_nominal=m1_flow_nominal,
          final deltaM=deltaM1,
          final allowFlowReversal=allowFlowReversal1,
          final show_T=false,
          final from_dp=from_dp1,
          final linearized=linearizeFlowResistance1,
          final homotopyInitialization=homotopyInitialization,
          final dp_nominal=dp1_nominal,
          final dh=1,
          final ReC=4000) "Pressure drop model for fluid 1"
          annotation (Placement(transformation(extent={{-80,70},{-60,90}})));

        Buildings.Fluid.FixedResistances.FixedResistanceDpM preDro2(
          redeclare package Medium = Medium2,
          final use_dh=false,
          final m_flow_nominal=m2_flow_nominal,
          final deltaM=deltaM2,
          final allowFlowReversal=allowFlowReversal2,
          final show_T=false,
          final from_dp=from_dp2,
          final linearized=linearizeFlowResistance2,
          final homotopyInitialization=homotopyInitialization,
          final dp_nominal=dp2_nominal,
          final dh=1,
          final ReC=4000) "Pressure drop model for fluid 2"
          annotation (Placement(transformation(extent={{80,-90},{60,-70}})));

      protected
        parameter Medium1.ThermodynamicState sta1_nominal=Medium1.setState_pTX(
            T=Medium1.T_default, p=Medium1.p_default, X=Medium1.X_default);
        parameter Modelica.SIunits.Density rho1_nominal=Medium1.density(sta1_nominal)
          "Density, used to compute fluid volume";
        parameter Medium2.ThermodynamicState sta2_nominal=Medium2.setState_pTX(
            T=Medium2.T_default, p=Medium2.p_default, X=Medium2.X_default);
        parameter Modelica.SIunits.Density rho2_nominal=Medium2.density(sta2_nominal)
          "Density, used to compute fluid volume";

        parameter Medium1.ThermodynamicState sta1_start=Medium1.setState_pTX(
            T=T1_start, p=p1_start, X=X1_start);
        parameter Modelica.SIunits.SpecificEnthalpy h1_outflow_start = Medium1.specificEnthalpy(sta1_start)
          "Start value for outflowing enthalpy";
        parameter Medium2.ThermodynamicState sta2_start=Medium2.setState_pTX(
            T=T2_start, p=p2_start, X=X2_start);
        parameter Modelica.SIunits.SpecificEnthalpy h2_outflow_start = Medium2.specificEnthalpy(sta2_start)
          "Start value for outflowing enthalpy";

      equation
        connect(vol1.ports[2], port_b1) annotation (Line(
            points={{2,70},{20,70},{20,60},{100,60}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(vol2.ports[2], port_b2) annotation (Line(
            points={{2,-70},{-30,-70},{-30,-60},{-100,-60}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(port_a1, preDro1.port_a) annotation (Line(
            points={{-100,60},{-90,60},{-90,80},{-80,80}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(preDro1.port_b, vol1.ports[1]) annotation (Line(
            points={{-60,80},{-2,80},{-2,70}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(port_a2, preDro2.port_a) annotation (Line(
            points={{100,-60},{90,-60},{90,-80},{80,-80}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(preDro2.port_b, vol2.ports[1]) annotation (Line(
            points={{60,-80},{2,-80},{2,-70}},
            color={0,127,255},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Documentation(info="<html>
<p>
This component transports two fluid streams between four ports. 
It provides the basic model for implementing a dynamic heat exchanger.
</p>
<p>
The model can be used as-is, although there will be no heat or mass transfer
between the two fluid streams. 
To add heat transfer, heat flow can be added to the heat port of the two volumes.
See for example
<a href=\"Buildings.Fluid.Chillers.Carnot\">
Buildings.Fluid.Chillers.Carnot</a>.
To add moisture input into (or moisture output from) volume <code>vol2</code>,
the model can be replaced as shown in
<a href=\"modelica://Buildings.Fluid.HeatExchangers.BaseClasses.HexElement\">
Buildings.Fluid.HeatExchangers.BaseClasses.HexElement</a>.
</p>
<h4>Implementation</h4>
<p>
The variable names follow the conventions used in 
<a href=\"modelica://Modelica.Fluid.HeatExchangers.BasicHX\">
Modelica.Fluid.HeatExchangers.BasicHX</a>.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 8, 2013, by Michael Wetter:<br/>
Removed parameter <code>show_V_flow</code>.
</li>
<li>
September 26, 2013, by Michael Wetter:<br/>
Removed unrequired <code>sum</code> operator.
</li>
<li>
February 6, 2012, by Michael Wetter:<br/>
Updated documentation.
</li>
<li>
February 3, 2012, by Michael Wetter:<br/>
Removed assignment of <code>m_flow_small</code> as it is no
longer used in its base class.
</li>
<li>
July 29, 2011, by Michael Wetter:
<ul>
<li>
Changed values of 
<code>h_outflow_a1_start</code>,
<code>h_outflow_b1_start</code>,
<code>h_outflow_a2_start</code> and
<code>h_outflow_b2_start</code>, and 
declared them as final.
</li>
<li>
Set nominal values for <code>vol1.C</code> and <code>vol2.C</code>.
</li>
</ul>
</li>
<li>
July 11, 2011, by Michael Wetter:<br/>
Changed parameterization of fluid volume so that steady-state balance is
used when <code>tau = 0</code>.
</li>
<li>
March 25, 2011, by Michael Wetter:<br/>
Added homotopy operator.
</li>
<li>
April 13, 2009, by Michael Wetter:<br/>
Added model to compute flow friction.
</li>
<li>
September 10, 2008 by Michael Wetter:<br/>
Added <code>stateSelect=StateSelect.always</code> for temperature of volume 1.
</li>
<li>
Changed temperature sensor from Celsius to Kelvin.
Unit conversion should be made during output
processing.
<li>
August 5, 2008, by Michael Wetter:<br/>
Replaced instances of <code>Delays.DelayFirstOrder</code> with instances of
<code>MixingVolumes.MixingVolume</code>. This allows to extract liquid for a condensing cooling
coil model.
</li>
<li>
March 25, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-70,80},{70,-80}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-99,64},{102,54}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-99,-56},{102,-66}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid)}));
      end FourPortHeatMassExchanger;

      model StaticTwoPortHeatMassExchanger
        "Partial model transporting fluid between two ports without storing mass or energy"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialTwoPortInterface(
            showDesignFlowDirection=false);
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.TwoPortFlowResistanceParameters(
            final computeFlowResistance=(abs(dp_nominal) > Modelica.Constants.eps));

        // Model inputs
        input Modelica.SIunits.HeatFlowRate Q_flow
          "Heat transfered into the medium";
        input Modelica.SIunits.MassFlowRate mWat_flow
          "Moisture mass flow rate added to the medium";

        // Models for conservation equations and pressure drop
        CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.StaticTwoPortConservationEquation
          vol(
          sensibleOnly=sensibleOnly,
          use_safeDivision=use_safeDivision,
          redeclare final package Medium = Medium,
          final m_flow_nominal=m_flow_nominal,
          final allowFlowReversal=allowFlowReversal,
          final m_flow_small=m_flow_small,
          final homotopyInitialization=homotopyInitialization)
          "Control volume for steady-state energy and mass balance"
          annotation (Placement(transformation(extent={{15,-10}, {35,10}})));
        Buildings.Fluid.FixedResistances.FixedResistanceDpM preDro(
          redeclare final package Medium = Medium,
          final use_dh=false,
          final m_flow_nominal=m_flow_nominal,
          final deltaM=deltaM,
          final allowFlowReversal=allowFlowReversal,
          final show_T=false,
          final from_dp=from_dp,
          final linearized=linearizeFlowResistance,
          final homotopyInitialization=homotopyInitialization,
          final dp_nominal=dp_nominal) "Pressure drop model"
          annotation (Placement(transformation(extent={{-50,-10},{-30,10}})));

        // Outputs that are needed in models that extend this model
        Modelica.Blocks.Interfaces.RealOutput hOut(unit="J/kg")
          "Leaving temperature of the component";

        Modelica.Blocks.Interfaces.RealOutput XiOut[Medium.nXi](each unit="1",
                                                                each min=0,
                                                                each max=1)
          "Leaving species concentration of the component";
        Modelica.Blocks.Interfaces.RealOutput COut[Medium.nC](each min=0)
          "Leaving trace substances of the component";

        constant Boolean sensibleOnly "Set to true if sensible exchange only";
        constant Boolean use_safeDivision=true
          "Set to true to improve numerical robustness";
      protected
        Modelica.Blocks.Sources.RealExpression heaInp(y=Q_flow)
          "Block to set heat input into volume"
          annotation (Placement(transformation(extent={{-20,40},{0,60}})));
        Modelica.Blocks.Sources.RealExpression
          masExc(final y=mWat_flow) "Block to set moisture exchange in volume"
          annotation (Placement(transformation(extent={{-20,20},{0,40}})));
      equation
        connect(vol.hOut, hOut);
        connect(vol.XiOut, XiOut);
        connect(vol.COut, COut);
        connect(port_a,preDro. port_a) annotation (Line(
            points={{-100,0},{-80,0},{-80,0},{-70,0},{-70,
                0},{-50,0}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(preDro.port_b, vol.port_a) annotation (Line(
            points={{-30,0},{15,0}},
            color={0,127,255},
            smooth=Smooth.None));

        connect(vol.port_b, port_b) annotation (Line(
            points={{35,0},{67,0},{100,5.55112e-16}},
            color={0,127,255},
            smooth=Smooth.None));

        connect(heaInp.y, vol.Q_flow) annotation (Line(
            points={{1,50},{6,50},{6,8},{13,8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(masExc.y, vol.mWat_flow) annotation (Line(
            points={{1,30},{4,30},{4,4},{13,4}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          preferredView="info",
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics),
          Documentation(info="<html>
<p>
This component transports fluid between its two ports, without
storing mass or energy. It is based on 
<a href=\"modelica://Modelica.Fluid.Interfaces.PartialTwoPortTransport\">
Modelica.Fluid.Interfaces.PartialTwoPortTransport</a> but it does
use a different implementation for handling reverse flow because
in this component, mass flow rate can be added or removed from
the medium.
</p>
<p>
If <code>dp_nominal &gt; Modelica.Constants.eps</code>, this component computes
pressure drop due to flow friction.
The pressure drop is defined by a quadratic function that goes through
the point <code>(m_flow_nominal, dp_nominal)</code>. At <code>|m_flow| &lt; deltaM * m_flow_nominal</code>,
the pressure drop vs. flow relation is linearized.
If the parameter <code>linearizeFlowResistance</code> is set to true,
then the whole pressure drop vs. flow resistance curve is linearized.
</p>
<h4>Implementation</h4>
This model uses inputs and constants that need to be set by models
that extend or instantiate this model.
The following inputs need to be assigned:
<ul>
<li>
<code>Q_flow</code>, which is the heat flow rate added to the medium.
</li>
<li>
<code>mWat_flow</code>, which is the moisture mass flow rate added to the medium.
</li>
</ul>

<p>
Set the constant <code>sensibleOnly=true</code> if the model that extends
or instantiates this model sets <code>mWat_flow = 0</code>.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 8, 2013 by Michael Wetter:<br/>
Removed propagation of <code>show_V_flow</code>
to pressure drop calculation, as this model no longer has
that parameter.
</li>
<li>
July 30, 2013 by Michael Wetter:<br/>
Changed connector <code>mXi_flow[Medium.nXi]</code>
to a scalar input connector <code>mWat_flow</code>.
The reason is that <code>mXi_flow</code> does not allow
to compute the other components in <code>mX_flow</code> and
therefore leads to an ambiguous use of the model.
By only requesting <code>mWat_flow</code>, the mass balance
and species balance can be implemented correctly.
</li>
<li>
March 27, 2013 by Michael Wetter:<br/>
Removed wrong unit attribute of <code>COut</code>,
and added min and max attributes for <code>XiOut</code>.
</li>
<li>
February 8, 2012 by Michael Wetter:<br/>
Changed model to use graphical modeling.
</li>
<li>
December 14, 2011 by Michael Wetter:<br/>
Changed assignment of <code>hOut</code>, <code>XiOut</code> and
<code>COut</code> to no longer declare that it is continuous. 
The declaration of continuity, i.e, the 
<code>smooth(0, if (port_a.m_flow >= 0) then ...</code> declaration,
was required for Dymola 2012 to simulate, but it is no longer needed 
for Dymola 2012 FD01.
</li>
<li>
August 19, 2011, by Michael Wetter:<br/>
Changed assignment of <code>hOut</code>, <code>XiOut</code> and
<code>COut</code> to declare that it is not differentiable.
</li>
<li>
August 4, 2011, by Michael Wetter:<br/>
Moved linearized pressure drop equation from the function body to the equation
section. With the previous implementation, 
the symbolic processor may not rearrange the equations, which can lead 
to coupled equations instead of an explicit solution.
</li>
<li>
March 29, 2011, by Michael Wetter:<br/>
Changed energy and mass balance to avoid a division by zero if <code>m_flow=0</code>.
</li>
<li>
March 27, 2011, by Michael Wetter:<br/>
Added <code>homotopy</code> operator.
</li>
<li>
August 19, 2010, by Michael Wetter:<br/>
Fixed bug in energy and moisture balance that affected results if a component
adds or removes moisture to the air stream. 
In the old implementation, the enthalpy and species
outflow at <code>port_b</code> was multiplied with the mass flow rate at 
<code>port_a</code>. The old implementation led to small errors that were proportional
to the amount of moisture change. For example, if the moisture added by the component
was <code>0.005 kg/kg</code>, then the error was <code>0.5%</code>.
Also, the results for forward flow and reverse flow differed by this amount.
With the new implementation, the energy and moisture balance is exact.
</li>
<li>
March 22, 2010, by Michael Wetter:<br/>
Added constant <code>sensibleOnly</code> to 
simplify species balance equation.
</li>
<li>
April 10, 2009, by Michael Wetter:<br/>
Added model to compute flow friction.
</li>
<li>
April 22, 2008, by Michael Wetter:<br/>
Revised to add mass balance.
</li>
<li>
March 17, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics));
      end StaticTwoPortHeatMassExchanger;

      model StaticFourPortHeatMassExchanger
        "Partial model transporting two fluid streams between four ports without storing mass or energy"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialFourPortInterface;
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.FourPortFlowResistanceParameters(
            final computeFlowResistance1=(dp1_nominal > Modelica.Constants.eps),
            final computeFlowResistance2=(dp2_nominal > Modelica.Constants.eps));
        import Modelica.Constants;
        input Modelica.SIunits.HeatFlowRate Q1_flow
          "Heat transfered into the medium 1";
        input Medium1.MassFlowRate mWat1_flow
          "Moisture mass flow rate added to the medium 1";
        input Modelica.SIunits.HeatFlowRate Q2_flow
          "Heat transfered into the medium 2";
        input Medium2.MassFlowRate mWat2_flow
          "Moisture mass flow rate added to the medium 2";
        constant Boolean sensibleOnly1
          "Set to true if sensible exchange only for medium 1";
        constant Boolean sensibleOnly2
          "Set to true if sensible exchange only for medium 2";
      protected
        CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.StaticTwoPortHeatMassExchanger
          bal1(
          final sensibleOnly=sensibleOnly1,
          redeclare final package Medium = Medium1,
          final m_flow_nominal=m1_flow_nominal,
          final dp_nominal=dp1_nominal,
          final allowFlowReversal=allowFlowReversal1,
          final m_flow_small=m1_flow_small,
          final homotopyInitialization=homotopyInitialization,
          final from_dp=from_dp1,
          final linearizeFlowResistance=linearizeFlowResistance1,
          final deltaM=deltaM1,
          final Q_flow=Q1_flow,
          final mWat_flow=mWat1_flow)
          "Model for heat, mass, species, trace substance and pressure balance of stream 1";
        CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.StaticTwoPortHeatMassExchanger
          bal2(
          final sensibleOnly=sensibleOnly2,
          redeclare final package Medium = Medium2,
          final m_flow_nominal=m2_flow_nominal,
          final dp_nominal=dp2_nominal,
          final allowFlowReversal=allowFlowReversal2,
          final m_flow_small=m2_flow_small,
          final homotopyInitialization=homotopyInitialization,
          final from_dp=from_dp2,
          final linearizeFlowResistance=linearizeFlowResistance2,
          final deltaM=deltaM2,
          final Q_flow=Q2_flow,
          final mWat_flow=mWat2_flow)
          "Model for heat, mass, species, trace substance and pressure balance of stream 2";
      equation
        connect(bal1.port_a, port_a1);
        connect(bal1.port_b, port_b1);
        connect(bal2.port_a, port_a2);
        connect(bal2.port_b, port_b2);
        annotation (
          preferredView="info",
          Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Documentation(info="<html>
<p>
This component transports two fluid streams between four ports, without
storing mass or energy. It is similar to
<a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger\">
Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger</a>,
but it has four ports instead of two.
</p>
<p>
If <code>dp<i>N</i>_nominal &gt; Modelica.Constants.eps</code>, 
where <code><i>N</i></code> denotes the fluid <i>1</i> or <i>2</i>,
then the model computes
pressure drop due to flow friction in the respective fluid stream.
The pressure drop is defined by a quadratic function that goes through
the point <code>(m<i>N</i>_flow_nominal, dp<i>N</i>_nominal)</code>. 
At <code>|m<i>N</i>_flow| &lt; deltaM<i>N</i> * m<i>N</i>_flow_nominal</code>,
the pressure drop vs. flow relation is linearized.
If the parameter <code>linearizeFlowResistance<i>N</i></code> is set to true,
then the whole pressure drop vs. flow resistance curve is linearized.
</p>

<h4>Implementation</h4>
<p>
This model uses inputs and constants that need to be set by models
that extend or instantiate this model.
The following inputs need to be assigned, where <code><i>N</i></code> denotes <code>1</code> or
<code>2</code>:</p>
<ul>
<li>
<code>Q<i>N</i>_flow</code>, which is the heat flow rate added to the medium <i>N</i>.
</li>
<li>
<code>mWat<i>N</i>_flow</code>, which is the moisture mass flow rate added to the medium <i>N</i>.
</li>
</ul>
<p>
Set the constant <code>sensibleOnly<i>N</i>=true</code> if the model that extends
or instantiates this model sets <code>mWat<i>N</i>_flow = 0</code>.
</p>
<p>
     Note that the model does not implement <code>0 = Q1_flow + Q2_flow</code> or
     <code>0 = mXi1_flow + mXi2_flow</code>. If there is no heat or mass transfer
     with the environment, then a model that extends this model needs to provide these 
     equations.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 8, 2013, by Michael Wetter:<br/>
Removed parameter <code>show_V_flow</code>.
</li>
<li>
July 30, 2013 by Michael Wetter:<br/>
Changed connector <code>mXi_flow[Medium.nXi]</code>
to a scalar input connector <code>mWat_flow</code>.
The reason is that <code>mXi_flow</code> does not allow
to compute the other components in <code>mX_flow</code> and
therefore leads to an ambiguous use of the model.
By only requesting <code>mWat_flow</code>, the mass balance
and species balance can be implemented correctly.
</li>
<li>
March 29, 2011, by Michael Wetter:<br/>
Changed energy and mass balance to avoid a division by zero if <code>m_flow=0</code>.
</li>
<li>
March 27, 2011, by Michael Wetter:<br/>
Added <code>homotopy</code> operator.
</li>
<li>
August 19, 2010, by Michael Wetter:<br/>
Fixed bug in energy and moisture balance that affected results if a component
adds or removes moisture to the air stream. 
In the old implementation, the enthalpy and species
outflow at <code>port_b</code> was multiplied with the mass flow rate at 
<code>port_a</code>. The old implementation led to small errors that were proportional
to the amount of moisture change. For example, if the moisture added by the component
was <code>0.005 kg/kg</code>, then the error was <code>0.5%</code>.
Also, the results for forward flow and reverse flow differed by this amount.
With the new implementation, the energy and moisture balance is exact.
</li>
<li>
March 22, 2010, by Michael Wetter:<br/>
Added constants <code>sensibleOnly1</code> and
<code>sensibleOnly2</code> to 
simplify species balance equations.
</li>
<li>
April 13, 2009, by Michael Wetter:<br/>
Added model to compute flow friction.
</li>
<li>
March 25, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-70,80},{70,-80}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,65},{101,55}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,-55},{101,-65}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid)}));
      end StaticFourPortHeatMassExchanger;

      partial model PartialTwoPort "Partial component with two ports"
        import Modelica.Constants;
        outer Modelica.Fluid.System system "System wide properties";

        replaceable package Medium =
            Modelica.Media.Interfaces.PartialMedium "Medium in the component"
            annotation (choicesAllMatching = true);

        parameter Boolean allowFlowReversal = system.allowFlowReversal
          "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"
          annotation(Dialog(tab="Assumptions"), Evaluate=true);

        CO2GCHPModels_Master_Monjur.FluidPort_a port_a(redeclare package Medium
            = Medium, m_flow(min=if allowFlowReversal then -Constants.inf else
                0))
          "Fluid connector a (positive design flow direction is from port_a to port_b)"
          annotation (Placement(transformation(extent={{-93,76},{-73,96}},
                  rotation=0), iconTransformation(extent={{-99,73},{-74,99}})));
        CO2GCHPModels_Master_Monjur.FluidPort_a port_b(redeclare package Medium
            = Medium, m_flow(max=if allowFlowReversal then +Constants.inf else
                0))
          "Fluid connector b (positive design flow direction is from port_a to port_b)"
          annotation (Placement(transformation(extent={{93,75},{73,95}},   rotation=
                   0), iconTransformation(extent={{100,72},{73,99}})));
        // Model structure, e.g., used for visualization
      protected
        parameter Boolean port_a_exposesState = false
          "= true if port_a exposes the state of a fluid volume";
        parameter Boolean port_b_exposesState = false
          "= true if port_b.p exposes the state of a fluid volume";
        parameter Boolean showDesignFlowDirection = true
          "= false to hide the arrow in the model icon";

      //   annotation (
      //     Diagram(coordinateSystem(
      //           preserveAspectRatio=false,
      //           extent={{-100,-100},{100,100}},
      //           grid={1,1}), graphics),
      //     Documentation(info="<html>
      // <p>
      // This partial model defines an interface for components with two ports.
      // The treatment of the design flow direction and of flow reversal are predefined based on the parameter <code><b>allowFlowReversal</b></code>.
      // The component may transport fluid and may have internal storage for a given fluid <code><b>Medium</b></code>.
      // </p>
      // <p>
      // An extending model providing direct access to internal storage of mass or energy through port_a or port_b
      // should redefine the protected parameters <code><b>port_a_exposesState</b></code> and <code><b>port_b_exposesState</b></code> appropriately.
      // This will be visualized at the port icons, in order to improve the understanding of fluid model diagrams.
      // </p>
      // </html>"),
      //     Icon(coordinateSystem(
      //           preserveAspectRatio=false,
      //           extent={{-100,-100},{100,100}},
      //           grid={1,1}), graphics={
      //         Text(
      //           extent={{-149,-114},{151,-154}},
      //           lineColor={0,0,255},
      //           textString="%name"),
      //         Ellipse(
      //           extent={{-110,26},{-90,-24}},
      //           lineColor={0,0,0},
      //           fillColor={0,0,0},
      //           fillPattern=FillPattern.Solid,
      //           visible=port_a_exposesState),
      //         Ellipse(
      //           extent={{90,25},{110,-25}},
      //           lineColor={0,0,0},
      //           fillColor={0,0,0},
      //           fillPattern=FillPattern.Solid,
      //           visible=port_b_exposesState)}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                  -100,-100},{100,100}}), graphics));
      end PartialTwoPort;

      partial model PartialTwoPortInterface
        "Partial model transporting fluid between two ports without storing mass or energy"
        import Modelica.Constants;
        extends CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialTwoPort(
            port_a(p(start=Medium.p_default, nominal=Medium.p_default)), port_b(
              p(start=Medium.p_default, nominal=Medium.p_default)));

        parameter Modelica.SIunits.MassFlowRate m_flow_nominal
          "Nominal mass flow rate"
          annotation(Dialog(group = "Nominal condition"));
        parameter Modelica.SIunits.MassFlowRate m_flow_small(min=0) = 1E-4*abs(m_flow_nominal)
          "Small mass flow rate for regularization of zero flow"
          annotation(Dialog(tab = "Advanced"));
        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));

        // Diagnostics
         parameter Boolean show_T = false
          "= true, if actual temperature at port is computed"
          annotation(Dialog(tab="Advanced",group="Diagnostics"));

        Modelica.SIunits.MassFlowRate m_flow(start=0) = port_a.m_flow
          "Mass flow rate from port_a to port_b (m_flow > 0 is design flow direction)";
        Modelica.SIunits.Pressure dp(start=0, displayUnit="Pa")
          "Pressure difference between port_a and port_b";

        Medium.ThermodynamicState sta_a=if homotopyInitialization then
            Medium.setState_phX(port_a.p,
                                homotopy(actual=noEvent(actualStream(port_a.h_outflow)),
                                         simplified=inStream(port_a.h_outflow)),
                                homotopy(actual=noEvent(actualStream(port_a.Xi_outflow)),
                                         simplified=inStream(port_a.Xi_outflow)))
          else
            Medium.setState_phX(port_a.p,
                                noEvent(actualStream(port_a.h_outflow)),
                                noEvent(actualStream(port_a.Xi_outflow))) if
               show_T "Medium properties in port_a";

        Medium.ThermodynamicState sta_b=if homotopyInitialization then
            Medium.setState_phX(port_b.p,
                                homotopy(actual=noEvent(actualStream(port_b.h_outflow)),
                                         simplified=port_b.h_outflow),
                                homotopy(actual=noEvent(actualStream(port_b.Xi_outflow)),
                                  simplified=port_b.Xi_outflow))
          else
            Medium.setState_phX(port_b.p,
                                noEvent(actualStream(port_b.h_outflow)),
                                noEvent(actualStream(port_b.Xi_outflow))) if
                show_T "Medium properties in port_b";
      equation
        dp = port_a.p - port_b.p;
        annotation (
          preferredView="info",
          Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Documentation(info="<html>
<p>
This component defines the interface for models that 
transports a fluid between two ports. It is similar to 
<a href=\"Modelica://Modelica.Fluid.Interfaces.PartialTwoPortTransport\">
Modelica.Fluid.Interfaces.PartialTwoPortTransport</a>, but it does not 
include the species balance
</p> 
<pre>
  port_b.Xi_outflow = inStream(port_a.Xi_outflow);
</pre>
<p>
Thus, it can be used as a base class for a heat <i>and</i> mass transfer component
</p>
<p>
The model is used by other models in this package that add heat transfer,
mass transfer and pressure drop equations. See for example
<a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger\">
Buildings.Fluid.Interfaces.StaticTwoPortHeatMassExchanger</a>.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 10, 2013 by Michael Wetter:<br/>
Added <code>noEvent</code> to the computation of the states at the port.
This is correct, because the states are only used for reporting, but not
to compute any other variable. 
Use of the states to compute other variables would violate the Modelica 
language, as conditionally removed variables must not be used in any equation.
</li>
<li>
October 8, 2013 by Michael Wetter:<br/>
Removed the computation of <code>V_flow</code> and removed the parameter
<code>show_V_flow</code>.
The reason is that the computation of <code>V_flow</code> required
the use of <code>sta_a</code> (to compute the density), 
but <code>sta_a</code> is also a variable that is conditionally
enabled. However, this was not correct Modelica syntax as conditional variables 
can only be used in a <code>connect</code>
statement, not in an assignment. Dymola 2014 FD01 beta3 is checking
for this incorrect syntax. Hence, <code>V_flow</code> was removed as its 
conditional implementation would require a rather cumbersome implementation
that uses a new connector that carries the state of the medium.
</li>
<li>
April 26, 2013 by Marco Bonvini:<br/>
Moved the definition of <code>dp</code> because it causes some problem with PyFMI.
</li>
<li>
March 27, 2012 by Michael Wetter:<br/>
Changed condition to remove <code>sta_a</code> to also
compute the state at the inlet port if <code>show_V_flow=true</code>. 
The previous implementation resulted in a translation error
if <code>show_V_flow=true</code>, but worked correctly otherwise
because the erroneous function call is removed if  <code>show_V_flow=false</code>.
</li>
<li>
March 27, 2011 by Michael Wetter:<br/>
Added <code>homotopy</code> operator.
</li>
<li>
March 21, 2010 by Michael Wetter:<br/>
Changed pressure start value from <code>system.p_start</code>
to <code>Medium.p_default</code> since HVAC models may have water and 
air, which are typically at different pressures.
</li>
<li>
September 19, 2008 by Michael Wetter:<br/>
Added equations for the mass balance of extra species flow,
i.e., <code>C</code> and <code>mC_flow</code>.
</li>
<li>
March 11, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end PartialTwoPortInterface;

      partial model PartialFourPortInterface
        "Partial model transporting fluid between two ports without storing mass or energy"
        import Modelica.Constants;
        extends CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.FourPort(
          port_a1(m_flow(min=if allowFlowReversal1 then -Constants.inf else 0)),
          port_b1(m_flow(max=if allowFlowReversal1 then +Constants.inf else 0)),
          port_a2(m_flow(min=if allowFlowReversal2 then -Constants.inf else 0)),
          port_b2(m_flow(max=if allowFlowReversal2 then +Constants.inf else 0)));

        parameter Modelica.SIunits.MassFlowRate m1_flow_nominal(min=0)
          "Nominal mass flow rate"
          annotation(Dialog(group = "Nominal condition"));
        parameter Modelica.SIunits.MassFlowRate m2_flow_nominal(min=0)
          "Nominal mass flow rate"
          annotation(Dialog(group = "Nominal condition"));
        parameter Medium1.MassFlowRate m1_flow_small(min=0) = 1E-4*abs(m1_flow_nominal)
          "Small mass flow rate for regularization of zero flow"
          annotation(Dialog(tab = "Advanced"));
        parameter Medium2.MassFlowRate m2_flow_small(min=0) = 1E-4*abs(m2_flow_nominal)
          "Small mass flow rate for regularization of zero flow"
          annotation(Dialog(tab = "Advanced"));
        parameter Boolean homotopyInitialization = true
          "= true, use homotopy method"
          annotation(Evaluate=true, Dialog(tab="Advanced"));
        // Diagnostics
        parameter Boolean show_T = false
          "= true, if actual temperature at port is computed"
          annotation(Dialog(tab="Advanced",group="Diagnostics"));
        Medium1.MassFlowRate m1_flow(start=0) = port_a1.m_flow
          "Mass flow rate from port_a1 to port_b1 (m1_flow > 0 is design flow direction)";
        Modelica.SIunits.Pressure dp1(start=0, displayUnit="Pa")
          "Pressure difference between port_a1 and port_b1";
        Medium2.MassFlowRate m2_flow(start=0) = port_a2.m_flow
          "Mass flow rate from port_a2 to port_b2 (m2_flow > 0 is design flow direction)";
        Modelica.SIunits.Pressure dp2(start=0, displayUnit="Pa")
          "Pressure difference between port_a2 and port_b2";
        Medium1.ThermodynamicState sta_a1=if homotopyInitialization then
            Medium1.setState_phX(port_a1.p,
               homotopy(actual=noEvent(actualStream(port_a1.h_outflow)),
                        simplified=inStream(port_a1.h_outflow)),
               homotopy(actual=noEvent(actualStream(port_a1.Xi_outflow)),
                        simplified=inStream(port_a1.Xi_outflow)))
          else
            Medium1.setState_phX(port_a1.p,
                                 noEvent(actualStream(port_a1.h_outflow)),
                                 noEvent(actualStream(port_a1.Xi_outflow))) if
               show_T "Medium properties in port_a1";

        Medium1.ThermodynamicState sta_b1=if homotopyInitialization then
            Medium1.setState_phX(port_b1.p,
                homotopy(actual=noEvent(actualStream(port_b1.h_outflow)),
                         simplified=port_b1.h_outflow),
                homotopy(actual=noEvent(actualStream(port_b1.Xi_outflow)),
                         simplified=port_b1.Xi_outflow))
          else
            Medium1.setState_phX(port_b1.p,
                                 noEvent(actualStream(port_b1.h_outflow)),
                                 noEvent(actualStream(port_b1.Xi_outflow))) if
               show_T "Medium properties in port_b1";

        Medium2.ThermodynamicState sta_a2=if homotopyInitialization then
            Medium2.setState_phX(port_b2.p,
                homotopy(actual=noEvent(actualStream(port_a2.h_outflow)),
                         simplified=inStream(port_a2.h_outflow)),
                homotopy(actual=noEvent(actualStream(port_a2.Xi_outflow)),
                         simplified=inStream(port_a2.Xi_outflow)))
          else
            Medium2.setState_phX(port_a2.p,
                                 noEvent(actualStream(port_a2.h_outflow)),
                                 noEvent(actualStream(port_a2.Xi_outflow))) if
               show_T "Medium properties in port_a2";

        Medium2.ThermodynamicState sta_b2=if homotopyInitialization then
            Medium2.setState_phX(port_b2.p,
                homotopy(actual=noEvent(actualStream(port_b2.h_outflow)),
                         simplified=port_b2.h_outflow),
                homotopy(actual=noEvent(actualStream(port_b2.Xi_outflow)),
                         simplified=port_b2.Xi_outflow))
          else
            Medium2.setState_phX(port_b2.p,
                                 noEvent(actualStream(port_b2.h_outflow)),
                                 noEvent(actualStream(port_b2.Xi_outflow))) if
               show_T "Medium properties in port_b2";
      protected
        Medium1.ThermodynamicState state_a1_inflow=
          Medium1.setState_phX(port_a1.p, inStream(port_a1.h_outflow), inStream(port_a1.Xi_outflow))
          "state for medium inflowing through port_a1";
        Medium1.ThermodynamicState state_b1_inflow=
          Medium1.setState_phX(port_b1.p, inStream(port_b1.h_outflow), inStream(port_b1.Xi_outflow))
          "state for medium inflowing through port_b1";
        Medium2.ThermodynamicState state_a2_inflow=
          Medium2.setState_phX(port_a2.p, inStream(port_a2.h_outflow), inStream(port_a2.Xi_outflow))
          "state for medium inflowing through port_a2";
        Medium2.ThermodynamicState state_b2_inflow=
          Medium2.setState_phX(port_b2.p, inStream(port_b2.h_outflow), inStream(port_b2.Xi_outflow))
          "state for medium inflowing through port_b2";
      equation
        dp1 = port_a1.p - port_b1.p;
        dp2 = port_a2.p - port_b2.p;
        annotation (
        preferredView="info",
          Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Documentation(info="<html>
<p>
This component defines the interface for models that 
transport two fluid streams between four ports. 
It is similar to 
<a href=\"modelica://Buildings.Fluid.Interfaces.PartialTwoPortInterface\">
Buildings.Fluid.Interfaces.PartialTwoPortInterface</a>,
but it has four ports instead of two.
<p>
The model is used by other models in this package that add heat transfer,
mass transfer and pressure drop equations.
</p>
</html>",       revisions="<html>
<ul>
<li>
October 10, 2013 by Michael Wetter:<br/>
Added <code>noEvent</code> to the computation of the states at the port.
This is correct, because the states are only used for reporting, but not
to compute any other variable. 
Use of the states to compute other variables would violate the Modelica 
language, as conditionally removed variables must not be used in any equation.
</li>
<li>
October 8, 2013 by Michael Wetter:<br/>
Removed the computation of <code>V_flow</code> and removed the parameter
<code>show_V_flow</code>.
The reason is that the computation of <code>V_flow</code> required
the use of <code>sta_a</code> (to compute the density), 
but <code>sta_a</code> is also a variable that is conditionally
enabled. However, this was not correct Modelica syntax as conditional variables 
can only be used in a <code>connect</code>
statement, not in an assignment. Dymola 2014 FD01 beta3 is checking
for this incorrect syntax. Hence, <code>V_flow</code> was removed as its 
conditional implementation would require a rather cumbersome implementation
that uses a new connector that carries the state of the medium.
</li>
<li>
April 26, 2013 by Marco Bonvini:<br/>
Moved the definitions of <code>dp1</code> and <code>dp2</code> because they cause some problem with PyFMI.
</li>
<li>
March 27, 2012 by Michael Wetter:<br/>
Replaced the erroneous function call <code>Medium.density</code> with 
<code>Medium1.density</code> and <code>Medium2.density</code>.
Changed condition to remove <code>sta_a1</code> and <code>sta_a2</code> to also
compute the states at the inlet port if <code>show_V_flow=true</code>. 
The previous implementation resulted in a translation error
if <code>show_V_flow=true</code>, but worked correctly otherwise
because the erroneous function call is removed if  <code>show_V_flow=false</code>.
</li>
<li>
March 27, 2011 by Michael Wetter:<br/>
Added <code>homotopy</code> operator.
</li>
<li>
March 21, 2010 by Michael Wetter:<br/>
Changed pressure start value from <code>system.p_start</code>
to <code>Medium.p_default</code> since HVAC models may have water and 
air, which are typically at different pressures.
</li>
<li>
September 19, 2008 by Michael Wetter:<br/>
Added equations for the mass balance of extra species flow,
i.e., <code>C</code> and <code>mC_flow</code>.
</li>
<li>
April 28, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end PartialFourPortInterface;

      model ConservationEquation "Lumped volume with mass and energy balance"

      //  outer Modelica.Fluid.System system "System properties";
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.LumpedVolumeDeclarations;
        // Port definitions
        parameter Integer nPorts=0 "Number of ports"
          annotation(Evaluate=true, Dialog(connectorSizing=true, tab="General",group="Ports"));
        Modelica.Fluid.Vessels.BaseClasses.VesselFluidPorts_b ports[nPorts](
            redeclare each package Medium = Medium) "Fluid inlets and outlets"
          annotation (Placement(transformation(extent={{-40,-10},{40,10}},
            origin={0,-100})));

        // Set nominal attributes where literal values can be used.
        Medium.BaseProperties medium(
          preferredMediumStates= not (energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState),
          p(start=p_start,
            nominal=Medium.p_default,
            stateSelect=if not (massDynamics == Modelica.Fluid.Types.Dynamics.SteadyState)
                           then StateSelect.prefer else StateSelect.default),
          h(start=hStart),
          T(start=T_start,
            nominal=Medium.T_default,
            stateSelect=if (not (energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState))
                           then StateSelect.prefer else StateSelect.default),
          Xi(start=X_start[1:Medium.nXi],
             nominal=Medium.X_default[1:Medium.nXi],
             each stateSelect=if (not (substanceDynamics == Modelica.Fluid.Types.Dynamics.SteadyState))
                           then StateSelect.prefer else StateSelect.default),
          d(start=rho_nominal)) "Medium properties";

        Modelica.SIunits.Energy U "Internal energy of fluid";
        Modelica.SIunits.Mass m "Mass of fluid";
        Modelica.SIunits.Mass[Medium.nXi] mXi
          "Masses of independent components in the fluid";
        Modelica.SIunits.Mass[Medium.nC] mC
          "Masses of trace substances in the fluid";
        // C need to be added here because unlike for Xi, which has medium.Xi,
        // there is no variable medium.C
        Medium.ExtraProperty C[Medium.nC](nominal=C_nominal)
          "Trace substance mixture content";

        Modelica.SIunits.MassFlowRate mb_flow "Mass flows across boundaries";
        Modelica.SIunits.MassFlowRate[Medium.nXi] mbXi_flow
          "Substance mass flows across boundaries";
        Medium.ExtraPropertyFlowRate[Medium.nC] mbC_flow
          "Trace substance mass flows across boundaries";
        Modelica.SIunits.EnthalpyFlowRate Hb_flow
          "Enthalpy flow across boundaries or energy source/sink";

        // Inputs that need to be defined by an extending class
        input Modelica.SIunits.Volume fluidVolume "Volume";

        Modelica.Blocks.Interfaces.RealInput Q_flow(unit="W")
          "Heat transfered into the medium"
          annotation (Placement(transformation(extent={{-140,40},{-100,80}})));
        Modelica.Blocks.Interfaces.RealInput mWat_flow(unit="kg/s")
          "Moisture mass flow rate added to the medium"
          annotation (Placement(transformation(extent={{-140,0},{-100,40}})));

        // Outputs that are needed in models that extend this model
        Modelica.Blocks.Interfaces.RealOutput hOut(unit="J/kg",
                                                   start=hStart)
          "Leaving enthalpy of the component"
           annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-50,110})));
        Modelica.Blocks.Interfaces.RealOutput XiOut[Medium.nXi](each unit="1",
                                                                each min=0,
                                                                each max=1)
          "Leaving species concentration of the component"
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,110})));
        Modelica.Blocks.Interfaces.RealOutput COut[Medium.nC](each min=0)
          "Leaving trace substances of the component"
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={50,110})));
      protected
        parameter Boolean initialize_p = not Medium.singleState
          "= true to set up initial equations for pressure";

        Medium.EnthalpyFlowRate ports_H_flow[nPorts];
        Modelica.SIunits.MassFlowRate ports_mXi_flow[nPorts,Medium.nXi];
        Medium.ExtraPropertyFlowRate ports_mC_flow[nPorts,Medium.nC];

        parameter Modelica.SIunits.Density rho_nominal=Medium.density(
         Medium.setState_pTX(
           T=T_start,
           p=p_start,
           X=X_start[1:Medium.nXi])) "Density, used to compute fluid mass"
        annotation (Evaluate=true);

        // Parameter that is used to construct the vector mXi_flow
        final parameter Real s[Medium.nXi] = {if Modelica.Utilities.Strings.isEqual(string1=Medium.substanceNames[i],
                                                  string2="Water",
                                                  caseSensitive=false)
                                                  then 1 else 0 for i in 1:Medium.nXi}
          "Vector with zero everywhere except where species is";
        parameter Modelica.SIunits.SpecificEnthalpy hStart=
          Medium.specificEnthalpy_pTX(p_start, T_start, X_start)
          "Start value for specific enthalpy";
      initial equation
        // Assert that the substance with name 'water' has been found.
        assert(Medium.nXi == 0 or abs(sum(s)-1) < 1e-5,
            "If Medium.nXi > 1, then substance 'water' must be present for one component.'"
               + Medium.mediumName + "'.\n"
               + "Check medium model.");

        // Make sure that if energyDynamics is SteadyState, then
        // massDynamics is also SteadyState.
        // Otherwise, the system of ordinary differential equations may be inconsistent.
        if energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState then
          assert(massDynamics == energyDynamics, "
         If 'massDynamics == Modelica.Fluid.Types.Dynamics.SteadyState', then it is 
         required that 'energyDynamics==Modelica.Fluid.Types.Dynamics.SteadyState'.
         Otherwise, the system of equations may not be consistent.
         You need to select other parameter values.");
        end if;

        // initialization of balances
        if energyDynamics == Modelica.Fluid.Types.Dynamics.FixedInitial then
            medium.T = T_start;
        else
          if energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyStateInitial then
              der(medium.T) = 0;
          end if;
        end if;

        if massDynamics == Modelica.Fluid.Types.Dynamics.FixedInitial then
          if initialize_p then
            medium.p = p_start;
          end if;
        else
          if massDynamics == Modelica.Fluid.Types.Dynamics.SteadyStateInitial then
            if initialize_p then
              der(medium.p) = 0;
            end if;
          end if;
        end if;

        if substanceDynamics == Modelica.Fluid.Types.Dynamics.FixedInitial then
          medium.Xi = X_start[1:Medium.nXi];
        else
          if substanceDynamics == Modelica.Fluid.Types.Dynamics.SteadyStateInitial then
            der(medium.Xi) = zeros(Medium.nXi);
          end if;
        end if;

        if traceDynamics == Modelica.Fluid.Types.Dynamics.FixedInitial then
          C = C_start[1:Medium.nC];
        else
          if traceDynamics == Modelica.Fluid.Types.Dynamics.SteadyStateInitial then
            der(C) = zeros(Medium.nC);
          end if;
        end if;

      equation
        // Total quantities
        m = fluidVolume*medium.d;
        mXi = m*medium.Xi;
        U = m*medium.u;
        mC = m*C;

        hOut = medium.h;
        XiOut = medium.Xi;
        COut = C;

        for i in 1:nPorts loop
          ports_H_flow[i]     = ports[i].m_flow * actualStream(ports[i].h_outflow)
            "Enthalpy flow";
          ports_mXi_flow[i,:] = ports[i].m_flow * actualStream(ports[i].Xi_outflow)
            "Component mass flow";
          ports_mC_flow[i,:]  = ports[i].m_flow * actualStream(ports[i].C_outflow)
            "Trace substance mass flow";
        end for;

        for i in 1:Medium.nXi loop
          mbXi_flow[i] = sum(ports_mXi_flow[:,i]);
        end for;

        for i in 1:Medium.nC loop
          mbC_flow[i]  = sum(ports_mC_flow[:,i]);
        end for;

        mb_flow = sum(ports.m_flow);
        Hb_flow = sum(ports_H_flow);

        // Energy and mass balances
        if energyDynamics == Modelica.Fluid.Types.Dynamics.SteadyState then
          0 = Hb_flow + Q_flow;
        else
          der(U) = Hb_flow + Q_flow;
        end if;

        if massDynamics == Modelica.Fluid.Types.Dynamics.SteadyState then
          0 = mb_flow + mWat_flow;
        else
          der(m) = mb_flow + mWat_flow;
        end if;

        if substanceDynamics == Modelica.Fluid.Types.Dynamics.SteadyState then
          zeros(Medium.nXi) = mbXi_flow + mWat_flow * s;
        else
          der(mXi) = mbXi_flow + mWat_flow * s;
        end if;

        if traceDynamics == Modelica.Fluid.Types.Dynamics.SteadyState then
          zeros(Medium.nC)  = mbC_flow;
        else
          der(mC)  = mbC_flow;
        end if;

        // Properties of outgoing flows
        for i in 1:nPorts loop
            ports[i].p          = medium.p;
            ports[i].h_outflow  = medium.h;
            ports[i].Xi_outflow = medium.Xi;
            ports[i].C_outflow  = C;
        end for;

        annotation (
          Documentation(info="<html>
<p>
Basic model for an ideally mixed fluid volume with the ability to store mass and energy.
It implements a dynamic or a steady-state conservation equation for energy and mass fractions.
The model has zero pressure drop between its ports.
</p>
<h4>Implementation</h4>
<p>
When extending or instantiating this model, the input 
<code>fluidVolume</code>, which is the actual volume occupied by the fluid,
needs to be assigned.
For most components, this can be set to a parameter. However, for components such as 
expansion vessels, the fluid volume can change in time.
</p>
Input connectors of the model are
<ul>
<li>
<code>Q_flow</code>, which is the sensible plus latent heat flow rate added to the medium, and
</li>
<li>
<code>mWat_flow</code>, which is the moisture mass flow rate added to the medium.
</li>
</ul>
<p>
The model can be used as a dynamic model or as a steady-state model.
However, for a steady-state model with exactly two fluid ports connected, 
the model
<a href=\"modelica://Buildings.Fluid.Interfaces.StaticTwoPortConservationEquation\">
Buildings.Fluid.Interfaces.StaticTwoPortConservationEquation</a>
provides a more efficient implementation.
</p>
<p>
For models that instantiates this model, see
<a href=\"modelica://Buildings.Fluid.MixingVolumes.MixingVolume\">
Buildings.Fluid.MixingVolumes.MixingVolume</a> and
<a href=\"modelica://Buildings.Fluid.Storage.ExpansionVessel\">
Buildings.Fluid.Storage.ExpansionVessel</a>.
</p>
</html>",       revisions="<html>
<ul>
<li>
September 17, 2013 by Michael Wetter:<br/>
Added start value for <code>hOut</code>.
</li>
<li>September 10, 2013 by Michael Wetter:<br/>
Removed unrequired parameter <code>i_w</code>.<br/>
Corrected the syntax error
<code>Medium.ExtraProperty C[Medium.nC](each nominal=C_nominal)</code>
to
<code>Medium.ExtraProperty C[Medium.nC](nominal=C_nominal)</code>
because <code>C_nominal</code> is a vector. 
This syntax error caused a compilation error in OpenModelica.
</li>
<li>
July 30, 2013 by Michael Wetter:<br/>
Changed connector <code>mXi_flow[Medium.nXi]</code>
to a scalar input connector <code>mWat_flow</code>.
The reason is that <code>mXi_flow</code> does not allow
to compute the other components in <code>mX_flow</code> and
therefore leads to an ambiguous use of the model.
By only requesting <code>mWat_flow</code>, the mass balance
and species balance can be implemented correctly.
</li>
<li>
March 27, 2013 by Michael Wetter:<br/>
Removed wrong unit attribute of <code>COut</code>,
and added min and max attributes for <code>XiOut</code>.
</li>
<li>
July 31, 2011 by Michael Wetter:<br/>
Added test to stop model translation if the setting for
<code>energyBalance</code> and <code>massBalance</code>
can lead to inconsistent equations.
</li>
<li>
July 26, 2011 by Michael Wetter:<br/>
Removed the option to use <code>h_start</code>, as this
is not needed for building simulation. 
Also removed the reference to <code>Modelica.Fluid.System</code>.
Moved parameters and medium to 
<a href=\"Buildings.Fluid.Interfaces.LumpedVolumeDeclarations\">
Buildings.Fluid.Interfaces.LumpedVolumeDeclarations</a>.
<li>
July 14, 2011 by Michael Wetter:<br/>
Added start value for medium density.
</li>
<li>
March 29, 2011 by Michael Wetter:<br/>
Changed default value for <code>substanceDynamics</code> and
<code>traceDynamics</code> from <code>energyDynamics</code>
to <code>massDynamics</code>.
</li>
<li>
September 28, 2010 by Michael Wetter:<br/>
Changed array index for nominal value of <code>Xi</code>.
<li>
September 13, 2010 by Michael Wetter:<br/>
Set nominal attributes for medium based on default medium values.
</li>
<li>
July 30, 2010 by Michael Wetter:<br/>
Added parameter <code>C_nominal</code> which is used as the nominal attribute for <code>C</code>.
Without this value, the ODE solver gives wrong results for concentrations around 1E-7.
</li>
<li>
March 21, 2010 by Michael Wetter:<br/>
Changed pressure start value from <code>system.p_start</code>
to <code>Medium.p_default</code> since HVAC models may have water and 
air, which are typically at different pressures.
</li>
<li><i>February 6, 2010</i> by Michael Wetter:<br/>
Added to <code>Medium.BaseProperties</code> the initialization 
<code>X(start=X_start[1:Medium.nX])</code>. Previously, the initialization
was only done for <code>Xi</code> but not for <code>X</code>, which caused the
medium to be initialized to <code>reference_X</code>, ignoring the value of <code>X_start</code>.
</li>
<li><i>October 12, 2009</i> by Michael Wetter:<br/>
Implemented first version in <code>Buildings</code> library, based on model from
<code>Modelica.Fluid 1.0</code>.
</li>
</ul>
</html>"),Diagram(coordinateSystem(preserveAspectRatio=true,  extent={{-100,-100},{
                  100,100}}),
                  graphics),
          Icon(graphics={            Rectangle(
                extent={{-100,100},{100,-100}},
                fillColor={135,135,135},
                fillPattern=FillPattern.Solid,
                pattern=LinePattern.None),
              Text(
                extent={{-89,17},{-54,34}},
                lineColor={0,0,127},
                textString="mWat_flow"),
              Text(
                extent={{-89,52},{-54,69}},
                lineColor={0,0,127},
                textString="Q_flow"),
              Line(points={{-56,-73},{81,-73}}, color={255,255,255}),
              Line(points={{-42,55},{-42,-84}}, color={255,255,255}),
              Polygon(
                points={{-42,67},{-50,45},{-34,45},{-42,67}},
                lineColor={255,255,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{87,-73},{65,-65},{65,-81},{87,-73}},
                lineColor={255,255,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-42,-28},{-6,-28},{18,4},{40,12},{66,14}},
                color={255,255,255},
                smooth=Smooth.Bezier),
              Text(
                extent={{-155,-120},{145,-160}},
                lineColor={0,0,255},
                textString="%name")}));
      end ConservationEquation;

      model StaticTwoPortConservationEquation
        "Partial model for static energy and mass conservation equations"
        extends
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.PartialTwoPortInterface(
            showDesignFlowDirection=false);

        constant Boolean sensibleOnly "Set to true if sensible exchange only";

        Modelica.Blocks.Interfaces.RealInput Q_flow(unit="W")
          "Heat transfered into the medium"
          annotation (Placement(transformation(extent={{-140,60},{-100,100}})));
        Modelica.Blocks.Interfaces.RealInput mWat_flow(unit="kg/s")
          "Moisture mass flow rate added to the medium"
          annotation (Placement(transformation(extent={{-140,20},{-100,60}})));

        // Outputs that are needed in models that extend this model
        Modelica.Blocks.Interfaces.RealOutput hOut(unit="J/kg",
                                                   start=Medium.specificEnthalpy_pTX(
                                                           p=Medium.p_default,
                                                           T=Medium.T_default,
                                                           X=Medium.X_default))
          "Leaving temperature of the component"
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-50,110}), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-50,110})));

        Modelica.Blocks.Interfaces.RealOutput XiOut[Medium.nXi](each unit="1",
                                                                each min=0,
                                                                each max=1)
          "Leaving species concentration of the component"
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,110})));
        Modelica.Blocks.Interfaces.RealOutput COut[Medium.nC](each min=0)
          "Leaving trace substances of the component"
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={50,110})));

        constant Boolean use_safeDivision=true
          "Set to true to improve numerical robustness";
      protected
        Real m_flowInv(unit="s/kg") "Regularization of 1/m_flow";

        Modelica.SIunits.MassFlowRate mXi_flow[Medium.nXi]
          "Mass flow rates of independent substances added to the medium";

        // Parameters that is used to construct the vector mXi_flow
        final parameter Real s[Medium.nXi] = {if Modelica.Utilities.Strings.isEqual(string1=Medium.substanceNames[i],
                                                  string2="Water",
                                                  caseSensitive=false)
                                                  then 1 else 0 for i in 1:Medium.nXi}
          "Vector with zero everywhere except where species is";

      initial equation
        // Assert that the substance with name 'water' has been found.
        assert(Medium.nXi == 0 or abs(sum(s)-1) < 1e-5,
            "If Medium.nXi > 1, then substance 'water' must be present for one component.'"
               + Medium.mediumName + "'.\n"
               + "Check medium model.");

      equation
       // Species flow rate from connector mWat_flow
       mXi_flow = mWat_flow * s;
        // Regularization of m_flow around the origin to avoid a division by zero
       if use_safeDivision then
          m_flowInv = Buildings.Utilities.Math.Functions.inverseXRegularized(x=port_a.m_flow, delta=m_flow_small/1E3);
       else
           m_flowInv = 0; // m_flowInv is not used if use_safeDivision = false.
       end if;

       if allowFlowReversal then
         // Formulate hOut using spliceFunction. This avoids an event iteration.
         // The introduced error is small because deltax=m_flow_small/1e3
         hOut = Buildings.Utilities.Math.Functions.spliceFunction(pos=port_b.h_outflow,
                                                                  neg=port_a.h_outflow,
                                                                  x=port_a.m_flow,
                                                                  deltax=m_flow_small/1E3);
         XiOut = Buildings.Utilities.Math.Functions.spliceFunction(pos=port_b.Xi_outflow,
                                                                  neg=port_a.Xi_outflow,
                                                                  x=port_a.m_flow,
                                                                  deltax=m_flow_small/1E3);
         COut = Buildings.Utilities.Math.Functions.spliceFunction(pos=port_b.C_outflow,
                                                                  neg=port_a.C_outflow,
                                                                  x=port_a.m_flow,
                                                                  deltax=m_flow_small/1E3);
       else
         hOut =  port_b.h_outflow;
         XiOut = port_b.Xi_outflow;
         COut =  port_b.C_outflow;
       end if;

        //////////////////////////////////////////////////////////////////////////////////////////
        // Energy balance and mass balance
        if sensibleOnly then
          // Mass balance
          port_a.m_flow = -port_b.m_flow;
          // Energy balance
          if use_safeDivision then
            port_b.h_outflow = inStream(port_a.h_outflow) + Q_flow * m_flowInv;
            port_a.h_outflow = inStream(port_b.h_outflow) - Q_flow * m_flowInv;
          else
            port_a.m_flow * (inStream(port_a.h_outflow) - port_b.h_outflow) = -Q_flow;
            port_a.m_flow * (inStream(port_b.h_outflow) - port_a.h_outflow) = +Q_flow;
          end if;
          // Transport of species
          port_a.Xi_outflow = inStream(port_b.Xi_outflow);
          port_b.Xi_outflow = inStream(port_a.Xi_outflow);
          // Transport of trace substances
          port_a.C_outflow = inStream(port_b.C_outflow);
          port_b.C_outflow = inStream(port_a.C_outflow);
        else
          // Mass balance (no storage)
          port_a.m_flow + port_b.m_flow = -mWat_flow;
          // Energy balance.
          // This equation is approXimate since m_flow = port_a.m_flow is used for the mass flow rate
          // at both ports. Since mWat_flow << m_flow, the error is small.
          if use_safeDivision then
            port_b.h_outflow = inStream(port_a.h_outflow) + Q_flow * m_flowInv;
            port_a.h_outflow = inStream(port_b.h_outflow) - Q_flow * m_flowInv;
            // Transport of species
            port_b.Xi_outflow = inStream(port_a.Xi_outflow) + mXi_flow * m_flowInv;
            port_a.Xi_outflow = inStream(port_b.Xi_outflow) - mXi_flow * m_flowInv;
           else
            port_a.m_flow * (inStream(port_a.h_outflow) - port_b.h_outflow) = -Q_flow;
            port_a.m_flow * (inStream(port_b.h_outflow) - port_a.h_outflow) = +Q_flow;
            // Transport of species
            port_a.m_flow * (inStream(port_a.Xi_outflow) - port_b.Xi_outflow) = -mXi_flow;
            port_a.m_flow * (inStream(port_b.Xi_outflow) - port_a.Xi_outflow) = +mXi_flow;
           end if;

          // Transport of trace substances
         port_a.m_flow*port_a.C_outflow = -port_b.m_flow*inStream(port_b.C_outflow);
         port_b.m_flow*port_b.C_outflow = -port_a.m_flow*inStream(port_a.C_outflow);

        end if; // sensibleOnly

        //////////////////////////////////////////////////////////////////////////////////////////
        // No pressure drop in this model
        port_a.p = port_b.p;

        annotation (
          preferredView="info",
          Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics),
          Documentation(info="<html>
<p>
This model transports fluid between its two ports, without storing mass or energy. 
It implements a steady-state conservation equation for energy and mass fractions.
The model has zero pressure drop between its ports.
</p>
<h4>Implementation</h4>
Input connectors of the model are
<ul>
<li>
<code>Q_flow</code>, which is the sensible plus latent heat flow rate added to the medium, and
</li>
<li>
<code>mWat_flow</code>, which is the moisture mass flow rate added to the medium.
</li>
</ul>

<p>
The model can only be used as a steady-state model with two fluid ports.
For a model with a dynamic balance, and more fluid ports, use
<a href=\"modelica://Buildings.Fluid.Interfaces.ConservationEquation\">
Buildings.Fluid.Interfaces.ConservationEquation</a>.
</p>
<p>
Set the constant <code>sensibleOnly=true</code> if the model that extends
or instantiates this model sets <code>mWat_flow = 0</code>.
</p>
</html>",
      revisions="<html>
<ul>
<li>
October 21, 2013 by Michael Wetter:<br/>
Corrected sign error in the equation that is used if <code>use_safeDivision=false</code>
and <code>sensibleOnly=true</code>.
This only affects internal numerical tests, but not any examples in the library
as the constant <code>use_safeDivision</code> is set to <code>true</code> by default.
</li>
<li>
September 25, 2013 by Michael Wetter:<br/>
Reformulated computation of outlet properties to avoid an event at zero mass flow rate.
</li>
<li>
September 17, 2013 by Michael Wetter:<br/>
Added start value for <code>hOut</code>.
</li>
<li>September 10, 2013 by Michael Wetter:<br/>
Removed unrequired parameter <code>i_w</code>.
</li>
<li>
May 7, 2013 by Michael Wetter:<br/>
Removed <code>for</code> loops for species balance and trace substance balance, 
as they cause the error <code>Error: Operand port_a.Xi_outflow[1] to operator inStream is not a stream variable.</code>
in OpenModelica.
</li>
<li>
March 27, 2013 by Michael Wetter:<br/>
Removed wrong unit attribute of <code>COut</code>,
and added min and max attributes for <code>XiOut</code>.
</li>
<li>
June 22, 2012 by Michael Wetter:<br/>
Reformulated implementation with <code>m_flowInv</code> to use <code>port_a.m_flow * ...</code>
if <code>use_safeDivision=false</code>. This avoids a division by zero if 
<code>port_a.m_flow=0</code>.
</li>
<li>
February 7, 2012 by Michael Wetter:<br/>
Revised base classes for conservation equations in <code>Buildings.Fluid.Interfaces</code>.
</li>
<li>
December 14, 2011 by Michael Wetter:<br/>
Changed assignment of <code>hOut</code>, <code>XiOut</code> and
<code>COut</code> to no longer declare that it is continuous. 
The declaration of continuity, i.e, the 
<code>smooth(0, if (port_a.m_flow >= 0) then ...</code> declaration,
was required for Dymola 2012 to simulate, but it is no longer needed 
for Dymola 2012 FD01.
</li>
<li>
August 19, 2011, by Michael Wetter:<br/>
Changed assignment of <code>hOut</code>, <code>XiOut</code> and
<code>COut</code> to declare that it is not differentiable.
</li>
<li>
August 4, 2011, by Michael Wetter:<br/>
Moved linearized pressure drop equation from the function body to the equation
section. With the previous implementation, 
the symbolic processor may not rearrange the equations, which can lead 
to coupled equations instead of an explicit solution.
</li>
<li>
March 29, 2011, by Michael Wetter:<br/>
Changed energy and mass balance to avoid a division by zero if <code>m_flow=0</code>.
</li>
<li>
March 27, 2011, by Michael Wetter:<br/>
Added <code>homotopy</code> operator.
</li>
<li>
August 19, 2010, by Michael Wetter:<br/>
Fixed bug in energy and moisture balance that affected results if a component
adds or removes moisture to the air stream. 
In the old implementation, the enthalpy and species
outflow at <code>port_b</code> was multiplied with the mass flow rate at 
<code>port_a</code>. The old implementation led to small errors that were proportional
to the amount of moisture change. For example, if the moisture added by the component
was <code>0.005 kg/kg</code>, then the error was <code>0.5%</code>.
Also, the results for forward flow and reverse flow differed by this amount.
With the new implementation, the energy and moisture balance is exact.
</li>
<li>
March 22, 2010, by Michael Wetter:<br/>
Added constant <code>sensibleOnly</code> to 
simplify species balance equation.
</li>
<li>
April 10, 2009, by Michael Wetter:<br/>
Added model to compute flow friction.
</li>
<li>
April 22, 2008, by Michael Wetter:<br/>
Revised to add mass balance.
</li>
<li>
March 17, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Rectangle(
                extent={{-100,100},{100,-100}},
                fillColor={135,135,135},
                fillPattern=FillPattern.Solid,
                pattern=LinePattern.None),
              Text(
                extent={{-93,72},{-58,89}},
                lineColor={0,0,127},
                textString="Q_flow"),
              Text(
                extent={{-93,37},{-58,54}},
                lineColor={0,0,127},
                textString="mWat_flow"),
              Text(
                extent={{-41,103},{-10,117}},
                lineColor={0,0,127},
                textString="hOut"),
              Text(
                extent={{10,103},{41,117}},
                lineColor={0,0,127},
                textString="XiOut"),
              Text(
                extent={{61,103},{92,117}},
                lineColor={0,0,127},
                textString="COut"),
              Line(points={{-42,55},{-42,-84}}, color={255,255,255}),
              Polygon(
                points={{-42,67},{-50,45},{-34,45},{-42,67}},
                lineColor={255,255,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{87,-73},{65,-65},{65,-81},{87,-73}},
                lineColor={255,255,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{-56,-73},{81,-73}}, color={255,255,255}),
              Line(points={{6,14},{6,-37}},     color={255,255,255}),
              Line(points={{54,14},{6,14}},     color={255,255,255}),
              Line(points={{6,-37},{-42,-37}},  color={255,255,255})}));
      end StaticTwoPortConservationEquation;

      record TwoPortFlowResistanceParameters
        "Parameters for flow resistance for models with two ports"

        parameter Boolean computeFlowResistance = true
          "=true, compute flow resistance. Set to false to assume no friction"
          annotation (Evaluate=true, Dialog(tab="Flow resistance"));

        parameter Boolean from_dp = false
          "= true, use m_flow = f(dp) else dp = f(m_flow)"
          annotation (Evaluate=true, Dialog(enable = computeFlowResistance,
                      tab="Flow resistance"));
        parameter Modelica.SIunits.Pressure dp_nominal(min=0, displayUnit="Pa")
          "Pressure"                                annotation(Dialog(group = "Nominal condition"));
        parameter Boolean linearizeFlowResistance = false
          "= true, use linear relation between m_flow and dp for any flow rate"
          annotation(Dialog(enable = computeFlowResistance,
                     tab="Flow resistance"));
        parameter Real deltaM = 0.1
          "Fraction of nominal flow rate where flow transitions to laminar"
          annotation(Dialog(enable = computeFlowResistance, tab="Flow resistance"));

      annotation (preferredView="info",
      Documentation(info="<html>
This class contains parameters that are used to
compute the pressure drop in models that have one fluid stream.
Note that the nominal mass flow rate is not declared here because
the model 
<a href=\"modelica://Buildings.Fluid.Interfaces.PartialTwoPortInterface\">
PartialTwoPortInterface</a>
already declares it.
</html>",
      revisions="<html>
<ul>
<li>
April 13, 2009, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end TwoPortFlowResistanceParameters;

      record FourPortFlowResistanceParameters
        "Parameters for flow resistance for models with four ports"

        parameter Boolean computeFlowResistance1 = true
          "=true, compute flow resistance. Set to false to assume no friction"
          annotation (Evaluate=true, Dialog(tab="Flow resistance", group="Medium 1"));

        parameter Boolean from_dp1 = false
          "= true, use m_flow = f(dp) else dp = f(m_flow)"
          annotation (Evaluate=true, Dialog(enable = computeFlowResistance1,
                      tab="Flow resistance", group="Medium 1"));
        parameter Modelica.SIunits.Pressure dp1_nominal(min=0, displayUnit="Pa")
          "Pressure" annotation(Dialog(group = "Nominal condition"));
        parameter Boolean linearizeFlowResistance1 = false
          "= true, use linear relation between m_flow and dp for any flow rate"
          annotation(Dialog(enable = computeFlowResistance1,
                     tab="Flow resistance", group="Medium 1"));
        parameter Real deltaM1 = 0.1
          "Fraction of nominal flow rate where flow transitions to laminar"
          annotation(Dialog(enable = computeFlowResistance1,
                            tab="Flow resistance", group="Medium 1"));
        parameter Boolean computeFlowResistance2 = true
          "=true, compute flow resistance. Set to false to assume no friction"
          annotation (Evaluate=true, Dialog(tab="Flow resistance", group="Medium 2"));

        parameter Boolean from_dp2 = false
          "= true, use m_flow = f(dp) else dp = f(m_flow)"
          annotation (Evaluate=true, Dialog(enable = computeFlowResistance2,
                      tab="Flow resistance", group="Medium 2"));
        parameter Modelica.SIunits.Pressure dp2_nominal(min=0, displayUnit="Pa")
          "Pressure" annotation(Dialog(group = "Nominal condition"));
        parameter Boolean linearizeFlowResistance2 = false
          "= true, use linear relation between m_flow and dp for any flow rate"
          annotation(Dialog(enable = computeFlowResistance2,
                     tab="Flow resistance", group="Medium 2"));
        parameter Real deltaM2 = 0.1
          "Fraction of nominal flow rate where flow transitions to laminar"
          annotation(Dialog(enable = computeFlowResistance2,
                            tab="Flow resistance", group="Medium 2"));
      annotation (preferredView="info",
      Documentation(info="<html>
This class contains parameters that are used to
compute the pressure drop in components that have two fluid streams.
Note that the nominal mass flow rate is not declared here because
the model 
<a href=\"modelica://Buildings.Fluid.Interfaces.PartialFourPortInterface\">
PartialFourPortInterface</a>
already declares it.
</html>",
      revisions="<html>
<ul>
<li>
April 13, 2009, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end FourPortFlowResistanceParameters;

      record LumpedVolumeDeclarations "Declarations for lumped volumes"
        replaceable package Medium =
          Modelica.Media.Interfaces.PartialMedium "Medium in the component"
            annotation (choicesAllMatching = true);

        // Assumptions
        parameter Modelica.Fluid.Types.Dynamics energyDynamics=Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
          "Formulation of energy balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));
        parameter Modelica.Fluid.Types.Dynamics massDynamics=energyDynamics
          "Formulation of mass balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));
        final parameter Modelica.Fluid.Types.Dynamics substanceDynamics=energyDynamics
          "Formulation of substance balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));
        final parameter Modelica.Fluid.Types.Dynamics traceDynamics=energyDynamics
          "Formulation of trace substance balance"
          annotation(Evaluate=true, Dialog(tab = "Dynamics", group="Equations"));

        // Initialization
        parameter Medium.AbsolutePressure p_start = Medium.p_default
          "Start value of pressure"
          annotation(Dialog(tab = "Initialization"));
        parameter Medium.Temperature T_start=Medium.T_default
          "Start value of temperature"
          annotation(Dialog(tab = "Initialization"));
        parameter Medium.MassFraction X_start[Medium.nX] = Medium.X_default
          "Start value of mass fractions m_i/m"
          annotation (Dialog(tab="Initialization", enable=Medium.nXi > 0));
        parameter Medium.ExtraProperty C_start[Medium.nC](
             quantity=Medium.extraPropertiesNames)=fill(0, Medium.nC)
          "Start value of trace substances"
          annotation (Dialog(tab="Initialization", enable=Medium.nC > 0));
        parameter Medium.ExtraProperty C_nominal[Medium.nC](
             quantity=Medium.extraPropertiesNames) = fill(1E-2, Medium.nC)
          "Nominal value of trace substances. (Set to typical order of magnitude.)"
         annotation (Dialog(tab="Initialization", enable=Medium.nC > 0));

      annotation (preferredView="info",
      Documentation(info="<html>
<p>
This class contains parameters and medium properties
that are used in the lumped  volume model, and in models that extend the 
lumped volume model.
</p>
<p>
These parameters are used by
<a href=\"modelica://Buildings.Fluid.Interfaces.ConservationEquation\">
Buildings.Fluid.Interfaces.ConservationEquation</a>,
<a href=\"modelica://Buildings.Fluid.MixingVolumes.MixingVolume\">
Buildings.Fluid.MixingVolumes.MixingVolume</a>,
<a href=\"modelica://Buildings.Rooms.MixedAir\">
Buildings.Rooms.MixedAir</a>, and by
<a href=\"modelica://Buildings.Rooms.BaseClasses.MixedAir\">
Buildings.Rooms.BaseClasses.MixedAir</a>.
</p>
</html>",
      revisions="<html>
<ul>
<li>
August 2, 2011, by Michael Wetter:<br/>
Set <code>substanceDynamics</code> and <code>traceDynamics</code> to final
and equal to <code>energyDynamics</code>, 
as there is no need to make them different from <code>energyDynamics</code>.
</li>
<li>
August 1, 2011, by Michael Wetter:<br/>
Changed default value for <code>energyDynamics</code> to
<code>Modelica.Fluid.Types.Dynamics.DynamicFreeInitial</code> because
<code>Modelica.Fluid.Types.Dynamics.SteadyStateInitial</code> leads
to high order DAE that Dymola cannot reduce.
</li>
<li>
July 31, 2011, by Michael Wetter:<br/>
Changed default value for <code>energyDynamics</code> to
<code>Modelica.Fluid.Types.Dynamics.SteadyStateInitial</code>.
</li>
<li>
April 13, 2009, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
      end LumpedVolumeDeclarations;

      package Examples
        "Collection of models that illustrate model use and test models"
        extends Modelica.Icons.ExamplesPackage;

        model ConservationEquation "Model that tests the conservation equation"
        extends Modelica.Icons.Example;
         package Medium = Buildings.Media.ConstantPropertyLiquidWater
            "Medium model";
          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.ConservationEquation
            dyn(
            redeclare package Medium = Medium,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
            nPorts=2,
            fluidVolume=0.01) "Dynamic conservation equation"
            annotation (Placement(transformation(extent={{-10,30},{10,50}})));

          CO2GCHPModels_Master_Monjur.Boreholes.Interfaces.StaticTwoPortConservationEquation
            ste(
            redeclare package Medium = Medium,
            m_flow_nominal=0.01,
            sensibleOnly=false,
            show_T=true) "Steady-state conservation equation"
            annotation (Placement(transformation(extent={{-10,-70},{10,-50}})));

          Modelica.Blocks.Sources.Constant mWat_flow(k=0)
            "Water mass flow rate added to the control volume"
            annotation (Placement(transformation(extent={{-80,20},{-60,40}})));
          Modelica.Blocks.Sources.TimeTable QSen_flow(startTime=0, table=[
                                        0,-100;
                                        900,-100;
                                        900,0;
                                        1800,0;
                                        1800,100])
            "Sensible heat flow rate added to the control volume"
            annotation (Placement(transformation(extent={{-80,60},{-60,80}})));
          Buildings.Fluid.Sources.Boundary_pT sin(
            nPorts=2,
            use_p_in=false,
            redeclare package Medium = Medium,
            p=101325,
            T=283.15)
              annotation (Placement(
                transformation(extent={{80,-68},{60,-48}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res1(
            from_dp=true,
            redeclare package Medium = Medium,
            m_flow_nominal=0.01,
            dp_nominal=100) "Flow resistance"
              annotation (Placement(transformation(extent={{20,-10},{40,10}},
                  rotation=0)));
          Buildings.Fluid.Sources.MassFlowSource_T bou(
            nPorts=2,
            redeclare package Medium = Medium,
            m_flow=0.01) "Boundary condition for mass flow rate"
            annotation (Placement(transformation(extent={{-80,-68},{-60,-48}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res2(
            from_dp=true,
            redeclare package Medium = Medium,
            m_flow_nominal=0.01,
            dp_nominal=100) "Flow resistance"
                     annotation (Placement(transformation(extent={{20,-70},{40,-50}},
                  rotation=0)));
          inner Modelica.Fluid.System system
            annotation (Placement(transformation(extent={{60,60},{80,80}})));
        equation
          connect(QSen_flow.y, dyn.Q_flow) annotation (Line(
              points={{-59,70},{-48,70},{-48,46},{-12,46}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(mWat_flow.y, dyn.mWat_flow) annotation (Line(
              points={{-59,30},{-40,30},{-40,42},{-12,42}},
              color={0,0,127},
              smooth=Smooth.None));

          connect(bou.ports[1], dyn.ports[1]) annotation (Line(
              points={{-60,-56},{-54,-56},{-54,20},{-2,20},{-2,30}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res1.port_b, sin.ports[1]) annotation (Line(
              points={{40,0},{52,0},{52,-56},{60,-56}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(QSen_flow.y, ste.Q_flow) annotation (Line(
              points={{-59,70},{-48,70},{-48,-52},{-12,-52}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(mWat_flow.y, ste.mWat_flow) annotation (Line(
              points={{-59,30},{-40,30},{-40,-56},{-12,-56}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(res2.port_b, sin.ports[2]) annotation (Line(
              points={{40,-60},{60,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(ste.port_a, bou.ports[2]) annotation (Line(
              points={{-10,-60},{-60,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(ste.port_b, res2.port_a) annotation (Line(
              points={{10,-60},{20,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(dyn.ports[2], res1.port_a) annotation (Line(
              points={{2,30},{0,30},{0,0},{20,0}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation (
          experiment(StopTime=3600),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/Interfaces/Examples/ConservationEquation.mos"
                "Simulate and plot"),
        Documentation(info="<html>
<p>
Model that tests the conservation equations that are used 
for the heat and mass balance.
</p>
</html>",
        revisions="<html>
<ul>
<li>
September 11, 2013, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),  Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
                    100}}), graphics));
        end ConservationEquation;

        model HeaterCoolerPrescribed
          "Model that tests a heat exchanger model with reverse flow"
          extends Modelica.Icons.Example;

         package Medium = Buildings.Media.ConstantPropertyLiquidWater;

          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea1(
                                                                 redeclare
              package Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{-14,90},{6,110}},   rotation=0)));
          Modelica.Blocks.Sources.Constant TDb(k=293.15) "Drybulb temperature"
            annotation (Placement(transformation(extent={{-200,94},{-180,114}},
                  rotation=0)));
          Buildings.Fluid.Sources.Boundary_pT sou_1(
            redeclare package Medium = Medium,
            use_T_in=true,
            nPorts=4,
            p(displayUnit="Pa") = 101735,
            T=293.15)             annotation (Placement(transformation(extent={{-170,90},
                    {-150,110}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_11(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,90},{-80,110}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_12(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,134},{-80,154}},
                  rotation=0)));
          Buildings.Fluid.Sources.Boundary_pT sin_1(                       redeclare
              package Medium = Medium,
            use_p_in=true,
            T=288.15,
            nPorts=4)             annotation (Placement(transformation(extent={{-168,
                    132},{-148,152}}, rotation=0)));
            Modelica.Blocks.Sources.Constant POut(k=101325)
              annotation (Placement(transformation(extent={{-200,140},{-180,160}},
                  rotation=0)));
            Modelica.Blocks.Sources.Ramp u(
            height=2,
            duration=3600,
            offset=-1,
            startTime=0) "Control signal"
                         annotation (Placement(transformation(extent={{-148,174},{-128,
                    194}}, rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea2(
                                                         redeclare package
              Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{28,134},{48,154}}, rotation=0)));
          Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(
                  extent={{-50,174},{-30,194}}, rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea3(
                                                                 redeclare
              package Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                   annotation (Placement(
                transformation(extent={{-14,-30},{6,-10}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_2(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-30},{-80,-10}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_3(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,22},{-80,42}},
                  rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea4(
                                                         redeclare package
              Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                   annotation (Placement(
                transformation(extent={{20,22},{40,42}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_4(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(
                origin={90,32},
                extent={{-10,-10},{10,10}},
                rotation=180)));
          Buildings.Fluid.MixingVolumes.MixingVolume mix1(
                                                   redeclare package Medium = Medium, V=
               0.000001,
            nPorts=2,
            m_flow_nominal=0.5,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
                         annotation (Placement(transformation(extent={{62,-20},{82,0}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass1(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,160},{180,180}}, rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass2(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,116},{180,136}}, rotation=
                   0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea5(
                                                                 redeclare
              package Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{-10,-190},{10,-170}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_1(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-190},{-80,-170}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_5(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-130},{-80,-110}},
                  rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea6(
                                                         redeclare package
              Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{0,-130},{20,-110}},rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea7(
                                                                 redeclare
              package Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{-10,-330},{10,-310}},  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_6(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-330},{-80,-310}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_7(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-270},{-80,-250}},
                  rotation=0)));
          Buildings.Fluid.HeatExchangers.HeaterCoolerPrescribed hea8(
                                                         redeclare package
              Medium =
                Medium, Q_flow_nominal=5000,
            m_flow_nominal=0.5,
            dp_nominal=200,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                                  annotation (Placement(
                transformation(extent={{0,-270},{20,-250}},  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_8(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(
                origin={90,-260},
                extent={{-10,-10},{10,10}},
                rotation=180)));
          Buildings.Fluid.MixingVolumes.MixingVolume mix2(
                                                   redeclare package Medium = Medium, V=
               0.000001,
            nPorts=2,
            m_flow_nominal=0.5,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
                         annotation (Placement(transformation(extent={{60,-320},{80,
                    -300}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass9(
                     threShold=0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-400},{180,-380}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass10(
                     threShold=0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-360},{180,-340}},
                  rotation=0)));
          inner Modelica.Fluid.System system(m_flow_start=0, energyDynamics=Modelica.Fluid.Types.Dynamics.SteadyState)
            annotation (Placement(transformation(extent={{-180,-380},{-160,-360}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem2a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-8,136},{8,152}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem2b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{56,136},{72,152}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem1a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-48,92},{-32,108}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem1b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{22,92},{38,108}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem3a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-48,-28},{-32,-12}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem3b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{20,-30},{40,-10}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem4a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-12,22},{8,42}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem4b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{50,22},{70,42}})));
          Buildings.Utilities.Diagnostics.AssertEquality ass3(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,0},{180,20}},    rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass4(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,60},{180,80}},   rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass5(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-164},{180,-144}},
                                                                               rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass6(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-100},{180,-80}},rotation=
                   0)));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem6b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{40,-130},{60,-110}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem6a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-60,-130},{-40,-110}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem5b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{20,-190},{40,-170}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem5a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-60,-190},{-40,-170}})));
          Buildings.Utilities.Diagnostics.AssertEquality ass7(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-284},{180,-264}},
                                                                               rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass8(               threShold=
                0.05, startTime=600)
            annotation (Placement(transformation(extent={{160,-240},{180,-220}},
                                                                               rotation=
                   0)));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem8b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{36,-272},{60,-248}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem8a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-60,-270},{-40,-250}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem7b(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{20,-330},{40,-310}})));
          Buildings.Fluid.Sensors.TemperatureTwoPort
                                              senTem7a(redeclare package Medium
              =                                                                   Medium,
            m_flow_nominal=0.5,
            tau=0) "Temperature sensor"
            annotation (Placement(transformation(extent={{-60,-330},{-40,-310}})));
        equation
          connect(POut.y,sin_1. p_in) annotation (Line(
              points={{-179,150},{-170,150}},
              color={0,0,127},
              pattern=LinePattern.None));
          connect(TDb.y,sou_1. T_in) annotation (Line(
              points={{-179,104},{-176,104},{-172,104}},
              color={0,0,127},
              pattern=LinePattern.None));
          connect(u.y, hea1.u)
                              annotation (Line(points={{-127,184},{-70,184},{-70,160},{
                  -28,160},{-28,106},{-16,106}},
                             color={0,0,127}));
          connect(gain.y, hea2.u) annotation (Line(points={{-29,184},{-20,184},{-20,160},
                  {20,160},{20,150},{26,150}},
                              color={0,0,127}));
          connect(u.y, gain.u) annotation (Line(points={{-127,184},{-52,184}}, color={0,
                  0,127}));
          connect(u.y, hea3.u)
                              annotation (Line(points={{-127,184},{-70,184},{-70,160},{
                  -28,160},{-28,-14},{-16,-14}},
                            color={0,0,127}));
          connect(gain.y, hea4.u) annotation (Line(points={{-29,184},{-20,184},{-20,60},
                  {12,60},{12,38},{18,38}},
                             color={0,0,127}));
          connect(u.y, hea6.u) annotation (Line(points={{-127,184},{-70,184},{-70,160},
                  {-28,160},{-28,-114},{-2,-114}},
                              color={0,0,127}));
          connect(u.y, hea8.u) annotation (Line(points={{-127,184},{-70,184},{-70,160},
                  {-28,160},{-28,-226},{-28,-254},{-2,-254}},
                               color={0,0,127}));
          connect(gain.y, hea5.u) annotation (Line(points={{-29,184},{-20,184},{-20,
                  -174},{-12,-174}},              color={0,0,127}));
          connect(gain.y, hea7.u) annotation (Line(points={{-29,184},{-20,184},{-20,
                  -314},{-14,-314},{-12,-314}},            color={0,0,127}));
          connect(sin_1.ports[1], res_12.port_a) annotation (Line(
              points={{-148,145},{-124,145},{-124,144},{-100,144}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[2], res_3.port_a) annotation (Line(
              points={{-148,143},{-124,143},{-124,32},{-100,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[1], res_11.port_a) annotation (Line(
              points={{-150,103},{-125,103},{-125,100},{-100,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[2], res_2.port_a) annotation (Line(
              points={{-150,101},{-128,101},{-128,-20},{-100,-20}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[3], res_1.port_a) annotation (Line(
              points={{-148,141},{-128,141},{-128,-180},{-100,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[4], res_6.port_a) annotation (Line(
              points={{-148,139},{-128,139},{-128,-320},{-100,-320}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[3], res_5.port_a) annotation (Line(
              points={{-150,99},{-124,99},{-124,-120},{-100,-120}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[4], res_7.port_a) annotation (Line(
              points={{-150,97},{-124,97},{-124,-260},{-100,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(mix1.ports[1], res_4.port_a) annotation (Line(
              points={{70,-20},{110,-20},{110,32},{100,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(mix2.ports[1], res_8.port_a) annotation (Line(
              points={{68,-320},{106,-320},{106,-260},{100,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem1a.T, ass1.u1) annotation (Line(
              points={{-40,108.8},{-40,122},{140,122},{140,176},{158,176}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem2a.T, ass1.u2) annotation (Line(
              points={{1.22125e-16,152.8},{0,152.8},{0,164},{158,164}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem1b.T, ass2.u2) annotation (Line(
              points={{30,108.8},{30,120},{158,120}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem2b.T, ass2.u1) annotation (Line(
              points={{64,152.8},{64,160},{120,160},{120,132},{158,132}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem4a.T, ass4.u2) annotation (Line(
              points={{-2,43},{-2,64},{158,64}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem3a.T, ass4.u1) annotation (Line(
              points={{-40,-11.2},{-40,10},{140,10},{140,76},{158,76}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem4b.T, ass3.u1) annotation (Line(
              points={{60,43},{60,52},{148,52},{148,16},{158,16}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem3b.T, ass3.u2) annotation (Line(
              points={{30,-9},{30,4},{158,4}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem6a.T, ass6.u2) annotation (Line(
              points={{-50,-109},{-50,-96},{158,-96}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem5a.T, ass6.u1) annotation (Line(
              points={{-50,-169},{-50,-150},{140,-150},{140,-84},{158,-84}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem6b.T, ass5.u1) annotation (Line(
              points={{50,-109},{50,-102},{150,-102},{150,-148},{158,-148}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem5b.T, ass5.u2) annotation (Line(
              points={{30,-169},{30,-160},{158,-160}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem8a.T, ass8.u2) annotation (Line(
              points={{-50,-249},{-50,-236},{158,-236}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem7a.T, ass8.u1) annotation (Line(
              points={{-50,-309},{-50,-292},{140,-292},{140,-224},{158,-224}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem8b.T, ass7.u1) annotation (Line(
              points={{48,-246.8},{48,-240},{148,-240},{148,-268},{158,-268}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem7b.T, ass7.u2) annotation (Line(
              points={{30,-309},{30,-280},{158,-280}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem3a.T, ass10.u1) annotation (Line(
              points={{-40,-11.2},{-40,10},{128,10},{128,-344},{158,-344}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem7a.T, ass10.u2) annotation (Line(
              points={{-50,-309},{-50,-292},{140,-292},{140,-356},{158,-356}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem2b.T, ass9.u1) annotation (Line(
              points={{64,152.8},{64,160},{120,160},{120,-384},{158,-384}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem5b.T, ass9.u2) annotation (Line(
              points={{30,-169},{30,-160},{112,-160},{112,-396},{158,-396}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(res_12.port_b, senTem2a.port_a) annotation (Line(
              points={{-80,144},{-8,144}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem2a.port_b, hea2.port_a) annotation (Line(
              points={{8,144},{28,144}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea2.port_b, senTem2b.port_a) annotation (Line(
              points={{48,144},{56,144}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem2b.port_b, senTem1b.port_b) annotation (Line(
              points={{72,144},{74,144},{74,100},{38,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea1.port_b, senTem1b.port_a) annotation (Line(
              points={{6,100},{22,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res_11.port_b, senTem1a.port_a) annotation (Line(
              points={{-80,100},{-48,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem1a.port_b, hea1.port_a) annotation (Line(
              points={{-32,100},{-14,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res_2.port_b, senTem3a.port_a) annotation (Line(
              points={{-80,-20},{-48,-20}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem3a.port_b, hea3.port_a) annotation (Line(
              points={{-32,-20},{-14,-20}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea3.port_b, senTem3b.port_a) annotation (Line(
              points={{6,-20},{20,-20}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem3b.port_b, mix1.ports[2]) annotation (Line(
              points={{40,-20},{74,-20}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea4.port_b, senTem4b.port_a) annotation (Line(
              points={{40,32},{50,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res_3.port_b, senTem4a.port_a) annotation (Line(
              points={{-80,32},{-12,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem4a.port_b, hea4.port_a) annotation (Line(
              points={{8,32},{20,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem4b.port_b, res_4.port_b) annotation (Line(
              points={{70,32},{80,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res_5.port_b, senTem6a.port_a) annotation (Line(
              points={{-80,-120},{-60,-120}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem6a.port_b, hea6.port_a) annotation (Line(
              points={{-40,-120},{-5.55112e-16,-120}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea6.port_b, senTem6b.port_a) annotation (Line(
              points={{20,-120},{40,-120}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem6b.port_b, senTem5b.port_b) annotation (Line(
              points={{60,-120},{70,-120},{70,-180},{40,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem5b.port_a, hea5.port_b) annotation (Line(
              points={{20,-180},{10,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea5.port_a, senTem5a.port_b) annotation (Line(
              points={{-10,-180},{-40,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem5a.port_a, res_1.port_b) annotation (Line(
              points={{-60,-180},{-80,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res_7.port_b, senTem8a.port_a) annotation (Line(
              points={{-80,-260},{-60,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem8a.port_b, hea8.port_a) annotation (Line(
              points={{-40,-260},{-5.55112e-16,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea8.port_b, senTem8b.port_a) annotation (Line(
              points={{20,-260},{36,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem8b.port_b, res_8.port_b) annotation (Line(
              points={{60,-260},{80,-260}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(mix2.ports[2], senTem7b.port_b) annotation (Line(
              points={{72,-320},{40,-320}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem7b.port_a, hea7.port_b) annotation (Line(
              points={{20,-320},{10,-320}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea7.port_a, senTem7a.port_b) annotation (Line(
              points={{-10,-320},{-40,-320}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem7a.port_a, res_6.port_b) annotation (Line(
              points={{-60,-320},{-80,-320}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation(Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-200,
                    -400},{200,240}}), graphics={Text(
                  extent={{30,234},{158,192}},
                  lineColor={0,0,255},
                  textString="Asserts for temperture check"), Text(
                  extent={{-188,-20},{-38,-84}},
                  lineColor={0,0,255},
                  textString="Same system as above, but with flow reversed")}),
        experiment(StopTime=3600),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/Interfaces/Examples/HeaterCoolerPrescribed.mos"
                "Simulate and plot"),
        Documentation(info="<html>
<p>Model that tests the basic class that is used for the heater models. It adds and removes heat for forward and reverse flow. The top and bottom models should give similar results, although the sign of the temperature difference over the components differ because of the reverse flow. The model uses assert statements that will be triggered if results that are expected to be close to each other differ by more than a prescribed threshold. All temperature sensors are configured as steady-state sensors to avoid differences in temperature due to the dynamic response of the sensor.</p>
</html>",
        revisions="<html>
<ul>
<li>
January 24, 2013, by Michael Wetter:<br/>
Increased parameter <code>startTime</code> of the assert block
and set initial conditions to 
<code>Modelica.Fluid.Types.Dynamics.FixedInitial</code>.
</li>
<li>
July 11, 2011, by Michael Wetter:<br/>
Changed model to sensors with two fluid ports.
Moved model to <code>Buildings.Fluid.Interfaces.Examples</code>.
</li>
<li>
April 17, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
        end HeaterCoolerPrescribed;

        model HumidifierPrescribed
          extends Modelica.Icons.Example;

         package Medium = Buildings.Media.PerfectGases.MoistAirUnsaturated;
         parameter Modelica.SIunits.MassFlowRate mWat_flow_nominal = 0.001
            "Nominal water mass flow rate";
          Humidifier hea1(redeclare package Medium =
                Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-54,92},{-34,112}}, rotation=0)));
          Modelica.Blocks.Sources.Constant TDb(k=293.15) "Drybulb temperature"
            annotation (Placement(transformation(extent={{-200,92},{-180,112}},
                  rotation=0)));
          Buildings.Fluid.Sources.Boundary_pT sou_1(
            redeclare package Medium = Medium,
            use_T_in=true,
            nPorts=4,
            p(displayUnit="Pa") = 101435,
            T=293.15)             annotation (Placement(transformation(extent={{-168,92},
                    {-148,112}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_11(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,92},{-80,112}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_12(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,134},{-80,154}},
                  rotation=0)));
          Buildings.Fluid.Sources.Boundary_pT sin_1(
            redeclare package Medium = Medium,
            use_p_in=true,
            T=288.15,
            nPorts=4)             annotation (Placement(transformation(extent={{-168,
                    134},{-148,154}}, rotation=0)));
            Modelica.Blocks.Sources.Constant POut(k=101325)
              annotation (Placement(transformation(extent={{-200,140},{-180,160}},
                  rotation=0)));
            Modelica.Blocks.Sources.Ramp u(
            duration=3600,
            startTime=0,
            height=1,
            offset=0) "Control signal"
                         annotation (Placement(transformation(extent={{-148,174},{-128,
                    194}}, rotation=0)));
          Humidifier hea2(
            redeclare package Medium = Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-12,134},{8,154}}, rotation=0)));
          Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(
                  extent={{-50,174},{-30,194}}, rotation=0)));
          Humidifier hea3(
            redeclare package Medium = Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-54,12},{-34,32}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_2(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,12},{-80,32}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_3(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,54},{-80,74}},
                  rotation=0)));
          Humidifier hea4(
            redeclare package Medium = Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-12,54},{8,74}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_4(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(
                origin={20,40},
                extent={{-10,-10},{10,10}},
                rotation=90)));
          Buildings.Fluid.MixingVolumes.MixingVolume mix1(
            redeclare package Medium = Medium,
            V=0.000001,
            nPorts=2,
            m_flow_nominal=0.5,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
                         annotation (Placement(transformation(extent={{-20,22},{0,42}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass1(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,140},{180,160}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y1(y=hea2.staB.T)
            annotation (Placement(transformation(extent={{40,150},{140,170}}, rotation=
                    0)));
          Modelica.Blocks.Sources.RealExpression y2(y=hea1.staB.T)
            annotation (Placement(transformation(extent={{40,130},{140,150}}, rotation=
                    0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass2(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,100},{180,120}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y3(y=hea2.staA.T)
            annotation (Placement(transformation(extent={{40,110},{140,130}}, rotation=
                    0)));
          Modelica.Blocks.Sources.RealExpression y4(y=hea1.staA.T)
            annotation (Placement(transformation(extent={{40,90},{140,110}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass3(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,38},{180,58}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y5(y=hea4.staB.T)
            annotation (Placement(transformation(extent={{40,48},{140,68}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y6(y=hea3.staB.T)
            annotation (Placement(transformation(extent={{40,28},{140,48}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass4(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-2},{180,18}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y7(y=hea4.staA.T)
            annotation (Placement(transformation(extent={{40,8},{140,28}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y8(y=hea3.staA.T)
            annotation (Placement(transformation(extent={{40,-12},{140,8}}, rotation=0)));
          Humidifier hea5(redeclare package Medium =
                Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-54,-110},{-34,-90}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_1(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-110},{-80,-90}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_5(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-68},{-80,-48}},
                  rotation=0)));
          Humidifier hea6(                               redeclare package
              Medium =
                Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-12,-68},{8,-48}}, rotation=0)));
          Humidifier hea7(redeclare package Medium =
                Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-54,-190},{-34,-170}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_6(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-190},{-80,-170}},
                  rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_7(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(extent={{-100,-148},{-80,-128}},
                  rotation=0)));
          Humidifier hea8(                               redeclare package
              Medium =
                Medium,
            m_flow_nominal=0.5,
            mWat_flow_nominal=mWat_flow_nominal,
            dp_nominal=50,
            show_T=true,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
            "Heater and cooler"                           annotation (Placement(
                transformation(extent={{-12,-148},{8,-128}}, rotation=0)));
            Buildings.Fluid.FixedResistances.FixedResistanceDpM res_8(
            redeclare package Medium = Medium,
            dp_nominal=5,
            m_flow_nominal=0.5)
                     annotation (Placement(transformation(
                origin={20,-162},
                extent={{-10,-10},{10,10}},
                rotation=90)));
          Buildings.Fluid.MixingVolumes.MixingVolume mix2(
                                                   redeclare package Medium = Medium, V=
               0.000001,
            nPorts=2,
            m_flow_nominal=0.5,
            energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial)
                         annotation (Placement(transformation(extent={{-20,-180},{0,
                    -160}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass5(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-62},{180,-42}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y9(y=hea6.staB.T)
            annotation (Placement(transformation(extent={{40,-50},{140,-30}}, rotation=
                    0)));
          Modelica.Blocks.Sources.RealExpression y10(
                                                    y=hea5.staB.T)
            annotation (Placement(transformation(extent={{40,-72},{140,-52}}, rotation=
                    0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass6(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-102},{180,-82}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y11(
                                                    y=hea6.staA.T)
            annotation (Placement(transformation(extent={{40,-92},{140,-72}}, rotation=
                    0)));
          Modelica.Blocks.Sources.RealExpression y12(
                                                    y=hea5.staA.T)
            annotation (Placement(transformation(extent={{40,-112},{140,-92}}, rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass7(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-164},{180,-144}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y13(
                                                    y=hea8.staB.T)
            annotation (Placement(transformation(extent={{40,-154},{140,-134}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y14(
                                                    y=hea7.staB.T)
            annotation (Placement(transformation(extent={{40,-174},{140,-154}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass8(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-204},{180,-184}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y15(
                                                    y=hea8.staA.T)
            annotation (Placement(transformation(extent={{40,-194},{140,-174}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y16(
                                                    y=hea7.staA.T)
            annotation (Placement(transformation(extent={{40,-214},{140,-194}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass9(
            startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-300},{180,-280}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y17(y=hea2.staB.T)
            annotation (Placement(transformation(extent={{40,-290},{140,-270}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y18(y=hea5.staB.T)
            annotation (Placement(transformation(extent={{40,-310},{140,-290}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass10(
             startTime=0.3,
            threShold=0.05)
            annotation (Placement(transformation(extent={{160,-260},{180,-240}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y19(y=hea4.staA.T)
            annotation (Placement(transformation(extent={{40,-250},{140,-230}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y20(y=hea7.staA.T)
            annotation (Placement(transformation(extent={{40,-270},{140,-250}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass11(
            threShold=1E-2,
            startTime=0.3)
            annotation (Placement(transformation(extent={{340,140},{360,160}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y21(y=hea2.staB.X[1])
            annotation (Placement(transformation(extent={{220,150},{320,170}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y22(y=hea1.staB.X[1])
            annotation (Placement(transformation(extent={{220,130},{320,150}}, rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass12(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,100},{360,120}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y23(
                                                    y=hea2.staA.X[1])
            annotation (Placement(transformation(extent={{220,110},{320,130}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y24(
                                                    y=hea1.staA.X[1])
            annotation (Placement(transformation(extent={{220,90},{320,110}}, rotation=
                    0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass13(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,38},{360,58}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y25(
                                                    y=hea4.staB.X[1])
            annotation (Placement(transformation(extent={{220,48},{320,68}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y26(
                                                    y=hea3.staB.X[1])
            annotation (Placement(transformation(extent={{220,28},{320,48}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass14(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-2},{360,18}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y27(
                                                    y=hea4.staA.X[1])
            annotation (Placement(transformation(extent={{220,8},{320,28}}, rotation=0)));
          Modelica.Blocks.Sources.RealExpression y28(
                                                    y=hea3.staA.X[1])
            annotation (Placement(transformation(extent={{220,-12},{320,8}}, rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass15(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-62},{360,-42}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y29(
                                                    y=hea6.staB.X[1])
            annotation (Placement(transformation(extent={{220,-52},{320,-32}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y30(
                                                    y=hea5.staB.X[1])
            annotation (Placement(transformation(extent={{220,-72},{320,-52}}, rotation=
                   0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass16(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-102},{360,-82}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y31(
                                                    y=hea6.staA.X[1])
            annotation (Placement(transformation(extent={{220,-92},{320,-72}}, rotation=
                   0)));
          Modelica.Blocks.Sources.RealExpression y32(
                                                    y=hea5.staA.X[1])
            annotation (Placement(transformation(extent={{220,-112},{320,-92}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass17(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-164},{360,-144}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y33(
                                                    y=hea8.staB.X[1])
            annotation (Placement(transformation(extent={{220,-154},{320,-134}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y34(
                                                    y=hea7.staB.X[1])
            annotation (Placement(transformation(extent={{220,-174},{320,-154}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass18(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-204},{360,-184}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y35(
                                                    y=hea8.staA.X[1])
            annotation (Placement(transformation(extent={{220,-194},{320,-174}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y36(
                                                    y=hea7.staA.X[1])
            annotation (Placement(transformation(extent={{220,-214},{320,-194}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass19(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-300},{360,-280}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y37(y=hea2.staB.X[1])
            annotation (Placement(transformation(extent={{220,-290},{320,-270}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y38(y=hea5.staB.X[1])
            annotation (Placement(transformation(extent={{220,-310},{320,-290}},
                  rotation=0)));
          Buildings.Utilities.Diagnostics.AssertEquality ass20(threShold=1E-2, startTime=
                0.3)
            annotation (Placement(transformation(extent={{340,-260},{360,-240}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y39(y=hea4.staA.X[1])
            annotation (Placement(transformation(extent={{220,-250},{320,-230}},
                  rotation=0)));
          Modelica.Blocks.Sources.RealExpression y40(y=hea7.staA.X[1])
            annotation (Placement(transformation(extent={{220,-270},{320,-250}},
                  rotation=0)));
          inner Modelica.Fluid.System system(energyDynamics=Modelica.Fluid.Types.Dynamics.SteadyState)
            annotation (Placement(transformation(extent={{-180,-300},{-160,-280}})));
        protected
          model Humidifier
            "Model for humidifier that adds a variable for the thermodynamic states at its ports"
            extends Buildings.Fluid.MassExchangers.HumidifierPrescribed;
           Medium.ThermodynamicState staA=
              Medium.setState_phX(port_a.p,
                                  actualStream(port_a.h_outflow),
                                  actualStream(port_a.Xi_outflow))
              "Thermodynamic state in port a";
           Medium.ThermodynamicState staB=
              Medium.setState_phX(port_b.p,
                                  actualStream(port_b.h_outflow),
                                  actualStream(port_b.Xi_outflow))
              "Thermodynamic state in port b";
          end Humidifier;
        equation
          connect(POut.y,sin_1. p_in) annotation (Line(
              points={{-179,150},{-174.5,150},{-174.5,152},{-170,152}},
              color={0,0,127},
              pattern=LinePattern.None));
          connect(TDb.y,sou_1. T_in) annotation (Line(
              points={{-179,102},{-174.5,102},{-174.5,106},{-170,106}},
              color={0,0,127},
              pattern=LinePattern.None));
          connect(res_11.port_b, hea1.port_a)
                                             annotation (Line(points={{-80,102},{-54,
                  102}}, color={0,127,255}));
          connect(u.y, hea1.u)
                              annotation (Line(points={{-127,184},{-64,184},{-64,108},{
                  -56,108}}, color={0,0,127}));
          connect(gain.y, hea2.u) annotation (Line(points={{-29,184},{-22,184},{-22,150},
                  {-14,150}}, color={0,0,127}));
          connect(u.y, gain.u) annotation (Line(points={{-127,184},{-52,184}}, color={0,
                  0,127}));
          connect(res_12.port_b, hea2.port_a) annotation (Line(points={{-80,144},{-12,
                  144}}, color={0,127,255}));
          connect(res_2.port_b, hea3.port_a) annotation (Line(points={{-80,22},{-54,22}},
                color={0,127,255}));
          connect(u.y, hea3.u)
                              annotation (Line(points={{-127,184},{-64,184},{-64,28},{
                  -56,28}}, color={0,0,127}));
          connect(gain.y, hea4.u) annotation (Line(points={{-29,184},{-22,184},{-22,70},
                  {-14,70}}, color={0,0,127}));
          connect(res_3.port_b, hea4.port_a) annotation (Line(points={{-80,64},{-12,64}},
                color={0,127,255}));
          connect(hea4.port_b, res_4.port_b) annotation (Line(points={{8,64},{20,64},{
                  20,50}}, color={0,127,255}));
          connect(hea1.port_b, hea2.port_b) annotation (Line(points={{-34,102},{20,102},
                  {20,144},{8,144}}, color={0,127,255}));
          connect(y1.y, ass1.u1) annotation (Line(points={{145,160},{154,160},{154,156},
                  {158,156}}, color={0,0,127}));
          connect(y2.y, ass1.u2) annotation (Line(points={{145,140},{152,140},{152,144},
                  {158,144}}, color={0,0,127}));
          connect(y3.y, ass2.u1) annotation (Line(points={{145,120},{154,120},{154,116},
                  {158,116}}, color={0,0,127}));
          connect(y4.y, ass2.u2) annotation (Line(points={{145,100},{152,100},{152,104},
                  {158,104}}, color={0,0,127}));
          connect(y5.y, ass3.u1) annotation (Line(points={{145,58},{154,58},{154,54},{
                  158,54}}, color={0,0,127}));
          connect(y6.y, ass3.u2) annotation (Line(points={{145,38},{152,38},{152,42},{
                  158,42}}, color={0,0,127}));
          connect(y7.y, ass4.u1) annotation (Line(points={{145,18},{154,18},{154,14},{
                  158,14}}, color={0,0,127}));
          connect(y8.y, ass4.u2) annotation (Line(points={{145,-2},{152,-2},{152,2},{
                  158,2}}, color={0,0,127}));
          connect(res_1.port_b, hea5.port_a) annotation (Line(points={{-80,-100},{-54,
                  -100}}, color={0,127,255}));
          connect(res_5.port_b, hea6.port_a)  annotation (Line(points={{-80,-58},{-12,
                  -58}}, color={0,127,255}));
          connect(res_6.port_b,hea7. port_a) annotation (Line(points={{-80,-180},{-54,
                  -180}}, color={0,127,255}));
          connect(res_7.port_b,hea8. port_a) annotation (Line(points={{-80,-138},{-12,
                  -138}}, color={0,127,255}));
          connect(hea8.port_b,res_8. port_b) annotation (Line(points={{8,-138},{20,-138},
                  {20,-152}}, color={0,127,255}));
          connect(hea5.port_b,hea6. port_b) annotation (Line(points={{-34,-100},{20,
                  -100},{20,-58},{8,-58}}, color={0,127,255}));
          connect(y9.y,ass5. u1) annotation (Line(points={{145,-40},{154,-40},{154,-46},
                  {158,-46}}, color={0,0,127}));
          connect(y10.y, ass5.u2)
                                 annotation (Line(points={{145,-62},{152,-62},{152,-58},
                  {158,-58}}, color={0,0,127}));
          connect(y11.y, ass6.u1)
                                 annotation (Line(points={{145,-82},{154,-82},{154,-86},
                  {158,-86}}, color={0,0,127}));
          connect(y12.y, ass6.u2)
                                 annotation (Line(points={{145,-102},{152,-102},{152,
                  -98},{158,-98}}, color={0,0,127}));
          connect(y13.y, ass7.u1)
                                 annotation (Line(points={{145,-144},{154,-144},{154,
                  -148},{158,-148}}, color={0,0,127}));
          connect(y14.y, ass7.u2)
                                 annotation (Line(points={{145,-164},{152,-164},{152,
                  -160},{158,-160}}, color={0,0,127}));
          connect(y15.y, ass8.u1)
                                 annotation (Line(points={{145,-184},{154,-184},{154,
                  -188},{158,-188}}, color={0,0,127}));
          connect(y16.y, ass8.u2)
                                 annotation (Line(points={{145,-204},{152,-204},{152,
                  -200},{158,-200}}, color={0,0,127}));
          connect(y17.y,ass9. u1)
                                 annotation (Line(points={{145,-280},{154,-280},{154,
                  -284},{158,-284}}, color={0,0,127}));
          connect(y18.y,ass9. u2)
                                 annotation (Line(points={{145,-300},{152,-300},{152,
                  -296},{158,-296}}, color={0,0,127}));
          connect(y19.y, ass10.u1)
                                 annotation (Line(points={{145,-240},{154,-240},{154,
                  -244},{158,-244}}, color={0,0,127}));
          connect(y20.y, ass10.u2)
                                 annotation (Line(points={{145,-260},{152,-260},{152,
                  -256},{158,-256}}, color={0,0,127}));
          connect(u.y, hea6.u) annotation (Line(points={{-127,184},{-70,184},{-70,-52},
                  {-14,-52}}, color={0,0,127}));
          connect(u.y, hea8.u) annotation (Line(points={{-127,184},{-70,184},{-70,-132},
                  {-14,-132}}, color={0,0,127}));
          connect(gain.y, hea5.u) annotation (Line(points={{-29,184},{-26,184},{-26,-80},
                  {-60,-80},{-60,-94},{-56,-94}}, color={0,0,127}));
          connect(gain.y, hea7.u) annotation (Line(points={{-29,184},{-26,184},{-26,
                  -160},{-64,-160},{-64,-174},{-56,-174}}, color={0,0,127}));
          connect(y21.y, ass11.u1)
                                 annotation (Line(points={{325,160},{334,160},{334,156},
                  {338,156}}, color={0,0,127}));
          connect(y22.y, ass11.u2)
                                 annotation (Line(points={{325,140},{332,140},{332,144},
                  {338,144}}, color={0,0,127}));
          connect(y23.y, ass12.u1)
                                 annotation (Line(points={{325,120},{334,120},{334,116},
                  {338,116}}, color={0,0,127}));
          connect(y24.y, ass12.u2)
                                 annotation (Line(points={{325,100},{332,100},{332,104},
                  {338,104}}, color={0,0,127}));
          connect(y25.y, ass13.u1)
                                 annotation (Line(points={{325,58},{334,58},{334,54},{
                  338,54}}, color={0,0,127}));
          connect(y26.y, ass13.u2)
                                 annotation (Line(points={{325,38},{332,38},{332,42},{
                  338,42}}, color={0,0,127}));
          connect(y27.y, ass14.u1)
                                 annotation (Line(points={{325,18},{334,18},{334,14},{
                  338,14}}, color={0,0,127}));
          connect(y28.y, ass14.u2)
                                 annotation (Line(points={{325,-2},{332,-2},{332,2},{
                  338,2}}, color={0,0,127}));
          connect(y29.y, ass15.u1)
                                 annotation (Line(points={{325,-42},{334,-42},{334,-46},
                  {338,-46}}, color={0,0,127}));
          connect(y30.y, ass15.u2)
                                 annotation (Line(points={{325,-62},{332,-62},{332,-58},
                  {338,-58}}, color={0,0,127}));
          connect(y31.y, ass16.u1)
                                 annotation (Line(points={{325,-82},{334,-82},{334,-86},
                  {338,-86}}, color={0,0,127}));
          connect(y32.y, ass16.u2)
                                 annotation (Line(points={{325,-102},{332,-102},{332,
                  -98},{338,-98}}, color={0,0,127}));
          connect(y33.y, ass17.u1)
                                 annotation (Line(points={{325,-144},{334,-144},{334,
                  -148},{338,-148}}, color={0,0,127}));
          connect(y34.y, ass17.u2)
                                 annotation (Line(points={{325,-164},{332,-164},{332,
                  -160},{338,-160}}, color={0,0,127}));
          connect(y35.y, ass18.u1)
                                 annotation (Line(points={{325,-184},{334,-184},{334,
                  -188},{338,-188}}, color={0,0,127}));
          connect(y36.y, ass18.u2)
                                 annotation (Line(points={{325,-204},{332,-204},{332,
                  -200},{338,-200}}, color={0,0,127}));
          connect(y37.y, ass19.u1)
                                 annotation (Line(points={{325,-280},{334,-280},{334,
                  -284},{338,-284}}, color={0,0,127}));
          connect(y38.y, ass19.u2)
                                 annotation (Line(points={{325,-300},{332,-300},{332,
                  -296},{338,-296}}, color={0,0,127}));
          connect(y39.y, ass20.u1)
                                 annotation (Line(points={{325,-240},{334,-240},{334,
                  -244},{338,-244}}, color={0,0,127}));
          connect(y40.y, ass20.u2)
                                 annotation (Line(points={{325,-260},{332,-260},{332,
                  -256},{338,-256}}, color={0,0,127}));
          connect(sin_1.ports[1], res_12.port_a) annotation (Line(
              points={{-148,147},{-106,147},{-106,144},{-100,144}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[2], res_3.port_a) annotation (Line(
              points={{-148,145},{-124,145},{-124,64},{-100,64}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[1], res_11.port_a) annotation (Line(
              points={{-148,105},{-107,105},{-107,102},{-100,102}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[2], res_2.port_a) annotation (Line(
              points={{-148,103},{-126,103},{-126,22},{-100,22}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[3], res_1.port_a) annotation (Line(
              points={{-148,143},{-130,143},{-130,-100},{-100,-100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sin_1.ports[4], res_6.port_a) annotation (Line(
              points={{-148,141},{-132,141},{-132,-180},{-100,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[3], res_5.port_a) annotation (Line(
              points={{-148,101},{-140,101},{-140,-58},{-100,-58}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(sou_1.ports[4], res_7.port_a) annotation (Line(
              points={{-148,99},{-142,99},{-142,-138},{-100,-138}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea3.port_b, mix1.ports[1]) annotation (Line(
              points={{-34,22},{-12,22}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(mix1.ports[2], res_4.port_a) annotation (Line(
              points={{-8,22},{20,22},{20,30}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(hea7.port_b, mix2.ports[1]) annotation (Line(
              points={{-34,-180},{-12,-180}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(mix2.ports[2], res_8.port_a) annotation (Line(
              points={{-8,-180},{20,-180},{20,-172}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation(Diagram(coordinateSystem(preserveAspectRatio=true,  extent={{-200,
                    -320},{360,200}}), graphics={
                Text(
                  extent={{30,204},{158,162}},
                  lineColor={0,0,255},
                  textString="Asserts for temperture check"),
                Text(
                  extent={{210,204},{338,162}},
                  lineColor={0,0,255},
                  textString="Asserts for humidity check"),
                Text(
                  extent={{-198,-4},{-6,-38}},
                  lineColor={0,0,255},
                  textString="Same models as above, but flow is reversed")}),
        experiment(StopTime=3600),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/Interfaces/Examples/HumidifierPrescribed.mos"
                "Simulate and plot"),
        Documentation(info="<html>
<p>
Model that tests the basic class that is used for the humidifier model.
It adds and removes water for forward and reverse flow.
The top and bottom models should give similar results, although 
the sign of the humidity difference over the components differ
because of the reverse flow.
The model uses assert statements that will be triggered if
results that are expected to be close to each other differ by more
than a prescribed threshold.</p>
</html>",
        revisions="<html>
<ul>
<li>
October 9, 2013, by Michael Wetter:<br/>
Introduced protected model <code>Humidifier</code> so that states at
the fluid ports can be computed without having to use a conditionally
removed variable. This is required for the model to pass the model check in 
Dymola 2014 FD01 beta3 with <code>Advanced.PedanticModelica=true;</code>.
</li>
<li>
January 24, 2013, by Michael Wetter:<br/>
Set initial conditions to 
<code>Modelica.Fluid.Types.Dynamics.FixedInitial</code>.
</li>
<li>
July 11, 2011, by Michael Wetter:<br/>
Moved model to <code>Buildings.Fluid.Interfaces.Examples</code>.
</li>
<li>
April 18, 2008, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
        end HumidifierPrescribed;

        model ReverseFlowHumidifier
          "Model that tests the reverse flow for a humidifier"
          extends Modelica.Icons.Example;
        package Medium = Buildings.Media.PerfectGases.MoistAir;
          Buildings.Utilities.Diagnostics.AssertEquality assTem(threShold=0.01)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{80,0},{100,20}})));
          Buildings.Utilities.Diagnostics.AssertEquality assEnt(threShold=0.5)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{80,-30},{100,-10}})));
          Buildings.Utilities.Diagnostics.AssertEquality assMas(threShold=1E-5)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{80,-60},{100,-40}})));
          Buildings.Fluid.MassExchangers.HumidifierPrescribed humBac(
            redeclare package Medium = Medium,
            dp_nominal=0,
            m_flow(start=1),
            m_flow_nominal=1,
            T=283.15,
            mWat_flow_nominal=0.1) "Humidifier with backward flow"
            annotation (Placement(transformation(extent={{-32,-16},{-52,4}})));
          Buildings.Fluid.MassExchangers.HumidifierPrescribed humFor(
            redeclare package Medium = Medium,
            dp_nominal=0,
            m_flow(start=1),
            m_flow_nominal=1,
            T=283.15,
            mWat_flow_nominal=0.1) "Humidifier with forward flow"
            annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
          Modelica.Blocks.Sources.Constant u2(k=0.01) "Control input"
            annotation (Placement(transformation(extent={{-92,54},{-80,66}})));
          Modelica.Fluid.Sources.MassFlowSource_T source1(
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            T(displayUnit="K") = 323.15,
            X={0.01,0.99},
            nPorts=1,
            m_flow=0.5) "Fluid source"
                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-90,30})));
          Buildings.Fluid.Sources.FixedBoundary sink1(
            redeclare package Medium = Medium,
            nPorts=2) "Fluid sink"
                         annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={40,28})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt1(redeclare package
              Medium = Medium) "Specific enthalpy sensor"
            annotation (Placement(transformation(extent={{10,70},{30,90}})));
          Buildings.Fluid.Sensors.Temperature senTem1(redeclare package Medium
              = Medium) "Temperature sensor"
            annotation (Placement(transformation(extent={{-30,70},{-10,90}})));
          Buildings.Fluid.Sensors.MassFraction senMas1(redeclare package Medium
              = Medium) "Mass fraction sensor"
            annotation (Placement(transformation(extent={{50,70},{70,90}})));
          Buildings.Fluid.Sensors.Temperature senTem2(redeclare package Medium
              = Medium) "Temperature sensor"
            annotation (Placement(transformation(extent={{-60,-60},{-40,-40}})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt2(redeclare package
              Medium = Medium) "Specific enthalpy sensor"
            annotation (Placement(transformation(extent={{-20,-60},{0,-40}})));
          Buildings.Fluid.Sensors.MassFraction senMas2(redeclare package Medium
              = Medium) "Mass fraction sensor"
            annotation (Placement(transformation(extent={{20,-60},{40,-40}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res1(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-10,20},{10,40}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res2(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-10,-16},{10,4}})));
          inner Modelica.Fluid.System system
            annotation (Placement(transformation(extent={{38,-100},{58,-80}})));
          Modelica.Fluid.Sources.MassFlowSource_T source2(
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            T(displayUnit="K") = 323.15,
            X={0.01,0.99},
            nPorts=1,
            m_flow=0.5) "Fluid source"
                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-90,-6})));
        equation
          connect(u2.y, humFor.u)                annotation (Line(
              points={{-79.4,60},{-60,60},{-60,36},{-52,36}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(u2.y, humBac.u)         annotation (Line(
              points={{-79.4,60},{-70,60},{-70,12},{-24,12},{-24,0},{-30,0}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(humFor.port_b, senTem1.port)         annotation (Line(
              points={{-30,30},{-30,70},{-20,70}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humFor.port_b, senEnt1.port)         annotation (Line(
              points={{-30,30},{-30,48},{20,48},{20,70}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humFor.port_b, senMas1.port)         annotation (Line(
              points={{-30,30},{-30,48},{60,48},{60,70}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humBac.port_a, senTem2.port)         annotation (Line(
              points={{-32,-6},{-32,-30},{-60,-30},{-60,-60},{-50,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humBac.port_a, senEnt2.port)         annotation (Line(
              points={{-32,-6},{-32,-30},{-60,-30},{-60,-70},{-10,-70},{-10,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humBac.port_a, senMas2.port)         annotation (Line(
              points={{-32,-6},{-32,-30},{-60,-30},{-60,-70},{30,-70},{30,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humFor.port_b, res1.port_a)         annotation (Line(
              points={{-30,30},{-10,30}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res1.port_b, sink1.ports[1]) annotation (Line(
              points={{10,30},{30,30}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(humBac.port_a, res2.port_a)         annotation (Line(
              points={{-32,-6},{-26.5,-6},{-26.5,-6},{-21,-6},{-21,-6},{-10,-6}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res2.port_b, sink1.ports[2]) annotation (Line(
              points={{10,-6},{16,-6},{16,26},{30,26}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem1.T, assTem.u1) annotation (Line(
              points={{-13,80},{0,80},{0,60},{70,60},{70,16},{78,16}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt1.h_out, assEnt.u1) annotation (Line(
              points={{31,80},{40,80},{40,54},{66,54},{66,-14},{78,-14}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas1.X, assMas.u1) annotation (Line(
              points={{71,80},{80,80},{80,64},{64,64},{64,-44},{78,-44}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem2.T, assTem.u2) annotation (Line(
              points={{-43,-50},{-20,-50},{-20,-30},{50,-30},{50,4},{78,4}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt2.h_out, assEnt.u2) annotation (Line(
              points={{1,-50},{8,-50},{8,-32},{54,-32},{54,-26},{78,-26}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas2.X, assMas.u2) annotation (Line(
              points={{41,-50},{60,-50},{60,-56},{78,-56}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(humFor.port_a, source1.ports[1]) annotation (Line(
              points={{-50,30},{-80,30}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(source2.ports[1], humBac.port_b) annotation (Line(
              points={{-80,-6},{-52,-6}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation (
        experiment(StopTime=1),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/Interfaces/Examples/ReverseFlowHumidifier.mos"
                "Simulate and plot"),
            Documentation(info="<html>
This model tests whether the results for a humidifer are
identical for forward flow and reverse flow.
If the results differ, then an assert is triggered.
</html>",         revisions="<html>
<ul>
<li>
October 9, 2013, by Michael Wetter:<br/>
Replaced
<code>Modelica.Fluid.Sources.FixedBoundary</code>
with 
<code>Buildings.Fluid.Sources.FixedBoundary</code>
as otherwise, the pedantic model check fails in 
Dymola 2014 FD01 beta3.
</li>
<li>
July 5, 2013, by Michael Wetter:<br/>
Changed one instance of <code>Modelica.Fluid.Sources.MassFlowSource_T</code>,
that was connected to the two fluid streams,
to two instances, each having half the mass flow rate.
This is required for the model to work with Modelica 3.2.1 due to the 
change introduced in 
ticket <a href=\"https://trac.modelica.org/Modelica/ticket/739\">#739</a>.
</li>
<li>
August 19, 2010, by Michael Wetter:<br/>
First implementation based on a model from Giuliano Fontanella.
</li>
</ul>
</html>"),  Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
                    100,100}}), graphics));
        end ReverseFlowHumidifier;

        model ReverseFlowMassExchanger
          "Model that tests the reverse flow for a mass exchanger"
          extends Modelica.Icons.Example;
        package Medium = Buildings.Media.PerfectGases.MoistAir;
          Buildings.Utilities.Diagnostics.AssertEquality assTem(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{160,0},{180,20}})));
          Buildings.Utilities.Diagnostics.AssertEquality assEnt(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{160,-30},{180,-10}})));
          Buildings.Utilities.Diagnostics.AssertEquality assMas(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{160,-60},{180,-40}})));
          Modelica.Fluid.Sources.MassFlowSource_T source2(
            m_flow=1,
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            nPorts=1,
            T(displayUnit="degC") = 303.15,
            X={0.02,0.98})  annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={38,70})));
          Buildings.Fluid.MassExchangers.ConstantEffectiveness masExcFor(
            redeclare package Medium1 = Medium,
            redeclare package Medium2 = Medium,
            m1_flow_nominal=1,
            m2_flow_nominal=1,
            dp1_nominal=0,
            dp2_nominal=0,
            epsL=0) "Mass exchanger with forward flow"
            annotation (Placement(transformation(extent={{-50,84},{-30,104}})));
          Buildings.Fluid.MassExchangers.ConstantEffectiveness masExcRev(
            redeclare package Medium1 = Medium,
            redeclare package Medium2 = Medium,
            m1_flow_nominal=1,
            m2_flow_nominal=1,
            dp1_nominal=0,
            dp2_nominal=0,
            epsL=0) "Mass exchanger with reverse flow"
            annotation (Placement(transformation(extent={{-30,30},{-50,50}})));
          Buildings.Fluid.Sources.FixedBoundary sink2(
             redeclare package Medium = Medium,
             nPorts=2) "Fluid sink"
             annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=180,
                origin={-152,30})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res3(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-88,78},{-108,98}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res4(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-88,24},{-108,44}})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt3(redeclare package
              Medium = Medium)
            annotation (Placement(transformation(extent={{-310,140},{-290,160}})));
          Buildings.Fluid.Sensors.Temperature senTem3(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{-350,140},{-330,160}})));
          Buildings.Fluid.Sensors.MassFraction senMas3(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{-270,140},{-250,160}})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt4(redeclare package
              Medium = Medium)
            annotation (Placement(transformation(extent={{-310,60},{-290,80}})));
          Buildings.Fluid.Sensors.Temperature senTem4(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{-350,60},{-330,80}})));
          Buildings.Fluid.Sensors.MassFraction senMas4(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{-270,60},{-250,80}})));
          Buildings.Utilities.Diagnostics.AssertEquality assTem1(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{-200,-20},{-180,0}})));
          Buildings.Utilities.Diagnostics.AssertEquality assEnt1(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{-200,-50},{-180,-30}})));
          Buildings.Utilities.Diagnostics.AssertEquality assMas1(threShold=1E-8,
              startTime=0)
            "Assert to test if the outputs of the forward flow and reverse flow model are identical"
            annotation (Placement(transformation(extent={{-200,-80},{-180,-60}})));
          Modelica.Fluid.Sources.MassFlowSource_T source3(
            m_flow=1,
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            X={0.01,0.99},
            nPorts=1,
            T(displayUnit="degC") = 293.15)
                            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-150,70})));
          Modelica.Fluid.Sources.MassFlowSource_T source4(
            m_flow=1,
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            nPorts=1,
            T(displayUnit="degC") = 303.15,
            X={0.02,0.98})  annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={38,30})));

          Modelica.Fluid.Sources.MassFlowSource_T source1(
            m_flow=1,
            redeclare package Medium = Medium,
            use_m_flow_in=false,
            use_T_in=false,
            use_X_in=false,
            X={0.01,0.99},
            nPorts=1,
            T(displayUnit="degC") = 293.15)
                            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-150,100})));
          Buildings.Fluid.Sources.FixedBoundary sink1(
            redeclare package Medium = Medium,
            nPorts=2) "Fluid sink"
            annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={40,98})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt1(redeclare package
              Medium = Medium)
            annotation (Placement(transformation(extent={{10,140},{30,160}})));
          Buildings.Fluid.Sensors.Temperature senTem1(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{-30,140},{-10,160}})));
          Buildings.Fluid.Sensors.MassFraction senMas1(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{50,140},{70,160}})));
          Buildings.Fluid.Sensors.Temperature senTem2(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{20,-60},{40,-40}})));
          Buildings.Fluid.Sensors.SpecificEnthalpy senEnt2(redeclare package
              Medium = Medium)
            annotation (Placement(transformation(extent={{60,-60},{80,-40}})));
          Buildings.Fluid.Sensors.MassFraction senMas2(redeclare package Medium
              = Medium)
            annotation (Placement(transformation(extent={{100,-60},{120,-40}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res1(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-10,90},{10,110}})));
          Buildings.Fluid.FixedResistances.FixedResistanceDpM res2(
            redeclare package Medium = Medium,
            m_flow_nominal=1,
            from_dp=true,
            linearized=false,
            dp_nominal=1000) "Fixed resistance"
            annotation (Placement(transformation(extent={{-12,36},{8,56}})));
          inner Modelica.Fluid.System system
            annotation (Placement(transformation(extent={{118,-100},{138,-80}})));
        equation

          connect(res1.port_b, sink1.ports[1]) annotation (Line(
              points={{10,100},{30,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res2.port_b, sink1.ports[2]) annotation (Line(
              points={{8,46},{16,46},{16,96},{30,96}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem1.T, assTem.u1) annotation (Line(
              points={{-13,150},{0,150},{0,126},{70,126},{70,16},{158,16}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt1.h_out, assEnt.u1) annotation (Line(
              points={{31,150},{34,150},{34,124},{146,124},{146,-14},{158,-14}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas1.X, assMas.u1) annotation (Line(
              points={{71,150},{140,150},{140,-44},{158,-44}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem2.T, assTem.u2) annotation (Line(
              points={{37,-50},{48,-50},{48,4},{158,4}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt2.h_out, assEnt.u2) annotation (Line(
              points={{81,-50},{88,-50},{88,-26},{158,-26}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas2.X, assMas.u2) annotation (Line(
              points={{121,-50},{140,-50},{140,-56},{158,-56}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(masExcFor.port_b1, res1.port_a) annotation (Line(
              points={{-30,100},{-10,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_a1, source1.ports[1]) annotation (Line(
              points={{-50,100},{-140,100}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a1, res2.port_a) annotation (Line(
              points={{-30,46},{-12,46}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(source2.ports[1], masExcFor.port_a2) annotation (Line(
              points={{28,70},{20,70},{20,88},{-30,88}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a1, senTem2.port) annotation (Line(
              points={{-30,46},{-20,46},{-20,-70},{30,-70},{30,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a1, senEnt2.port) annotation (Line(
              points={{-30,46},{-20,46},{-20,-70},{70,-70},{70,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a1, senMas2.port) annotation (Line(
              points={{-30,46},{-20,46},{-20,-70},{110,-70},{110,-60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b1, senTem1.port) annotation (Line(
              points={{-30,100},{-20,100},{-20,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b1, senEnt1.port) annotation (Line(
              points={{-30,100},{-20,100},{-20,132},{20,132},{20,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b1, senMas1.port) annotation (Line(
              points={{-30,100},{-20,100},{-20,132},{60,132},{60,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b2, res3.port_a) annotation (Line(
              points={{-50,88},{-88,88}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a2, res4.port_a) annotation (Line(
              points={{-50,34},{-88,34}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res3.port_b, sink2.ports[1]) annotation (Line(
              points={{-108,88},{-128,88},{-128,28},{-142,28}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(res4.port_b, sink2.ports[2]) annotation (Line(
              points={{-108,34},{-126,34},{-126,32},{-142,32}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(senTem3.T, assTem1.u1) annotation (Line(
              points={{-333,150},{-312,150},{-312,-4},{-202,-4}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senTem4.T, assTem1.u2) annotation (Line(
              points={{-333,70},{-320,70},{-320,-16},{-202,-16}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt3.h_out, assEnt1.u1) annotation (Line(
              points={{-289,150},{-272,150},{-272,-34},{-202,-34}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senEnt4.h_out, assEnt1.u2) annotation (Line(
              points={{-289,70},{-280,70},{-280,-46},{-202,-46}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas3.X, assMas1.u1) annotation (Line(
              points={{-249,150},{-230,150},{-230,-64},{-202,-64}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(senMas4.X, assMas1.u2) annotation (Line(
              points={{-249,70},{-240,70},{-240,-76},{-202,-76}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(masExcFor.port_b2, senTem3.port) annotation (Line(
              points={{-50,88},{-70,88},{-70,128},{-340,128},{-340,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b2, senEnt3.port) annotation (Line(
              points={{-50,88},{-70,88},{-70,128},{-300,128},{-300,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcFor.port_b2, senMas3.port) annotation (Line(
              points={{-50,88},{-70,88},{-70,128},{-260,128},{-260,140}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a2, senTem4.port) annotation (Line(
              points={{-50,34},{-70,34},{-70,50},{-340,50},{-340,60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a2, senEnt4.port) annotation (Line(
              points={{-50,34},{-70,34},{-70,50},{-300,50},{-300,60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(masExcRev.port_a2, senMas4.port) annotation (Line(
              points={{-50,34},{-70,34},{-70,50},{-260,50},{-260,60}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(source3.ports[1], masExcRev.port_b1) annotation (Line(
              points={{-140,70},{-120,70},{-120,46},{-50,46}},
              color={0,127,255},
              smooth=Smooth.None));
          connect(source4.ports[1], masExcRev.port_b2) annotation (Line(
              points={{28,30},{0,30},{0,34},{-30,34}},
              color={0,127,255},
              smooth=Smooth.None));
          annotation (
        experiment(StopTime=1),
        __Dymola_Commands(file="modelica://Buildings/Resources/Scripts/Dymola/Fluid/Interfaces/Examples/ReverseFlowMassExchanger.mos"
                "Simulate and plot"),
            Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-400,-200},{200,
                    200}})),
            Documentation(info="<html>
<p>
This model tests whether the results for a mass exchanger are
identical for forward flow and reverse flow.
If the results differ, then an assert is triggered.
</p>
<p>
Note that if the latent heat transfer effectiveness is non-zero, then
the results will differ. The reason is that the maximum capacity stream 
is computed using the mass flow rates at <code>port_a1</code>
and <code>port_a2</code>. For reverse flow, they are not equal if
moisture is added to the mass flow rate. Using an average mass flow rate
in computing the heat and moisture transfer would lead to identical results,
but it would introduce additional nonlinear equations that need to be solved.
Therefore, the model uses the mass flow rates at <code>port_a1</code>
and <code>port_a2</code>.
</p>
<p>
<b>Note:</b> This problem fails to translate in Dymola 2012 due to an error in Dymola's support
of stream connector. This bug will be corrected in future versions of Dymola.
</p>
</html>",         revisions="<html>
<ul>
<li>
October 9, 2013, by Michael Wetter:<br/>
Replaced
<code>Modelica.Fluid.Sources.FixedBoundary</code>
with 
<code>Buildings.Fluid.Sources.FixedBoundary</code>
as otherwise, the pedantic model check fails in 
Dymola 2014 FD01 beta3.
</li>
<li>
August 19, 2010, by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"));
        end ReverseFlowMassExchanger;
      annotation (preferredView="info", Documentation(info="<html>
<p>
This package contains examples for the use of models that can be found in
<a href=\"modelica://Buildings.Fluid.Interfaces\">
Buildings.Fluid.Interfaces</a>.
</p>
</html>"));
      end Examples;
    annotation (preferredView="info", Documentation(info="<html>
<p>
This package contains basic classes that are used to build
component models that change the state of the
fluid. The classes are not directly usable, but can
be extended when building a new model.
</p>
</html>"));
    end Interfaces;

  annotation (preferredView="info", Documentation(info="<html>
This package contains models for borehole heat exchangers.
</html>"));
  end Boreholes;

  model CO2HybridGCHP_035_PlateHX "Heat Pump Cycle CO2"

    inner TIL.SystemInformationManager sim(
      redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
        Placement(transformation(extent={{86,82},{100,100}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
        presetVariableType="dp")
                          annotation (Placement(transformation(
          origin={-69.5,80},
          extent={{-7,-7},{7,7}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
        pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
            extent={{56,48},{68,60}}, rotation=0)));

    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{70,59},{78,67}}, rotation=0)));
    TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
        use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
      annotation (Placement(transformation(
          origin={48,-66},
          extent={{-6,-3},{6,3}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
        pressureStateID=3, pInitial=3500000) annotation (Placement(transformation(
            extent={{-44,-84},{-32,-72}},
                                        rotation=0)));
    TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                  annotation (Placement(transformation(extent={{42,-48},{54,-28}},
            rotation=0)));
    TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
      volumetricEfficiency=0.8,
      use_mechanicalPort=false,
      use_relDisplacementInput=false,
      displacement=3.33e-6,
      nFixed=120,
      effectiveIsentropicEfficiency=1,
      isentropicEfficiency=0.75)         annotation (Placement(transformation(
            extent={{73,27},{87,41}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      dpFixed=0,
      presetVariableType="m_flow",
      m_flowFixed=0.202)
                        annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=-90,
          origin={24,-92})));
    TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
      annotation (Placement(transformation(extent={{-35,-102},{-29,-88}})));
    TIL.LiquidComponents.Boundaries.Boundary boundary1(
      m_flowFixed=0.02,
      boundaryType="p",
      TFixed=285.15)
      annotation (Placement(transformation(extent={{36,-103},{42,-88}})));
    Boreholes.UTube borehole(
      redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
      dp_nominal(displayUnit="bar") = 10000,
      xC=0.04,
      matFil(
        k=2.1,
        c=750,
        d=2300),
      rTub=0.0125,
      kTub=0.46,
      eTub=0.0035,
      rExt=2,
      samplePeriod=604800,
      rBor=0.08,
      nVer=10,
      nHor=10,
      m_flow_nominal=0.3,
      redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
        c=1696,
        d=1932,
        k=1.86),
      T_start=291.15,
      hBor=201,
      TExt0_start=291.15)
      annotation (Placement(transformation(extent={{-35,85},{-20,100}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-30,87},{-50,107}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-25,87},{-5,107}})));
    inner Modelica.Fluid.System system(T_start=308.15)
      annotation (Placement(transformation(extent={{-98,82},{-84,96}})));

    Modelica.SIunits.Power Q_borehole;
    Modelica.SIunits.Power q_borehole;
    Real COP_Cooling;

    TIL.GasComponents.Boundaries.Boundary boundary2(
      V_flowFixed=-0.2,
      boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      TFixed(displayUnit="K") = 308.15,
      phiFixed=80,
      use_temperatureInput=true)
                        annotation (Placement(transformation(
          extent={{-3,-7},{3,7}},
          rotation=0,
          origin={-5,42})));
    TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=30)
      annotation (Placement(transformation(
          extent={{-3,-6},{3,6}},
          rotation=180,
          origin={45,42})));
    TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.181)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={8,42})));
    TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
      SupplementalRejector(
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      hxGeometry(
        nTubeSideParallelHydraulicFlows=2,
        nSerialTubes=2,
        finnedTubeLength=0.33,
        nParallelTubes=18))
      annotation (Placement(transformation(extent={{18,38},{38,58}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
      annotation (Placement(transformation(extent={{1,59},{9,67}},   rotation=0)));
    TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
      pressureStateID_a=2,
      pressureStateID_b=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      thermalResistance=0.001,
      heatCapacityInputType="m, solid",
      solidMass=2.5,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      nCells=5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      thermalResistanceInputType="l, A, lambda",
      hxGeometry(
        innerDiameter_a=0.008,
        innerDiameter_b=0.012,
        length_a=0.382,
        length_b=0.382),
      crossSection=0.012)
      annotation (Placement(transformation(extent={{-7,-7},{7,7}},
          rotation=90,
          origin={76,2})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
      annotation (Placement(transformation(extent={{-59,59},{-51,67}},
                                                                     rotation=0)));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX gasCooler(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=1,
      m_flowStart_b=-0.5,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.314,
        width=0.07,
        patternAmplitude=2e-3,
        numberOfPlates=30),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-35,49},{-13,71}},
            rotation=0)));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX Evaperater(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_b=-0.5,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.314,
        width=0.07,
        patternAmplitude=2e-3,
        numberOfPlates=30),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      pressureStateID=3,
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-14,-73},{8,-95}},
            rotation=0)));

    TIL.VLEFluidComponents.Ejectors.EffEjector effEjector
      annotation (Placement(transformation(extent={{-68,-42},{-52,-26}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp1(
        pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
            extent={{-14,-40},{-2,-28}},rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=8)
      annotation (Placement(transformation(extent={{66,-49},{74,-41}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=4)
      annotation (Placement(transformation(extent={{-94,-29},{-86,-21}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=10)
      annotation (Placement(transformation(extent={{-84,-71},{-76,-63}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=5)
      annotation (Placement(transformation(extent={{-42,-23},{-34,-15}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint9(stateViewerIndex=6)
      annotation (Placement(transformation(extent={{60,-25},{68,-17}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint10(stateViewerIndex=9)
      annotation (Placement(transformation(extent={{66,-73},{74,-65}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=7)
      annotation (Placement(transformation(extent={{88,17},{96,25}}, rotation=0)));
    TIL.LiquidComponents.Sensors.Sensor_T sensor_T
      annotation (Placement(transformation(extent={{2,84},{10,92}})));
    TIL.LiquidComponents.Sensors.Sensor_T sensor_T1 annotation (Placement(
          transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-52,88})));
  equation
    connect(compressor.portB, pressureState_hp.portA) annotation (Line(
        points={{80,41},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5));

    connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-76.5,80},{-80,80},{-80,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
        points={{-39,97},{-39,98.95},{-33.9875,98.95}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));

    Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.path_b.T_liq_A-gasCooler.summary.path_b.T_liq_B);
    q_borehole = Q_borehole/2/borehole.hBor;
    COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

    connect(boundary2.port,simpleFan. portA) annotation (Line(
        points={{-5,42},{2,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
        points={{14,42},{18,42},{18,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
       Line(
        points={{38,53.7143},{48,53.7143},{48,54},{56,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
        points={{38,42.2857},{45,42.2857},{45,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
        points={{68,54},{74,54},{74,59}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
        points={{-21.0125,98.9125},{-18.5063,98.9125},{-18.5063,97},{-16,97}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
      annotation (Line(
        points={{5,59},{5,54},{18,54},{18,53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
        points={{53,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
        points={{80,9},{80,27}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portB_a, SupplementalRejector.portA_vle) annotation (Line(
        points={{-13,53.7143},{-6,53.7143},{-6,54},{2,54},{2,53.7143},{18,
            53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasCooler.portA_b, pump.portB) annotation (Line(
        points={{-35,66.2857},{-44.5,66.2857},{-44.5,80},{-62.5,80}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portB_b) annotation (
        Line(
        points={{-14,97},{-8,97},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portA_a, SuctionGasHeatExchager.portB_b) annotation (Line(
        points={{-35,53.7143},{-80,53.7143},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint3.sensorPort, SuctionGasHeatExchager.portB_b) annotation (
        Line(
        points={{-55,59},{-55,54},{-80,54},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
        points={{8,-90.2857},{12,-90.2857},{12,-92},{18,-92}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portA_b, effEjector.drivingPort) annotation (
       Line(
        points={{72,-5},{72,-8},{-76,-8},{-76,-34},{-68,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portLiquid, expansionValve.portA) annotation (Line(
        points={{48,-48},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp.portA, Evaperater.portA_a) annotation (Line(
        points={{-32,-78},{-18,-78},{-18,-77.7143},{-14,-77.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.suctionPort, pressureState_lp.portB) annotation (Line(
        points={{-60,-42},{-60,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary.port, Evaperater.portA_b) annotation (Line(
        points={{-32,-95},{-24,-95},{-24,-90.2857},{-14,-90.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.dischargePort, pressureState_lp1.portB) annotation (Line(
        points={{-52,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp1.portA, separator.portInlet) annotation (Line(
        points={{-2,-34},{43,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
        points={{70,-49},{70,-54},{48,-54},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_a, expansionValve.portB) annotation (Line(
        points={{8,-77.7143},{28,-77.7143},{28,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint5.sensorPort, effEjector.drivingPort) annotation (Line(
        points={{-90,-29},{-90,-34},{-68,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
        points={{-80,-71},{-80,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint7.sensorPort, pressureState_lp1.portB) annotation (Line(
        points={{-38,-23},{-38,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simplePump.portA, boundary1.port) annotation (Line(
        points={{30,-92},{34,-92},{34,-95.5},{39,-95.5}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint9.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
       Line(
        points={{64,-25},{64,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint10.sensorPort, expansionValve.portB) annotation (Line(
        points={{70,-73},{70,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
        points={{92,17},{92,14},{80,14},{80,27}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T.port, gasCooler.portB_b) annotation (Line(
        points={{6,84},{6,78},{-8,78},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T1.port, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-48,88},{-44,88},{-44,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}),
              graphics),
      experiment(StopTime=600),
      experimentSetupOutput,
      Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
  end CO2HybridGCHP_035_PlateHX;

  package MaterialsforGLorentzen
    model BoreholeTestWithInletTempVariation

      InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
            Modelica.Media.Examples.TwoPhaseWater)
        annotation (Placement(transformation(extent={{14,-4},{-6,16}})));
      InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
          = Modelica.Media.Examples.TwoPhaseWater)
        annotation (Placement(transformation(extent={{34,-4},{54,16}})));
      inner TIL.SystemInformationManager sim(redeclare
          TILMedia.LiquidTypes.TILMedia_Water liquidType1)
        annotation (Placement(transformation(extent={{-79,81},{-61,99}})));
      inner Modelica.Fluid.System system
        annotation (Placement(transformation(extent={{-98,82},{-82,98}})));
      TIL.LiquidComponents.Pumps.SimplePump simplePump(
        presetVariableType="dp",
        use_massFlowRateInput=false,
        dpFixed=10000)   annotation (Placement(transformation(
            extent={{-8,-8},{8,8}},
            rotation=-90,
            origin={-16,6})));

      Modelica.SIunits.Power Q_borehole;
      Modelica.SIunits.Power q_borehole;

      Boreholes.UTube borehole(
        redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
        dp_nominal(displayUnit="bar") = 10000,
        xC=0.04,
        matFil(
          k=2.1,
          c=750,
          d=2300),
        rTub=0.0125,
        kTub=0.46,
        eTub=0.0035,
        rExt=2,
        samplePeriod=604800,
        rBor=0.08,
        nVer=10,
        nHor=10,
        hBor=200,
        m_flow_nominal=0.35,
        redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
          c=1696,
          d=1932,
          k=1.86),
        T_start=291.15,
        TExt0_start=291.15)
        annotation (Placement(transformation(extent={{15,-14},{33,4}})));
      TIL.LiquidComponents.Boundaries.Boundary boundary(
        boundaryType="p",
        use_massFlowRateInput=false,
        use_temperatureInput=true,
        TFixed=299.15)
        annotation (Placement(transformation(extent={{-44,-4},{-36,16}})));
      TIL.LiquidComponents.Boundaries.Boundary boundary1(
                                                        boundaryType="p")
        annotation (Placement(transformation(extent={{56,-4},{64,16}})));
      Modelica.Blocks.Sources.Ramp Temp(
        height=30,
        duration=8640000,
        startTime=864000,
        offset=293.15)
        annotation (Placement(transformation(extent={{-70,-4},{-54,12}})));
    equation
      Q_borehole = borehole.m_flow_nominal*4198*(borehole.Tdown[1]-borehole.Tup[1]);
      q_borehole = Q_borehole/borehole.hBor;

      connect(simplePump.portB, interfaceMFtoTILLiquid.liquidPort) annotation (
          Line(
          points={{-8,6},{3,6}},
          color={0,170,238},
          thickness=0.5,
          smooth=Smooth.None));
      connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
          points={{5,6},{10,6},{10,2.74},{16.215,2.74}},
          color={23,162,255},
          thickness=0.5,
          smooth=Smooth.None));
      connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
          points={{31.785,2.695},{38.4937,2.695},{38.4937,6},{43,6}},
          color={23,162,255},
          thickness=0.5,
          smooth=Smooth.None));
      connect(interfaceMFtoTILLiquid1.liquidPort, boundary1.port) annotation (Line(
          points={{45,6},{60,6}},
          color={0,170,238},
          thickness=0.5,
          smooth=Smooth.None));
      connect(boundary.port, simplePump.portA) annotation (Line(
          points={{-40,6},{-24,6}},
          color={0,170,238},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Temp.y, boundary.T_in) annotation (Line(
          points={{-53.2,4},{-44,4}},
          color={0,0,127},
          smooth=Smooth.None));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}),      graphics));
    end BoreholeTestWithInletTempVariation;

    package OptimizePressureStage2
      model BasisSizeFor80bar "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(
          use_massFlowRateInput=false,
          m_flowFixed=-0.245,
          presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,7},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1,
          fixedInitialPressure=false,
          pInitial=7500000)                      annotation (Placement(transformation(
                extent={{48,-12},{60,0}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          solidMass=18,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26,
            length_b=26),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,-11},
                  {-38,12}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{64,-1},{72,7}},  rotation=0)));

        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          hBor=200,
          m_flow_nominal=0.3,
          dp_nominal(displayUnit="bar") = 10000,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-37,23},{-22,38}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,27},{-50,47}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,27},{-5,47}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=80,
          use_temperatureInput=false,
          TFixed(displayUnit="K") = 305.15)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,-18})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,-18})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={7,-18})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nParallelTubes=18,
            finnedTubeLength=0.44,
            nSerialTubes=2))
          annotation (Placement(transformation(extent={{18,-23},{40,-1}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,-1},{9,7}},    rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,-1},{-43,7}},rotation=0)));
        TIL.VLEFluidComponents.Boundaries.BoundaryOverdetermined
          boundaryOverdetermined(
          streamVariablesInputType="T",
          m_flowFixed=-0.03,
          use_temperatureInput=true,
          use_pressureInput=true,
          pFixed=7500000,
          TFixed=343.15)
          annotation (Placement(transformation(extent={{80,-16},{72,4}})));
        TIL.VLEFluidComponents.Boundaries.BoundaryUnderdetermined
          boundaryUnderdetermined(streamVariablesInputType="T")
          annotation (Placement(transformation(extent={{-84,-16},{-76,4}})));
        Modelica.Blocks.Sources.Ramp Pressure(
          duration=18640000,
          startTime=8640000,
          height=100,
          offset=8000000)
          annotation (Placement(transformation(extent={{64,20},{80,36}})));
        Modelica.Blocks.Sources.Ramp Temp(
          duration=18640000,
          startTime=8640000,
          height=0.1,
          offset=350)
          annotation (Placement(transformation(extent={{64,-42},{80,-26}})));
      equation

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,7.07143},{-44,7.07143},{-44,7},{-54.5,7}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,37},{4,37},{4,7.07143},{-16,7.07143}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,7},{-80,7},{-80,37},{-41,37}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,37},{-39,36.95},{-35.9875,36.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/borehole.hBor;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,-18},{1,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{13,-18},{18,-18},{18,-18.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{40,-5.71429},{48,-5.71429},{48,-6}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{40,-18.2857},{45,-18.2857},{45,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{60,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-23.0125,36.9125},{-18.5063,36.9125},{-18.5063,37},{-16,37}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,-6.07143},{2,-6.07143},{2,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,-1},{5,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,-1},{-47,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryUnderdetermined.port, gasCooler.portB_a) annotation (
            Line(
            points={{-80,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryOverdetermined.port, statePoint1.sensorPort)
          annotation (Line(
            points={{76,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Pressure.y, boundaryOverdetermined.p_in) annotation (Line(
            points={{80.8,28},{90,28},{90,0},{80,0}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(Temp.y, boundaryOverdetermined.T_in) annotation (Line(
            points={{80.8,-34},{90,-34},{90,-8},{80,-8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end BasisSizeFor80bar;

      model BasisSizeFor80barAmbientTemp "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(
          use_massFlowRateInput=false,
          m_flowFixed=-0.245,
          presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,7},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1,
          fixedInitialPressure=false,
          pInitial=7500000)                      annotation (Placement(transformation(
                extent={{48,-12},{60,0}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          solidMass=18,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26,
            length_b=26),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,-11},
                  {-38,12}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{64,-1},{72,7}},  rotation=0)));

        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          hBor=200,
          m_flow_nominal=0.3,
          dp_nominal(displayUnit="bar") = 10000,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-37,23},{-22,38}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,27},{-50,47}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,27},{-5,47}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=80,
          TFixed(displayUnit="K") = 305.15,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,-18})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,-18})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={7,-18})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nParallelTubes=18,
            finnedTubeLength=0.44,
            nSerialTubes=2))
          annotation (Placement(transformation(extent={{18,-23},{40,-1}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,-1},{9,7}},    rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,-1},{-43,7}},rotation=0)));
        TIL.VLEFluidComponents.Boundaries.BoundaryOverdetermined
          boundaryOverdetermined(
          streamVariablesInputType="T",
          m_flowFixed=-0.03,
          use_temperatureInput=true,
          use_pressureInput=true,
          pFixed=7500000,
          TFixed=343.15)
          annotation (Placement(transformation(extent={{80,-16},{72,4}})));
        TIL.VLEFluidComponents.Boundaries.BoundaryUnderdetermined
          boundaryUnderdetermined(streamVariablesInputType="T")
          annotation (Placement(transformation(extent={{-84,-16},{-76,4}})));
        Modelica.Blocks.Sources.Ramp Pressure(
          duration=18640000,
          startTime=8640000,
          height=2500000,
          offset=7500000)
          annotation (Placement(transformation(extent={{64,20},{80,36}})));
        Modelica.Blocks.Sources.Ramp Temp(
          duration=18640000,
          startTime=8640000,
          offset=343.88,
          height=29)
          annotation (Placement(transformation(extent={{64,-42},{80,-26}})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,-36},{-20,-20}})));
      equation

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,7.07143},{-44,7.07143},{-44,7},{-54.5,7}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,37},{4,37},{4,7.07143},{-16,7.07143}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,7},{-80,7},{-80,37},{-41,37}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,37},{-39,36.95},{-35.9875,36.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/borehole.hBor;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,-18},{1,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{13,-18},{18,-18},{18,-18.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{40,-5.71429},{48,-5.71429},{48,-6}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{40,-18.2857},{45,-18.2857},{45,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{60,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-23.0125,36.9125},{-18.5063,36.9125},{-18.5063,37},{-16,37}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,-6.07143},{2,-6.07143},{2,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,-1},{5,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,-1},{-47,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryUnderdetermined.port, gasCooler.portB_a) annotation (
            Line(
            points={{-80,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryOverdetermined.port, statePoint1.sensorPort)
          annotation (Line(
            points={{76,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Pressure.y, boundaryOverdetermined.p_in) annotation (Line(
            points={{80.8,28},{90,28},{90,0},{80,0}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(Temp.y, boundaryOverdetermined.T_in) annotation (Line(
            points={{80.8,-34},{90,-34},{90,-8},{80,-8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,-28},{-14,-28},{-14,-22.2},{-8,-22.2}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end BasisSizeFor80barAmbientTemp;

      model BasisSizeFor80bar_Constant "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(
          use_massFlowRateInput=false,
          m_flowFixed=-0.245,
          presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,7},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1,
          fixedInitialPressure=false,
          pInitial=7500000)                      annotation (Placement(transformation(
                extent={{48,-12},{60,0}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          solidMass=18,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26,
            length_b=26),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,-11},
                  {-38,12}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{64,-1},{72,7}},  rotation=0)));

        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          hBor=200,
          m_flow_nominal=0.3,
          dp_nominal(displayUnit="bar") = 10000,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-37,23},{-22,38}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,27},{-50,47}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,27},{-5,47}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=80,
          TFixed(displayUnit="K") = 305.15,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,-18})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,-18})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={7,-18})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nParallelTubes=18,
            finnedTubeLength=0.44,
            nSerialTubes=2),
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000))
          annotation (Placement(transformation(extent={{18,-23},{40,-1}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,-1},{9,7}},    rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,-1},{-43,7}},rotation=0)));
        TIL.VLEFluidComponents.Boundaries.BoundaryOverdetermined
          boundaryOverdetermined(
          streamVariablesInputType="T",
          m_flowFixed=-0.03,
          use_pressureInput=false,
          pFixed=8000000,
          use_temperatureInput=false,
          TFixed=349.95)
          annotation (Placement(transformation(extent={{80,-16},{72,4}})));
        TIL.VLEFluidComponents.Boundaries.BoundaryUnderdetermined
          boundaryUnderdetermined(streamVariablesInputType="T")
          annotation (Placement(transformation(extent={{-84,-16},{-76,4}})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,-36},{-20,-20}})));
      equation

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,7.07143},{-44,7.07143},{-44,7},{-54.5,7}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,37},{4,37},{4,7.07143},{-16,7.07143}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,7},{-80,7},{-80,37},{-41,37}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,37},{-39,36.95},{-35.9875,36.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/borehole.hBor;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,-18},{1,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{13,-18},{18,-18},{18,-18.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{40,-5.71429},{48,-5.71429},{48,-6}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{40,-18.2857},{45,-18.2857},{45,-18}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{60,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-23.0125,36.9125},{-18.5063,36.9125},{-18.5063,37},{-16,37}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,-6.07143},{2,-6.07143},{2,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,-1},{5,-6},{18,-6},{18,-5.71429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,-1},{-47,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryUnderdetermined.port, gasCooler.portB_a) annotation (
            Line(
            points={{-80,-6},{-38,-6},{-38,-6.07143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(boundaryOverdetermined.port, statePoint1.sensorPort)
          annotation (Line(
            points={{76,-6},{68,-6},{68,-1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,-28},{-14,-28},{-14,-22.2},{-8,-22.2}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end BasisSizeFor80bar_Constant;
    end OptimizePressureStage2;

    package CO2GCHPAirCoolingCapacity
      model CO2HybridGCHP_00_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{42,22},{54,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=17,
            length_b=17),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=13,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.424)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{16,-66},{28,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.5,
            length_b=14.5),
          crossSection=0.457)
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=310,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{17,33},{25,41}}, rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{54,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{28,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{16,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{54,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{16,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, pressureState_hp.portB) annotation (Line(
            points={{-16,27.9286},{20,27.9286},{20,28},{42,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, pressureState_hp.portB) annotation (Line(
            points={{21,33},{21,28},{42,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_00_AirCooling;

      model CO2HybridGCHP_01_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=19,
            length_b=19),
          crossSection=0.476)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=280,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.032)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=6,
            finnedTubeLength=0.17))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_01_AirCooling;

      model CO2HybridGCHP_02_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=21.5,
            length_b=21.5),
          crossSection=0.54)              annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=250,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.077)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            finnedTubeLength=0.23,
            nParallelTubes=10))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_02_AirCooling;

      model CO2HybridGCHP_03_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=24.2,
            length_b=24.2),
          crossSection=0.61)              annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=217,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.142)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            finnedTubeLength=0.32,
            nParallelTubes=14))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_03_AirCooling;

      model CO2HybridGCHP_035_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=25.4,
            length_b=25.4),
          crossSection=0.637)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=201,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.181)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            finnedTubeLength=0.33,
            nParallelTubes=18))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_035_AirCooling;

      model CO2HybridGCHP_04_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=185,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling;

      model CO2HybridGCHP_05_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          crossSection=0.622,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=21.3,
            length_b=21.3))               annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.339e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.20) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=155,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.313)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            finnedTubeLength=0.59,
            nParallelTubes=24))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_05_AirCooling;

      model CO2HybridGCHP_06_AirCooling "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=22,
            length_b=22),
          crossSection=0.552,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000))       annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.362e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6),
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=124,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.416)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nParallelTubes=24,
            finnedTubeLength=0.67,
            nSerialTubes=3),
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-34,0},{-20,13}})));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000))
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.3,6.5},{-13.65,6.5},{-13.65,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-80,27.9286},{-80,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_06_AirCooling;
    end CO2GCHPAirCoolingCapacity;

    package CO2GCHPAirCoolingPressure

      model CO2HybridGCHP_04_AirCoolingWithTemp "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=true)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=185,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Ramp FlowArea(
          offset=2.9e-7,
          height=5.2e-7,
          duration=864000,
          startTime=2864000)
          annotation (Placement(transformation(extent={{-80,-24},{-64,-8}})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(FlowArea.y, expansionValve.effectiveFlowArea_in)    annotation (
           Line(
            points={{-63.2,-16},{-60,-16},{-60,-46},{-76.25,-46}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCoolingWithTemp;

      model CO2HybridGCHP_04_AirCoolingWithoutTemp "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=true)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=185,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=false)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Ramp FlowArea(
          offset=2.9e-7,
          height=5.2e-7,
          duration=864000,
          startTime=2864000)
          annotation (Placement(transformation(extent={{-80,-24},{-64,-8}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(FlowArea.y, expansionValve.effectiveFlowArea_in)    annotation (
           Line(
            points={{-63.2,-16},{-60,-16},{-60,-46},{-76.25,-46}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCoolingWithoutTemp;

    end CO2GCHPAirCoolingPressure;

    package CO2GCHPAirCoolingDepth

      model CO2HybridGCHP_04_AirCooling_5 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=743,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_5;

      model CO2HybridGCHP_04_AirCooling_10 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=371,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_10;

      model CO2HybridGCHP_04_AirCooling_15 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=247,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_15;

      model CO2HybridGCHP_04_AirCooling_20 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=185,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_20;

      model CO2HybridGCHP_04_AirCooling_25 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          hBor=148,
          T_start=291.15,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_25;

      model CO2HybridGCHP_04_AirCooling_30 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=124,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_30;

      model CO2HybridGCHP_04_AirCooling_35 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=106,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_35;

      model CO2HybridGCHP_04_AirCooling_40 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=93,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_40;

      model CO2HybridGCHP_04_AirCooling_45 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=82.6,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_45;

      model CO2HybridGCHP_04_AirCooling_50 "Heat Pump Cycle CO2"

        inner TIL.SystemInformationManager sim(
          redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
          redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
          redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
            Placement(transformation(extent={{80,80},{100,100}}, rotation=0)));

        TIL.LiquidComponents.Pumps.SimplePump pump(m_flowFixed=0.034,
            presetVariableType="dp")
                              annotation (Placement(transformation(
              origin={-61.5,41},
              extent={{-7,-7},{7,7}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
            pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
                extent={{56,22},{68,34}}, rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX gasCooler(
          pressureStateID=1,
          nCells=10,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          heatCapacity=1,
          hInitialVLEFluid_a=350e3,
          initVLEFluid_a="linearEnthalpyDistribution",
          hInitialVLEFluid_a_CellN=300e3,
          hInitialVLEFluid_a_Cell1=500e3,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          solidMass=15,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            innerDiameter_a=0.006,
            innerDiameter_b=0.012,
            length_a=26.1,
            length_b=26.1),
          crossSection=0.656)             annotation (Placement(transformation(extent={{-16,23},
                  {-38,46}},        rotation=0)));

        TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
          annotation (Placement(transformation(extent={{70,33},{78,41}}, rotation=0)));
        TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
            use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=0.3617e-6)
          annotation (Placement(transformation(
              origin={-80,-46},
              extent={{-6,-3},{6,3}},
              rotation=270)));

        TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
            pressureStateID=2, pInitial=3500000) annotation (Placement(transformation(
                extent={{12,-66},{24,-54}}, rotation=0)));
        TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=0.5e-3)
                      annotation (Placement(transformation(extent={{42,-74},{54,-54}},
                rotation=0)));
        TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
          volumetricEfficiency=0.8,
          use_mechanicalPort=false,
          use_relDisplacementInput=false,
          displacement=3.33e-6,
          nFixed=120,
          effectiveIsentropicEfficiency=1,
          isentropicEfficiency=0.75)         annotation (Placement(transformation(
                extent={{73,1},{87,15}},  rotation=0)));

        TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Evaperater(
          pressureStateID=2,
          nCells=10,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatCapacityInputType="m, solid",
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          heatDistance=0.001,
          thermalResistance=6e-5,
          thermalResistanceInputType="l, A, lambda",
          thermalConductivity=40,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          crossSection=0.503,
          solidMass=20,
          redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
            hxGeometry(
            crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
            innerDiameter_a=0.008,
            innerDiameter_b=0.02,
            length_a=14.6,
            length_b=14.6))
          annotation (Placement(transformation(extent={{-36,-55},{-12,-79}})));

        TIL.LiquidComponents.Pumps.SimplePump simplePump(
          dpFixed=0,
          presetVariableType="m_flow",
          m_flowFixed=0.202)
                            annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=-90,
              origin={0,-74})));
        TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=280.15)
          annotation (Placement(transformation(extent={{-51,-84},{-45,-70}})));
        TIL.LiquidComponents.Boundaries.Boundary boundary1(
          m_flowFixed=0.02,
          boundaryType="p",
          TFixed=285.15)
          annotation (Placement(transformation(extent={{14,-85},{20,-70}})));
        Boreholes.UTube borehole(
          redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
          dp_nominal(displayUnit="bar") = 10000,
          xC=0.04,
          matFil(
            k=2.1,
            c=750,
            d=2300),
          rTub=0.0125,
          kTub=0.46,
          eTub=0.0035,
          rExt=2,
          samplePeriod=604800,
          rBor=0.08,
          nVer=10,
          nHor=10,
          m_flow_nominal=0.3,
          redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
            c=1696,
            d=1932,
            k=1.86),
          T_start=291.15,
          hBor=74,
          TExt0_start=291.15)
          annotation (Placement(transformation(extent={{-35,57},{-20,72}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-30,61},{-50,81}})));
        InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium
            = Modelica.Media.Examples.TwoPhaseWater)
          annotation (Placement(transformation(extent={{-25,61},{-5,81}})));
        inner Modelica.Fluid.System system(T_start=308.15)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

        Modelica.SIunits.Power Q_borehole;
        Modelica.SIunits.Power q_borehole;
        Real COP_Cooling;

        TIL.GasComponents.Boundaries.Boundary boundary2(
          V_flowFixed=-0.2,
          boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          TFixed(displayUnit="K") = 308.15,
          phiFixed=80,
          use_temperatureInput=true)
                            annotation (Placement(transformation(
              extent={{-3,-7},{3,7}},
              rotation=0,
              origin={-5,16})));
        TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
          streamVariablesInputTypeConcentration="phi",
          phiFixed=30)
          annotation (Placement(transformation(
              extent={{-3,-6},{3,6}},
              rotation=180,
              origin={45,16})));
        TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=0.229)
          annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={8,16})));
        TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
          SupplementalRejector(
          redeclare model TubeSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          redeclare model FinSideHeatTransferModel =
              TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          hxGeometry(
            nTubeSideParallelHydraulicFlows=2,
            nSerialTubes=2,
            nParallelTubes=18,
            finnedTubeLength=0.35))
          annotation (Placement(transformation(extent={{18,12},{38,32}})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
          annotation (Placement(transformation(extent={{1,33},{9,41}},   rotation=0)));
        TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
          pressureStateID_a=2,
          pressureStateID_b=1,
          redeclare model PressureDropModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          redeclare model PressureDropModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
          thermalResistance=0.001,
          heatCapacityInputType="m, solid",
          solidMass=2.5,
          redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
          nCells=5,
          redeclare model HeatTransferModel_a =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          redeclare model HeatTransferModel_b =
              TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
              (constantAlpha=2000),
          thermalResistanceInputType="l, A, lambda",
          hxGeometry(
            innerDiameter_a=0.008,
            innerDiameter_b=0.012,
            length_a=0.382,
            length_b=0.382),
          crossSection=0.012)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=90,
              origin={76,-20})));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
          annotation (Placement(transformation(extent={{-51,33},{-43,41}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
          annotation (Placement(transformation(extent={{45,-25},{53,-17}},
                                                                         rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
          annotation (Placement(transformation(extent={{-50,-55},{-42,-47}},
                                                                          rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
          annotation (Placement(transformation(extent={{-1,-55},{7,-47}},  rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
          annotation (Placement(transformation(extent={{65,-55},{73,-47}}, rotation=0)));
        TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
          annotation (Placement(transformation(extent={{-4,-4},{4,4}},     rotation=90,
              origin={71,-5})));
        Modelica.Blocks.Sources.Trapezoid TempVariation(
          startTime=7200,
          rising=36000,
          width=7200,
          falling=36000,
          period=86400,
          offset=308.15,
          amplitude=-11)
          annotation (Placement(transformation(extent={{-36,0},{-20,15}})));
      equation
        connect(compressor.portB, pressureState_hp.portA) annotation (Line(
            points={{80,15},{80,28},{68,28}},
            color={153,204,0},
            thickness=0.5));

        connect(gasCooler.portB_b, pump.portB) annotation (Line(
            points={{-38,41.0714},{-44,41.0714},{-44,41},{-54.5,41}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
            points={{24,-60},{43,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
            points={{-80,-52},{-80,-60.1429},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_a, pressureState_lp.portB) annotation (Line(
            points={{-12,-60.1429},{2,-60.1429},{2,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portA_b) annotation (
            Line(
            points={{-14,71},{4,71},{4,41.0714},{-16,41.0714}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
            points={{-68.5,41},{-80,41},{-80,71},{-41,71}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
            points={{-39,71},{-39,70.95},{-33.9875,70.95}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));

        Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.tube_b.T_liq_A-gasCooler.summary.tube_b.T_liq_B);
        q_borehole = Q_borehole/2/borehole.hBor;
        COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

        connect(boundary2.port,simpleFan. portA) annotation (Line(
            points={{-5,16},{2,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
            points={{14,16},{18,16},{18,16.2857}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
           Line(
            points={{38,27.7143},{48,27.7143},{48,28},{56,28}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
            points={{38,16.2857},{45,16.2857},{45,16}},
            color={255,153,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(pressureState_hp.portA, statePoint1.sensorPort) annotation (Line(
            points={{68,28},{74,28},{74,33}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
            points={{-12,-73.8571},{-6,-73.8571},{-6,-74}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(simplePump.portA, boundary1.port) annotation (Line(
            points={{6,-74},{11,-74},{11,-77.5},{17,-77.5}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Evaperater.portA_b, boundary.port) annotation (Line(
            points={{-36,-73.8571},{-42,-73.8571},{-42,-77},{-48,-77}},
            color={0,170,238},
            thickness=0.5,
            smooth=Smooth.None));
        connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
            points={{-21.0125,70.9125},{-18.5063,70.9125},{-18.5063,71},{-16,71}},
            color={23,162,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portA_a, SupplementalRejector.portA_vle) annotation (Line(
            points={{-16,27.9286},{2,27.9286},{2,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint2.sensorPort, SupplementalRejector.portA_vle)
          annotation (Line(
            points={{5,33},{5,28},{18,28},{18,27.7143}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(gasCooler.portB_a, SuctionGasHeatExchager.portB_b) annotation (Line(
            points={{-38,27.9286},{-60,27.9286},{-60,-10},{72,-10},{72,-13}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portA_b, expansionValve.portA) annotation (
            Line(
            points={{72,-27},{72,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
            points={{53,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
            points={{80,-13},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint3.sensorPort, gasCooler.portB_a) annotation (Line(
            points={{-47,33},{-46.5,33},{-46.5,27.9286},{-38,27.9286}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint4.sensorPort, expansionValve.portA) annotation (Line(
            points={{49,-25},{49,-30},{-80,-30},{-80,-40}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint5.sensorPort, Evaperater.portA_a) annotation (Line(
            points={{-46,-55},{-46,-60},{-36,-60},{-36,-60.1429}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint6.sensorPort, pressureState_lp.portB) annotation (Line(
            points={{3,-55},{3,-60},{12,-60}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
           Line(
            points={{69,-55},{69,-60},{80,-60},{80,-27}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(statePoint8.sensorPort, compressor.portA) annotation (Line(
            points={{75,-5},{80,-5},{80,1}},
            color={153,204,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TempVariation.y, boundary2.T_in) annotation (Line(
            points={{-19.2,7.5},{-14,7.5},{-14,11.8},{-8,11.8}},
            color={0,0,127},
            smooth=Smooth.None));
        annotation (
          Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}),
                  graphics),
          experiment(StopTime=600),
          experimentSetupOutput,
          Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
      end CO2HybridGCHP_04_AirCooling_50;
    end CO2GCHPAirCoolingDepth;
  end MaterialsforGLorentzen;

  model CO2HybridGCHP_Ejector_Basic "Heat Pump Cycle CO2"

    inner TIL.SystemInformationManager sim(
      redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
        Placement(transformation(extent={{86,82},{100,100}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump pump(presetVariableType="m_flow",
        m_flowFixed=0.23) annotation (Placement(transformation(
          origin={-69.5,78},
          extent={{-7,-7},{7,7}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
        pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
            extent={{56,48},{68,60}}, rotation=0)));

    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{90,17},{98,25}}, rotation=0)));
    TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
        use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=8.39e-7)
      annotation (Placement(transformation(
          origin={48,-66},
          extent={{-6,-3},{6,3}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
        pressureStateID=3, pInitial=3500000) annotation (Placement(transformation(
            extent={{-44,-84},{-32,-72}},
                                        rotation=0)));
    TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=3e-3)
                  annotation (Placement(transformation(extent={{42,-48},{54,-28}},
            rotation=0)));
    TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
      volumetricEfficiency=0.8,
      use_mechanicalPort=false,
      use_relDisplacementInput=false,
      displacement=3.33e-6,
      nFixed=120,
      effectiveIsentropicEfficiency=1,
      isentropicEfficiency=0.75)         annotation (Placement(transformation(
            extent={{73,27},{87,41}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      dpFixed=0,
      presetVariableType="m_flow",
      m_flowFixed=0.16) annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=-90,
          origin={24,-92})));
    TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=
          280.15)
      annotation (Placement(transformation(extent={{-35,-102},{-29,-88}})));
    TIL.LiquidComponents.Boundaries.Boundary boundary1(
      m_flowFixed=0.02,
      boundaryType="p",
      TFixed=285.15)
      annotation (Placement(transformation(extent={{36,-103},{42,-88}})));
    Boreholes.UTube borehole(
      redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
      dp_nominal(displayUnit="bar") = 10000,
      xC=0.04,
      matFil(
        k=2.1,
        c=750,
        d=2300),
      rTub=0.0125,
      kTub=0.46,
      eTub=0.0035,
      rExt=2,
      samplePeriod=604800,
      rBor=0.08,
      nVer=10,
      nHor=10,
      m_flow_nominal=0.3,
      redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
        c=1696,
        d=1932,
        k=1.86),
      T_start=291.15,
      hBor=198,
      TExt0_start=291.15)
      annotation (Placement(transformation(extent={{-35,85},{-20,100}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-30,87},{-50,107}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-25,87},{-5,107}})));
    inner Modelica.Fluid.System system(T_start=308.15)
      annotation (Placement(transformation(extent={{-98,82},{-84,96}})));

    Modelica.SIunits.Power Q_borehole;
    Modelica.SIunits.Power q_borehole;
    Real COP_Cooling;

    TIL.GasComponents.Boundaries.Boundary boundary2(
      V_flowFixed=-0.2,
      boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      TFixed(displayUnit="K") = 308.15,
      phiFixed=80,
      use_temperatureInput=false)
                        annotation (Placement(transformation(
          extent={{-3,-7},{3,7}},
          rotation=90,
          origin={-9,34})));
    TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=30)
      annotation (Placement(transformation(
          extent={{-3,-6},{3,6}},
          rotation=0,
          origin={55,42})));
    TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=1.02)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={8,42})));
    TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
      SupplementalRejector(
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      hxGeometry(
        nTubeSideParallelHydraulicFlows=2,
        finnedTubeLength=0.4,
        nSerialTubes=3,
        nParallelTubes=17),
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000))
      annotation (Placement(transformation(extent={{18,38},{38,58}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
      annotation (Placement(transformation(extent={{77,63},{85,71}}, rotation=0)));
    TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
      pressureStateID_a=2,
      pressureStateID_b=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      thermalResistance=0.001,
      heatCapacityInputType="m, solid",
      solidMass=2.5,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      nCells=5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      thermalResistanceInputType="l, A, lambda",
      hxGeometry(
        innerDiameter_a=0.008,
        innerDiameter_b=0.012,
        length_a=0.382,
        length_b=0.382),
      crossSection=0.012)
      annotation (Placement(transformation(extent={{-7,-7},{7,7}},
          rotation=90,
          origin={76,2})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
      annotation (Placement(transformation(extent={{1,61},{8,68}},   rotation=0)));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX gasCooler(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=1,
      m_flowStart_b=-0.5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.314,
        width=0.07,
        patternAmplitude=2e-3,
        numberOfPlates=9),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-35,49},{-13,71}},
            rotation=0)));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX Evaperater(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_b=-0.5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      pressureStateID=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        length=0.466,
        width=0.1,
        numberOfPlates=14),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-14,-73},{8,-95}},
            rotation=0)));

    TIL.VLEFluidComponents.Ejectors.EffEjector effEjector(
      fixedEffectiveDrivingFlowArea=3.459e-7,
      redeclare model NozzleModel =
          TIL.VLEFluidComponents.Ejectors.NozzleModels.EnergyBalance,
      use_effectiveDrivingFlowAreaInput=true,
      fixedEjectorEfficiency=0.4)
      annotation (Placement(transformation(extent={{-70,-42},{-54,-26}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp1(
        pressureStateID=2, pInitial=3800000) annotation (Placement(transformation(
            extent={{-14,-40},{-2,-28}},rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
      annotation (Placement(transformation(extent={{-60,61},{-52,69}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
      annotation (Placement(transformation(extent={{-94,-29},{-86,-21}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
      annotation (Placement(transformation(extent={{-38,-25},{-30,-17}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
      annotation (Placement(transformation(extent={{60,-25},{68,-17}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint10(stateViewerIndex=10)
      annotation (Placement(transformation(extent={{-84,-71},{-76,-63}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
      annotation (Placement(transformation(extent={{64,-51},{72,-43}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint9(stateViewerIndex=9)
      annotation (Placement(transformation(extent={{70,-74},{78,-66}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{2,84},{10,92}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-52,88})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC2 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-22,42})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={46,32})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{88,48},{96,56}})));
    TIL.OtherComponents.Controllers.PIController
                                             highPressureController(
      yMax=3e-6,
      Ti=10,
      controllerType="PI",
      invertFeedback=true,
      yInitial=0.5e-6,
      k=1e-9,
      activationTime=500,
      yMin=3.459e-7)
      annotation (Placement(transformation(extent={{-46,4},{-54,-4}})));
    Modelica.Blocks.Sources.RealExpression phSetpoint(y=88e5) annotation (
        Placement(transformation(
          origin={-29,0},
          extent={{9,-8},{-9,8}},
          rotation=0)));
    TIL.VLEFluidComponents.Sensors.Sensor_p
                                        sensor_p annotation (Placement(
          transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-6,8})));
  equation
    connect(compressor.portB, pressureState_hp.portA) annotation (Line(
        points={{80,41},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5));

    connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-76.5,78},{-80,78},{-80,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
        points={{-39,97},{-39,98.95},{-33.9875,98.95}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));

    Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.path_b.T_liq_A-gasCooler.summary.path_b.T_liq_B);
    q_borehole = Q_borehole/2/borehole.hBor;
    COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

    connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
        points={{14,42},{18,42},{18,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
       Line(
        points={{38,53.7143},{48,53.7143},{48,54},{56,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
        points={{-21.0125,98.9125},{-18.5063,98.9125},{-18.5063,97},{-16,97}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
        points={{53,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
        points={{80,9},{80,27}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portB_a, SupplementalRejector.portA_vle) annotation (Line(
        points={{-13,53.7143},{-6,53.7143},{-6,54},{2,54},{2,53.7143},{18,
            53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasCooler.portA_b, pump.portB) annotation (Line(
        points={{-35,66.2857},{-44.5,66.2857},{-44.5,78},{-62.5,78}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portB_b) annotation (
        Line(
        points={{-14,97},{-8,97},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portA_a, SuctionGasHeatExchager.portB_b) annotation (Line(
        points={{-35,53.7143},{-80,53.7143},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
        points={{8,-90.2857},{12,-90.2857},{12,-92},{18,-92}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portA_b, effEjector.drivingPort) annotation (
       Line(
        points={{72,-5},{72,-8},{-76,-8},{-76,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portLiquid, expansionValve.portA) annotation (Line(
        points={{48,-48},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp.portA, Evaperater.portA_a) annotation (Line(
        points={{-32,-78},{-18,-78},{-18,-77.7143},{-14,-77.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.suctionPort, pressureState_lp.portB) annotation (Line(
        points={{-62,-42},{-62,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary.port, Evaperater.portA_b) annotation (Line(
        points={{-32,-95},{-24,-95},{-24,-90.2857},{-14,-90.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.dischargePort, pressureState_lp1.portB) annotation (Line(
        points={{-54,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp1.portA, separator.portInlet) annotation (Line(
        points={{-2,-34},{43,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_a, expansionValve.portB) annotation (Line(
        points={{8,-77.7143},{28,-77.7143},{28,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint5.sensorPort, effEjector.drivingPort) annotation (Line(
        points={{-90,-29},{-90,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simplePump.portA, boundary1.port) annotation (Line(
        points={{30,-92},{34,-92},{34,-95.5},{39,-95.5}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint1.sensorPort, compressor.portA) annotation (Line(
        points={{94,17},{94,14},{80,14},{80,27}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint2.sensorPort, pressureState_hp.portA) annotation (Line(
        points={{81,63},{81,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint3.sensorPort, SupplementalRejector.portA_vle) annotation (
       Line(
        points={{4.5,61},{4.5,53.7143},{18,53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint4.sensorPort, SuctionGasHeatExchager.portB_b) annotation (
       Line(
        points={{-56,61},{-56,54},{-80,54},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint8.sensorPort, expansionValve.portA) annotation (Line(
        points={{68,-51},{68,-54},{48,-54},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint6.sensorPort, pressureState_lp1.portB) annotation (Line(
        points={{-34,-25},{-34,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
       Line(
        points={{64,-25},{64,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint10.sensorPort, pressureState_lp.portB) annotation (Line(
        points={{-80,-71},{-80,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint9.sensorPort, expansionValve.portB) annotation (Line(
        points={{74,-74},{74,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC1.port, interfaceMFtoTILLiquid.liquidPort) annotation (
       Line(
        points={{-48,88},{-44,88},{-44,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC.port, gasCooler.portB_b) annotation (Line(
        points={{6,84},{6,82},{-8,82},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC4.port, pressureState_hp.portA) annotation (Line(
        points={{92,48},{92,44},{80,44},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC2.port, simpleFan.portA) annotation (Line(
        points={{-18,42},{2,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC3.port, SupplementalRejector.portB_gas) annotation (
        Line(
        points={{46,36},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary3.port, SupplementalRejector.portB_gas) annotation (Line(
        points={{55,42},{46,42},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary2.port, simpleFan.portA) annotation (Line(
        points={{-9,34},{-8,34},{-8,42},{2,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(phSetpoint.y,highPressureController. u_s) annotation (Line(
        points={{-38.9,0},{-46.2667,0}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(sensor_p.port, effEjector.drivingPort) annotation (Line(
        points={{-6,4},{-6,-8},{-76,-8},{-76,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_p.sensorValue, highPressureController.u_m) annotation (Line(
        points={{-6,10.2},{-50,10.2},{-50,3.86667}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(highPressureController.y, effEjector.effectiveDrivingFlowArea_in)
      annotation (Line(
        points={{-54.2667,0},{-62,0},{-62,-26}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}),
              graphics),
      experiment(StopTime=600),
      experimentSetupOutput,
      Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
  end CO2HybridGCHP_Ejector_Basic;

  model HS1 "Heat Pump Cycle CO2"

    inner TIL.SystemInformationManager sim(
      redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
        Placement(transformation(extent={{86,82},{100,100}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump pump(presetVariableType="m_flow",
        m_flowFixed=0.35) annotation (Placement(transformation(
          origin={-65.5,78},
          extent={{-7,-7},{7,7}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
        pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
            extent={{56,48},{68,60}}, rotation=0)));

    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{90,17},{98,25}}, rotation=0)));
    TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
        effectiveFlowAreaFixed=5.8e-7, use_effectiveFlowAreaInput=true)
      annotation (Placement(transformation(
          origin={-52,-34},
          extent={{-6,-3},{6,3}},
          rotation=270)));

    TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=3e-3)
                  annotation (Placement(transformation(extent={{42,-48},{54,-28}},
            rotation=0)));
    TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
      volumetricEfficiency=0.8,
      use_mechanicalPort=false,
      use_relDisplacementInput=false,
      effectiveIsentropicEfficiency=1,
      nFixed=50,
      displacement=1.6e-5,
      isentropicEfficiency=0.8)          annotation (Placement(transformation(
            extent={{73,23},{87,37}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      dpFixed=0,
      presetVariableType="m_flow",
      m_flowFixed=0.48,
      eta=0.5)          annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=-90,
          origin={24,-92})));
    TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=
          280.15)
      annotation (Placement(transformation(extent={{-49,-88},{-42,-72}})));
    TIL.LiquidComponents.Boundaries.Boundary boundary1(
      m_flowFixed=0.02,
      boundaryType="p",
      TFixed=285.15)
      annotation (Placement(transformation(extent={{36,-103},{42,-88}})));
    Boreholes.UTube borehole(
      dp_nominal(displayUnit="bar") = 10000,
      xC=0.04,
      matFil(
        k=2.1,
        c=750,
        d=2300),
      rTub=0.0125,
      kTub=0.46,
      eTub=0.0035,
      rExt=2,
      samplePeriod=604800,
      rBor=0.08,
      nVer=10,
      nHor=10,
      redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
        c=1696,
        d=1932,
        k=1.86),
      m_flow_nominal=0.35,
      redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
      T_start=291.15,
      hBor=300,
      TExt0_start=291.15)
      annotation (Placement(transformation(extent={{-35,85},{-20,100}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-30,87},{-50,107}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-25,87},{-5,107}})));
    inner Modelica.Fluid.System system(T_start=308.15)
      annotation (Placement(transformation(extent={{-98,82},{-84,96}})));

    Modelica.SIunits.Power Q_borehole;
    Modelica.SIunits.Power q_borehole;
    Real COP_Cooling;

    TIL.GasComponents.Boundaries.Boundary boundary2(
      V_flowFixed=-0.2,
      boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      TFixed(displayUnit="K") = 308.15,
      phiFixed=80,
      use_temperatureInput=false)
                        annotation (Placement(transformation(
          extent={{-3,-7},{3,7}},
          rotation=90,
          origin={-9,34})));
    TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=30)
      annotation (Placement(transformation(
          extent={{-3,-6},{3,6}},
          rotation=0,
          origin={55,42})));
    TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=1.02)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={6,42})));
    TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
      SupplementalRejector(
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      hxGeometry(
        finnedTubeLength=0.6,
        nSerialTubes=5,
        nParallelTubes=8,
        nTubeSideParallelHydraulicFlows=5))
      annotation (Placement(transformation(extent={{18,38},{38,58}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
      annotation (Placement(transformation(extent={{77,63},{85,71}}, rotation=0)));
    TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
      pressureStateID_a=2,
      pressureStateID_b=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      thermalResistance=0.001,
      heatCapacityInputType="m, solid",
      solidMass=2.5,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      nCells=5,
      thermalResistanceInputType="l, A, lambda",
      crossSection=0.012,
      hxGeometry(
        innerDiameter_a=0.008,
        length_a=0.382,
        length_b=0.382,
        innerDiameter_b=0.008),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000))
      annotation (Placement(transformation(extent={{-7,-7},{7,7}},
          rotation=90,
          origin={76,-2})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
      annotation (Placement(transformation(extent={{1,61},{8,68}},   rotation=0)));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX gasCooler(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=1,
      m_flowStart_b=-0.5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        length=0.3,
        width=0.1,
        numberOfPlates=14),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-35,49},{-13,71}},
            rotation=0)));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX Evaperater(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_b=-0.5,
      pressureStateID=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        width=0.1,
        numberOfPlates=33,
        length=0.3),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-20,-53},{2,-75}},
            rotation=0)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp1(
        pressureStateID=2, pInitial=3800000) annotation (Placement(transformation(
            extent={{14,-64},{26,-52}}, rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
      annotation (Placement(transformation(extent={{-66,29},{-58,37}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
      annotation (Placement(transformation(extent={{32,-5},{40,3}},  rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
      annotation (Placement(transformation(extent={{-36,-53},{-28,-45}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
      annotation (Placement(transformation(extent={{60,-25},{68,-17}},
                                                                     rotation=0)));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{2,84},{10,92}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-52,88})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC2 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-22,42})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={46,32})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{88,48},{96,56}})));
    Modelica.Blocks.Sources.RealExpression Pgc(y=105e5)
                                                       annotation (Placement(
          transformation(
          origin={3,0},
          extent={{9,-8},{-9,8}},
          rotation=0)));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC5
      annotation (Placement(transformation(extent={{-92,54},{-84,62}})));
    TIL.OtherComponents.Controllers.PIController
                                             highPressureController(
      Ti=10,
      controllerType="PI",
      invertFeedback=true,
      k=1e-9,
      activationTime=500,
      yMin=3.459e-7,
      yMax=2e-6,
      yInitial=1.5e-6)
      annotation (Placement(transformation(extent={{-20,4},{-28,-4}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p
      annotation (Placement(transformation(extent={{-48,-2},{-40,6}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC6
      annotation (Placement(transformation(extent={{24,82},{32,90}})));
  equation
    connect(compressor.portB, pressureState_hp.portA) annotation (Line(
        points={{80,37},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5));

    connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-72.5,78},{-80,78},{-80,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
        points={{-39,97},{-39,98.95},{-33.9875,98.95}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));

    Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.path_b.T_liq_A-gasCooler.summary.path_b.T_liq_B);
    q_borehole = Q_borehole/2/borehole.hBor;
    COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

    connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
        points={{12,42},{18,42},{18,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
       Line(
        points={{38,53.7143},{48,53.7143},{48,54},{56,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
        points={{-21.0125,98.9125},{-18.5063,98.9125},{-18.5063,97},{-16,97}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
        points={{53,-34},{80,-34},{80,-9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
        points={{80,5},{80,23}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portB_a, SupplementalRejector.portA_vle) annotation (Line(
        points={{-13,53.7143},{-6,53.7143},{-6,54},{2,54},{2,53.7143},{18,
            53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasCooler.portA_b, pump.portB) annotation (Line(
        points={{-35,66.2857},{-44.5,66.2857},{-44.5,78},{-58.5,78}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portB_b) annotation (
        Line(
        points={{-14,97},{-8,97},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portA_a, SuctionGasHeatExchager.portB_b) annotation (Line(
        points={{-35,53.7143},{-80,53.7143},{-80,12},{72,12},{72,5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
        points={{2,-70.2857},{12,-70.2857},{12,-92},{18,-92}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp1.portA, separator.portInlet) annotation (Line(
        points={{26,-58},{34,-58},{34,-34},{43,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simplePump.portA, boundary1.port) annotation (Line(
        points={{30,-92},{34,-92},{34,-95.5},{39,-95.5}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint1.sensorPort, compressor.portA) annotation (Line(
        points={{94,17},{94,14},{80,14},{80,23}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint2.sensorPort, pressureState_hp.portA) annotation (Line(
        points={{81,63},{81,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint3.sensorPort, SupplementalRejector.portA_vle) annotation (
       Line(
        points={{4.5,61},{4.5,53.7143},{18,53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
       Line(
        points={{64,-25},{64,-34},{80,-34},{80,-9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC1.port, interfaceMFtoTILLiquid.liquidPort) annotation (
       Line(
        points={{-48,88},{-44,88},{-44,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC.port, gasCooler.portB_b) annotation (Line(
        points={{6,84},{6,82},{-8,82},{-8,66.2857},{-13,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC4.port, pressureState_hp.portA) annotation (Line(
        points={{92,48},{92,44},{80,44},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC2.port, simpleFan.portA) annotation (Line(
        points={{-18,42},{8.88178e-016,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC3.port, SupplementalRejector.portB_gas) annotation (
        Line(
        points={{46,36},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary3.port, SupplementalRejector.portB_gas) annotation (Line(
        points={{55,42},{46,42},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary2.port, simpleFan.portA) annotation (Line(
        points={{-9,34},{-8,34},{-8,42},{8.88178e-016,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(expansionValve.portA, SuctionGasHeatExchager.portA_b) annotation (
        Line(
        points={{-52,-28},{-52,-12},{72,-12},{72,-9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(expansionValve.portB, Evaperater.portA_a) annotation (Line(
        points={{-52,-40},{-52,-57.7143},{-20,-57.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary.port, Evaperater.portA_b) annotation (Line(
        points={{-45.5,-80},{-36,-80},{-36,-70.2857},{-20,-70.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_a, pressureState_lp1.portB) annotation (Line(
        points={{2,-57.7143},{12,-57.7143},{12,-58},{14,-58}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint5.sensorPort, SuctionGasHeatExchager.portA_b) annotation (
       Line(
        points={{36,-5},{36,-12},{72,-12},{72,-9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint6.sensorPort, Evaperater.portA_a) annotation (Line(
        points={{-32,-53},{-32,-57.7143},{-20,-57.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint4.sensorPort, SuctionGasHeatExchager.portB_b) annotation (
       Line(
        points={{-62,29},{-62,24},{-80,24},{-80,12},{72,12},{72,5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC5.port, SuctionGasHeatExchager.portB_b) annotation (
        Line(
        points={{-88,54},{-88,48},{-80,48},{-80,12},{72,12},{72,5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Pgc.y, highPressureController.u_s) annotation (Line(
        points={{-6.9,0},{-20.2667,0}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(sensor_p.port, SuctionGasHeatExchager.portA_b) annotation (Line(
        points={{-44,-2},{-44,-12},{72,-12},{72,-9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_p.sensorValue, highPressureController.u_m) annotation (Line(
        points={{-44,4.2},{-44,8},{-24,8},{-24,3.86667}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(highPressureController.y, expansionValve.effectiveFlowArea_in)
      annotation (Line(
        points={{-28.2667,0},{-32,0},{-32,-34},{-48.25,-34}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(sensor_T_degC6.port, SupplementalRejector.portA_vle) annotation (
        Line(
        points={{28,82},{28,76},{12,76},{12,53.7143},{18,53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}),
              graphics),
      experiment(StopTime=600),
      experimentSetupOutput,
      Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
  end HS1;

  model HS3 "Heat Pump Cycle CO2"

    inner TIL.SystemInformationManager sim(
      redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
        Placement(transformation(extent={{86,82},{100,100}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump pump(presetVariableType="m_flow",
        m_flowFixed=0.23) annotation (Placement(transformation(
          origin={-69.5,78},
          extent={{-7,-7},{7,7}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
        pressureStateID=1, pInitial=8000000) annotation (Placement(transformation(
            extent={{56,48},{68,60}}, rotation=0)));

    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{90,17},{98,25}}, rotation=0)));
    TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
        use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=1.6e-6)
      annotation (Placement(transformation(
          origin={48,-66},
          extent={{-6,-3},{6,3}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
        pressureStateID=3, pInitial=3500000) annotation (Placement(transformation(
            extent={{-44,-84},{-32,-72}},
                                        rotation=0)));
    TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=3e-3)
                  annotation (Placement(transformation(extent={{42,-48},{54,-28}},
            rotation=0)));
    TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
      volumetricEfficiency=0.8,
      use_mechanicalPort=false,
      use_relDisplacementInput=false,
      effectiveIsentropicEfficiency=1,
      nFixed=50,
      displacement=1.5e-5,
      isentropicEfficiency=0.8)          annotation (Placement(transformation(
            extent={{73,23},{87,37}}, rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      dpFixed=0,
      presetVariableType="m_flow",
      m_flowFixed=0.48,
      eta=0.5)          annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=-90,
          origin={24,-92})));
    TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=
          280.15)
      annotation (Placement(transformation(extent={{-35,-102},{-29,-88}})));
    TIL.LiquidComponents.Boundaries.Boundary boundary1(
      m_flowFixed=0.02,
      boundaryType="p",
      TFixed=285.15)
      annotation (Placement(transformation(extent={{36,-103},{42,-88}})));
    Boreholes.UTube borehole(
      redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
      dp_nominal(displayUnit="bar") = 10000,
      xC=0.04,
      matFil(
        k=2.1,
        c=750,
        d=2300),
      rTub=0.0125,
      kTub=0.46,
      eTub=0.0035,
      rExt=2,
      samplePeriod=604800,
      rBor=0.08,
      nVer=10,
      nHor=10,
      m_flow_nominal=0.3,
      redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
        c=1696,
        d=1932,
        k=1.86),
      T_start=291.15,
      hBor=200,
      TExt0_start=291.15)
      annotation (Placement(transformation(extent={{-35,85},{-20,100}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-30,87},{-50,107}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-25,87},{-5,107}})));
    inner Modelica.Fluid.System system(T_start=308.15)
      annotation (Placement(transformation(extent={{-98,82},{-84,96}})));

    Modelica.SIunits.Power Q_borehole;
    Modelica.SIunits.Power q_borehole;
    Real COP_Cooling;

    TIL.GasComponents.Boundaries.Boundary boundary2(
      V_flowFixed=-0.2,
      boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=80,
      use_temperatureInput=true,
      TFixed(displayUnit="K") = 308.15)
                        annotation (Placement(transformation(
          extent={{-3,-7},{3,7}},
          rotation=90,
          origin={-9,34})));
    TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=30,
      TFixed=311.15)
      annotation (Placement(transformation(
          extent={{-3,-6},{3,6}},
          rotation=0,
          origin={55,42})));
    TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=1.02)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={8,42})));
    TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
      SupplementalRejector(
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      hxGeometry(
        finnedTubeLength=0.6,
        nSerialTubes=5,
        nParallelTubes=8,
        nTubeSideParallelHydraulicFlows=4))
      annotation (Placement(transformation(extent={{18,38},{38,58}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
      annotation (Placement(transformation(extent={{77,63},{85,71}}, rotation=0)));
    TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX SuctionGasHeatExchager(
      pressureStateID_a=2,
      pressureStateID_b=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      thermalResistance=0.001,
      heatCapacityInputType="m, solid",
      solidMass=2.5,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      nCells=5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      thermalResistanceInputType="l, A, lambda",
      hxGeometry(
        innerDiameter_a=0.008,
        innerDiameter_b=0.012,
        length_a=0.382,
        length_b=0.382),
      crossSection=0.012)
      annotation (Placement(transformation(extent={{-7,-7},{7,7}},
          rotation=90,
          origin={76,2})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
      annotation (Placement(transformation(extent={{1,61},{8,68}},   rotation=0)));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX gasCooler(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=1,
      m_flowStart_b=-0.5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        length=0.3,
        width=0.1,
        numberOfPlates=14),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-39,49},{-17,71}},
            rotation=0)));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX Evaperater(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_b=-0.5,
      pressureStateID=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        width=0.1,
        numberOfPlates=33,
        length=0.3),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-14,-73},{8,-95}},
            rotation=0)));

    TIL.VLEFluidComponents.Ejectors.EffEjector effEjector(
      redeclare model NozzleModel =
          TIL.VLEFluidComponents.Ejectors.NozzleModels.EnergyBalance,
      fixedEjectorEfficiency=0.308,
      fixedEffectiveDrivingFlowArea=6.264e-7,
      use_effectiveDrivingFlowAreaInput=true)
      annotation (Placement(transformation(extent={{-70,-42},{-54,-26}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp1(
        pressureStateID=2, pInitial=3800000) annotation (Placement(transformation(
            extent={{-14,-40},{-2,-28}},rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
      annotation (Placement(transformation(extent={{-60,61},{-52,69}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
      annotation (Placement(transformation(extent={{-94,-29},{-86,-21}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
      annotation (Placement(transformation(extent={{-38,-25},{-30,-17}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
      annotation (Placement(transformation(extent={{60,-25},{68,-17}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint10(stateViewerIndex=10)
      annotation (Placement(transformation(extent={{-84,-71},{-76,-63}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
      annotation (Placement(transformation(extent={{64,-51},{72,-43}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint9(stateViewerIndex=9)
      annotation (Placement(transformation(extent={{70,-74},{78,-66}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{2,84},{10,92}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-52,88})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC2 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-22,42})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={46,32})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{88,48},{96,56}})));
    Modelica.Blocks.Sources.Trapezoid TempVariation(
      amplitude=8,
      rising=9000,
      width=14400,
      falling=12600,
      period=50400,
      offset=305.15,
      startTime=14400)
      annotation (Placement(transformation(extent={{-56,26},{-40,41}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC5
      annotation (Placement(transformation(extent={{-94,52},{-86,60}})));
    Modelica.Blocks.Sources.RealExpression Pgc(y=100e5)
                                                       annotation (Placement(
          transformation(
          origin={13,0},
          extent={{9,-8},{-9,8}},
          rotation=0)));
    TIL.OtherComponents.Controllers.PIController
                                             highPressureController(
      Ti=10,
      controllerType="PI",
      invertFeedback=true,
      k=1e-9,
      activationTime=500,
      yMin=3.459e-7,
      yMax=2e-6,
      yInitial=1.5e-6)
      annotation (Placement(transformation(extent={{-10,4},{-18,-4}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p
      annotation (Placement(transformation(extent={{-38,8},{-30,16}})));
  equation
    connect(compressor.portB, pressureState_hp.portA) annotation (Line(
        points={{80,37},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5));

    connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-76.5,78},{-80,78},{-80,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
        points={{-39,97},{-39,98.95},{-33.9875,98.95}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));

    Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.path_b.T_liq_A-gasCooler.summary.path_b.T_liq_B);
    q_borehole = Q_borehole/2/borehole.hBor;
    COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

    connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
        points={{14,42},{18,42},{18,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
       Line(
        points={{38,53.7143},{48,53.7143},{48,54},{56,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
        points={{-21.0125,98.9125},{-18.5063,98.9125},{-18.5063,97},{-16,97}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portGas, SuctionGasHeatExchager.portA_a) annotation (Line(
        points={{53,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portB_a, compressor.portA) annotation (Line(
        points={{80,9},{80,23}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portB_a, SupplementalRejector.portA_vle) annotation (Line(
        points={{-17,53.7143},{-6,53.7143},{-6,54},{2,54},{2,53.7143},{18,
            53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasCooler.portA_b, pump.portB) annotation (Line(
        points={{-39,66.2857},{-44.5,66.2857},{-44.5,78},{-62.5,78}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portB_b) annotation (
        Line(
        points={{-14,97},{-8,97},{-8,66.2857},{-17,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portA_a, SuctionGasHeatExchager.portB_b) annotation (Line(
        points={{-39,53.7143},{-80,53.7143},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
        points={{8,-90.2857},{12,-90.2857},{12,-92},{18,-92}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SuctionGasHeatExchager.portA_b, effEjector.drivingPort) annotation (
       Line(
        points={{72,-5},{72,-8},{-76,-8},{-76,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portLiquid, expansionValve.portA) annotation (Line(
        points={{48,-48},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp.portA, Evaperater.portA_a) annotation (Line(
        points={{-32,-78},{-18,-78},{-18,-77.7143},{-14,-77.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.suctionPort, pressureState_lp.portB) annotation (Line(
        points={{-62,-42},{-62,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary.port, Evaperater.portA_b) annotation (Line(
        points={{-32,-95},{-24,-95},{-24,-90.2857},{-14,-90.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.dischargePort, pressureState_lp1.portB) annotation (Line(
        points={{-54,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp1.portA, separator.portInlet) annotation (Line(
        points={{-2,-34},{43,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_a, expansionValve.portB) annotation (Line(
        points={{8,-77.7143},{28,-77.7143},{28,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint5.sensorPort, effEjector.drivingPort) annotation (Line(
        points={{-90,-29},{-90,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simplePump.portA, boundary1.port) annotation (Line(
        points={{30,-92},{34,-92},{34,-95.5},{39,-95.5}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint1.sensorPort, compressor.portA) annotation (Line(
        points={{94,17},{94,14},{80,14},{80,23}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint2.sensorPort, pressureState_hp.portA) annotation (Line(
        points={{81,63},{81,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint3.sensorPort, SupplementalRejector.portA_vle) annotation (
       Line(
        points={{4.5,61},{4.5,53.7143},{18,53.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint4.sensorPort, SuctionGasHeatExchager.portB_b) annotation (
       Line(
        points={{-56,61},{-56,54},{-80,54},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint8.sensorPort, expansionValve.portA) annotation (Line(
        points={{68,-51},{68,-54},{48,-54},{48,-60}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint6.sensorPort, pressureState_lp1.portB) annotation (Line(
        points={{-34,-25},{-34,-34},{-14,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint7.sensorPort, SuctionGasHeatExchager.portA_a) annotation (
       Line(
        points={{64,-25},{64,-34},{80,-34},{80,-5}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint10.sensorPort, pressureState_lp.portB) annotation (Line(
        points={{-80,-71},{-80,-78},{-44,-78}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint9.sensorPort, expansionValve.portB) annotation (Line(
        points={{74,-74},{74,-78},{48,-78},{48,-72}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC1.port, interfaceMFtoTILLiquid.liquidPort) annotation (
       Line(
        points={{-48,88},{-44,88},{-44,97},{-41,97}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC.port, gasCooler.portB_b) annotation (Line(
        points={{6,84},{6,82},{-8,82},{-8,66.2857},{-17,66.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC4.port, pressureState_hp.portA) annotation (Line(
        points={{92,48},{92,44},{80,44},{80,54},{68,54}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC2.port, simpleFan.portA) annotation (Line(
        points={{-18,42},{2,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC3.port, SupplementalRejector.portB_gas) annotation (
        Line(
        points={{46,36},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary3.port, SupplementalRejector.portB_gas) annotation (Line(
        points={{55,42},{46,42},{46,42.2857},{38,42.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary2.port, simpleFan.portA) annotation (Line(
        points={{-9,34},{-8,34},{-8,42},{2,42}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC5.port, SuctionGasHeatExchager.portB_b) annotation (
        Line(
        points={{-90,52},{-90,46},{-80,46},{-80,16},{72,16},{72,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(TempVariation.y, boundary2.T_in) annotation (Line(
        points={{-39.2,33.5},{-18,33.5},{-18,31},{-4.8,31}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(Pgc.y,highPressureController. u_s) annotation (Line(
        points={{3.1,0},{-10.2667,0}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(sensor_p.sensorValue,highPressureController. u_m) annotation (Line(
        points={{-34,14.2},{-34,16},{-14,16},{-14,3.86667}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(sensor_p.port, effEjector.drivingPort) annotation (Line(
        points={{-34,8},{-34,-8},{-76,-8},{-76,-34},{-70,-34}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(highPressureController.y, effEjector.effectiveDrivingFlowArea_in)
      annotation (Line(
        points={{-18.2667,0},{-40,0},{-40,-4},{-62,-4},{-62,-26}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}),
              graphics),
      experiment(StopTime=600),
      experimentSetupOutput,
      Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
  end HS3;

  model HS2 "Heat Pump Cycle CO2"

    inner TIL.SystemInformationManager sim(
      redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.GasTypes.VDI4670_MoistAir gasType1)     annotation (
        Placement(transformation(extent={{84,82},{98,100}},  rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump pump(presetVariableType="m_flow",
        m_flowFixed=0.23) annotation (Placement(transformation(
          origin={-69.5,74},
          extent={{-7,-7},{7,7}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
        pressureStateID=1, pInitial=9000000) annotation (Placement(transformation(
            extent={{56,44},{68,56}}, rotation=0)));

    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{54,1},{62,9}},   rotation=0)));
    TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
        use_effectiveFlowAreaInput=false, effectiveFlowAreaFixed=1.8e-6)
      annotation (Placement(transformation(
          origin={48,-52},
          extent={{-6,-3},{6,3}},
          rotation=270)));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
        pressureStateID=3, pInitial=3500000) annotation (Placement(transformation(
            extent={{-44,-70},{-32,-58}},
                                        rotation=0)));
    TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2, V=3e-3)
                  annotation (Placement(transformation(extent={{42,-34},{54,-14}},
            rotation=0)));
    TIL.VLEFluidComponents.Compressors.EffCompressor compressor(
      volumetricEfficiency=0.8,
      use_mechanicalPort=false,
      use_relDisplacementInput=false,
      effectiveIsentropicEfficiency=1,
      nFixed=50,
      displacement=1.5e-5,
      isentropicEfficiency=0.8)          annotation (Placement(transformation(
            extent={{73,9},{87,23}},  rotation=0)));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      dpFixed=0,
      presetVariableType="m_flow",
      m_flowFixed=0.48,
      eta=0.5)          annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=-90,
          origin={24,-78})));
    TIL.LiquidComponents.Boundaries.Boundary boundary(boundaryType="p", TFixed=
          280.15)
      annotation (Placement(transformation(extent={{-35,-88},{-29,-74}})));
    TIL.LiquidComponents.Boundaries.Boundary boundary1(
      m_flowFixed=0.02,
      boundaryType="p",
      TFixed=285.15)
      annotation (Placement(transformation(extent={{36,-89},{42,-74}})));
    Boreholes.UTube borehole(
      redeclare package Medium = Modelica.Media.Examples.TwoPhaseWater,
      dp_nominal(displayUnit="bar") = 10000,
      xC=0.04,
      matFil(
        k=2.1,
        c=750,
        d=2300),
      rTub=0.0125,
      kTub=0.46,
      eTub=0.0035,
      rExt=2,
      samplePeriod=604800,
      rBor=0.08,
      nVer=10,
      nHor=10,
      m_flow_nominal=0.3,
      redeclare Buildings.HeatTransfer.Data.Soil.Granite matSoi(
        c=1696,
        d=1932,
        k=1.86),
      hBor=260,
      T_start=291.15,
      TExt0_start=291.15)
      annotation (Placement(transformation(extent={{-35,81},{-20,96}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-30,83},{-50,103}})));
    InterfaceMFtoTILLiquid interfaceMFtoTILLiquid1(redeclare package Medium =
          Modelica.Media.Examples.TwoPhaseWater)
      annotation (Placement(transformation(extent={{-25,83},{-5,103}})));
    inner Modelica.Fluid.System system(T_start=308.15)
      annotation (Placement(transformation(extent={{40,82},{54,96}})));

    Modelica.SIunits.Power Q_borehole;
    Modelica.SIunits.Power q_borehole;
    Real COP_Cooling;

    TIL.GasComponents.Boundaries.Boundary boundary2(
      V_flowFixed=-0.2,
      boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=80,
      use_temperatureInput=false,
      TFixed(displayUnit="K") = 308)
                        annotation (Placement(transformation(
          extent={{-3,-7},{3,7}},
          rotation=-90,
          origin={-11,30})));
    TIL.GasComponents.Boundaries.Boundary boundary3(boundaryType="p",
      streamVariablesInputTypeConcentration="phi",
      phiFixed=30)
      annotation (Placement(transformation(
          extent={{-3,-6},{3,6}},
          rotation=0,
          origin={53,38})));
    TIL.GasComponents.Fans.SimpleFan simpleFan(V_flowFixed=1.04)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={8,38})));
    TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.ParallelFlowHX
      SupplementalRejector(
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      hxGeometry(
        finnedTubeLength=0.6,
        nSerialTubes=5,
        nParallelTubes=8,
        nTubeSideParallelHydraulicFlows=4),
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2000))
      annotation (Placement(transformation(extent={{18,34},{38,54}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
      annotation (Placement(transformation(extent={{77,57},{85,65}}, rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
      annotation (Placement(transformation(extent={{1,57},{8,64}},   rotation=0)));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX gasCooler(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=1,
      m_flowStart_b=-0.5,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        length=0.3,
        width=0.1,
        numberOfPlates=19),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-35,45},{-13,67}},
            rotation=0)));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX Evaperater(
      m_flowStart_a=0.5,
      includeSummaryArrays=true,
      includeDefaultSummary=true,
      nCells=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_b=-0.5,
      pressureStateID=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        patternAmplitude=2e-3,
        width=0.1,
        numberOfPlates=33,
        length=0.3),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2000),
      TInitialLiquid_b=293.15,
      pStart_a=5000000)
                annotation (Placement(transformation(extent={{-14,-59},{8,-81}},
            rotation=0)));

    TIL.VLEFluidComponents.Ejectors.EffEjector effEjector(
      redeclare model NozzleModel =
          TIL.VLEFluidComponents.Ejectors.NozzleModels.EnergyBalance,
      fixedEffectiveDrivingFlowArea=3.5e-7,
      fixedEjectorEfficiency=0.308,
      use_effectiveDrivingFlowAreaInput=true)
      annotation (Placement(transformation(extent={{-70,-28},{-54,-12}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp1(
        pressureStateID=2, pInitial=3800000) annotation (Placement(transformation(
            extent={{-14,-26},{-2,-14}},rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4)
      annotation (Placement(transformation(extent={{-58,57},{-50,65}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
      annotation (Placement(transformation(extent={{-38,-11},{-30,-3}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
      annotation (Placement(transformation(extent={{-84,-57},{-76,-49}},
            rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
      annotation (Placement(transformation(extent={{60,-37},{68,-29}},
                                                                     rotation=0)));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
      annotation (Placement(transformation(extent={{60,-58},{68,-50}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{2,80},{10,88}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-52,84})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC2 annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={-34,38})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={44,26})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{88,44},{96,52}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC5
      annotation (Placement(transformation(extent={{-74,54},{-66,62}})));
    Modelica.Blocks.Sources.RealExpression phSetpoint(y=95e5) annotation (
        Placement(transformation(
          origin={-19,10},
          extent={{9,-8},{-9,8}},
          rotation=0)));
    TIL.OtherComponents.Controllers.PIController
                                             highPressureController(
      Ti=10,
      controllerType="PI",
      invertFeedback=true,
      k=1e-9,
      activationTime=500,
      yMin=3.459e-7,
      yMax=2e-6,
      yInitial=1.5e-6)
      annotation (Placement(transformation(extent={{-36,14},{-44,6}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p
      annotation (Placement(transformation(extent={{-62,22},{-54,30}})));
  equation
    connect(compressor.portB, pressureState_hp.portA) annotation (Line(
        points={{80,23},{80,50},{68,50}},
        color={153,204,0},
        thickness=0.5));

    connect(pump.portA, interfaceMFtoTILLiquid.liquidPort) annotation (Line(
        points={{-76.5,74},{-80,74},{-80,93},{-41,93}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid.port_a, borehole.port_a) annotation (Line(
        points={{-39,93},{-39,94.95},{-33.9875,94.95}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));

    Q_borehole = gasCooler.portB_b.m_flow*4198*(gasCooler.summary.path_b.T_liq_A-gasCooler.summary.path_b.T_liq_B);
    q_borehole = Q_borehole/2/borehole.hBor;
    COP_Cooling = Evaperater.summary.Q_flow/compressor.summary.P_flow_vle;

    connect(boundary2.port,simpleFan. portA) annotation (Line(
        points={{-11,30},{-10,30},{-10,38},{2,38}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simpleFan.portB, SupplementalRejector.portA_gas) annotation (Line(
        points={{14,38},{18,38},{18,38.2857}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_vle, pressureState_hp.portB) annotation (
       Line(
        points={{38,49.7143},{48,49.7143},{48,50},{56,50}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SupplementalRejector.portB_gas, boundary3.port) annotation (Line(
        points={{38,38.2857},{53,38.2857},{53,38}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(borehole.port_b, interfaceMFtoTILLiquid1.port_a) annotation (Line(
        points={{-21.0125,94.9125},{-18.5063,94.9125},{-18.5063,93},{-16,93}},
        color={23,162,255},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portB_a, SupplementalRejector.portA_vle) annotation (Line(
        points={{-13,49.7143},{-6,49.7143},{-6,50},{2,50},{2,49.7143},{18,
            49.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasCooler.portA_b, pump.portB) annotation (Line(
        points={{-35,62.2857},{-44.5,62.2857},{-44.5,74},{-62.5,74}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(interfaceMFtoTILLiquid1.liquidPort, gasCooler.portB_b) annotation (
        Line(
        points={{-14,93},{-8,93},{-8,62.2857},{-13,62.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_b, simplePump.portB) annotation (Line(
        points={{8,-76.2857},{12,-76.2857},{12,-78},{18,-78}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portLiquid, expansionValve.portA) annotation (Line(
        points={{48,-34},{48,-46}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp.portA, Evaperater.portA_a) annotation (Line(
        points={{-32,-64},{-18,-64},{-18,-63.7143},{-14,-63.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.suctionPort, pressureState_lp.portB) annotation (Line(
        points={{-62,-28},{-62,-64},{-44,-64}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(boundary.port, Evaperater.portA_b) annotation (Line(
        points={{-32,-81},{-24,-81},{-24,-76.2857},{-14,-76.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(effEjector.dischargePort, pressureState_lp1.portB) annotation (Line(
        points={{-54,-20},{-14,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pressureState_lp1.portA, separator.portInlet) annotation (Line(
        points={{-2,-20},{43,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(Evaperater.portB_a, expansionValve.portB) annotation (Line(
        points={{8,-63.7143},{28,-63.7143},{28,-64},{48,-64},{48,-58}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simplePump.portA, boundary1.port) annotation (Line(
        points={{30,-78},{34,-78},{34,-81.5},{39,-81.5}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint2.sensorPort, pressureState_hp.portA) annotation (Line(
        points={{81,57},{81,50},{68,50}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint3.sensorPort, SupplementalRejector.portA_vle) annotation (
       Line(
        points={{4.5,57},{4.5,49.7143},{18,49.7143}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint6.sensorPort, expansionValve.portA) annotation (Line(
        points={{64,-37},{64,-42},{48,-42},{48,-46}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint5.sensorPort, pressureState_lp1.portB) annotation (Line(
        points={{-34,-11},{-34,-20},{-14,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint8.sensorPort, pressureState_lp.portB) annotation (Line(
        points={{-80,-57},{-80,-64},{-44,-64}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint7.sensorPort, expansionValve.portB) annotation (Line(
        points={{64,-58},{64,-64},{48,-64},{48,-58}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC1.port, interfaceMFtoTILLiquid.liquidPort) annotation (
       Line(
        points={{-48,84},{-44,84},{-44,93},{-41,93}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC.port, gasCooler.portB_b) annotation (Line(
        points={{6,80},{6,78},{-8,78},{-8,62.2857},{-13,62.2857}},
        color={0,170,238},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC4.port, pressureState_hp.portA) annotation (Line(
        points={{92,44},{92,40},{80,40},{80,50},{68,50}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC2.port, simpleFan.portA) annotation (Line(
        points={{-30,38},{2,38}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC3.port, boundary3.port) annotation (Line(
        points={{44,30},{48,30},{48,38},{53,38}},
        color={255,153,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(separator.portGas, compressor.portA) annotation (Line(
        points={{53,-20},{80,-20},{80,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasCooler.portA_a, effEjector.drivingPort) annotation (Line(
        points={{-35,49.7143},{-78,49.7143},{-78,-20},{-70,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(statePoint1.sensorPort, compressor.portA) annotation (Line(
        points={{58,1},{58,-6},{80,-6},{80,9}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_p.port, effEjector.drivingPort) annotation (Line(
        points={{-58,22},{-58,18},{-78,18},{-78,-20},{-70,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_p.sensorValue, highPressureController.u_m) annotation (Line(
        points={{-58,28.2},{-58,28},{-40,28},{-40,13.8667}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(phSetpoint.y, highPressureController.u_s) annotation (Line(
        points={{-28.9,10},{-36.2667,10}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(highPressureController.y, effEjector.effectiveDrivingFlowArea_in)
      annotation (Line(
        points={{-44.2667,10},{-62,10},{-62,-12}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(statePoint4.sensorPort, effEjector.drivingPort) annotation (Line(
        points={{-54,57},{-54,50},{-78,49.7143},{-78,-20},{-70,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    connect(sensor_T_degC5.port, effEjector.drivingPort) annotation (Line(
        points={{-70,54},{-70,50},{-78,49.7143},{-78,-20},{-70,-20}},
        color={153,204,0},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}),
              graphics),
      experiment(StopTime=600),
      experimentSetupOutput,
      Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"));
  end HS2;

  annotation (uses(
      Buildings(version="1.5"),
      TILMedia(version="3.1.0"),
      TIL(version="3.1.0"),
      Modelica(version="3.2.1")));
end CO2GCHPModels_Master_Monjur;
